@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -260,23 +260,12 @@ CEC_Prefs_Packet::CEC_Prefs_Packet(uint32 selection, EC_DETAIL_LEVEL pref_detail
 			filePrefs.AddTag(CECEmptyTag(EC_TAG_FILES_CHECK_FREE_SPACE));
 		}
 		filePrefs.AddTag(CECTag(EC_TAG_FILES_MIN_FREE_SPACE, thePrefs::GetMinFreeDiskSpaceMB()));
+		if (!thePrefs::CreateFilesSparse()) {
+			filePrefs.AddTag(CECEmptyTag(EC_TAG_FILES_CREATE_NORMAL));
+		}
 		AddTag(filePrefs);
 	}
 
-	if (selection & EC_PREFS_SRCDROP) {
-		CECEmptyTag srcdrop(EC_TAG_PREFS_SRCDROP);
-		srcdrop.AddTag(CECTag(EC_TAG_SRCDROP_NONEEDED, (uint8)thePrefs::GetNoNeededSources()));
-		if (thePrefs::DropFullQueueSources()) {
-			srcdrop.AddTag(CECEmptyTag(EC_TAG_SRCDROP_DROP_FQS));
-		}
-		if (thePrefs::DropHighQueueRankingSources()) {
-			srcdrop.AddTag(CECEmptyTag(EC_TAG_SRCDROP_DROP_HQRS));
-		}
-		srcdrop.AddTag(CECTag(EC_TAG_SRCDROP_HQRS_VALUE, (uint16)thePrefs::HighQueueRanking()));
-		srcdrop.AddTag(CECTag(EC_TAG_SRCDROP_AUTODROP_TIMER, (uint16)thePrefs::GetAutoDropTimer()));
-		AddTag(srcdrop);
-	}
-
 	if (selection & EC_PREFS_DIRECTORIES) {
 		CECEmptyTag dirPrefs(EC_TAG_PREFS_DIRECTORIES);
 		dirPrefs.AddTag(CECTag(EC_TAG_DIRECTORIES_INCOMING, thePrefs::GetIncomingDir().GetRaw()));
@@ -315,7 +304,7 @@ CEC_Prefs_Packet::CEC_Prefs_Packet(uint32 selection, EC_DETAIL_LEVEL pref_detail
 		if (thePrefs::IsSecureIdentEnabled()) {
 			secPrefs.AddTag(CECEmptyTag(EC_TAG_SECURITY_USE_SECIDENT));
 		}
-		
+
 		if (thePrefs::IsClientCryptLayerSupported()) {
 			secPrefs.AddTag(CECEmptyTag(EC_TAG_SECURITY_OBFUSCATION_SUPPORTED));
 		}
@@ -373,7 +362,7 @@ void ApplyBoolean(bool use_tag, const CECTag *thisTab, void (applyFunc)(bool), i
  *  -> On remote gui they are loaded on startup, and then changed on-command
  *  -> Webserver doesn't supposed to change it.
  */
-void CEC_Prefs_Packet::Apply()
+void CEC_Prefs_Packet::Apply() const
 {
 	const CECTag *thisTab = NULL;
 	const CECTag *oneTag = NULL;
@@ -397,7 +386,7 @@ void CEC_Prefs_Packet::Apply()
 	// webserver doesn't transmit all boolean values
 	//
 	bool use_tag = (GetDetailLevel() == EC_DETAIL_FULL);
-	
+
 	if ((thisTab = GetTagByName(EC_TAG_PREFS_CONNECTIONS)) != NULL) {
 		if ((oneTag = thisTab->GetTagByName(EC_TAG_CONN_UL_CAP)) != NULL) {
 			thePrefs::SetMaxGraphUploadRate(oneTag->GetInt());
@@ -487,7 +476,7 @@ void CEC_Prefs_Packet::Apply()
 		ApplyBoolean(use_tag, thisTab, thePrefs::SetManualHighPrio, EC_TAG_SERVERS_MANUAL_HIGH_PRIO);
 		if ((oneTag = thisTab->GetTagByName(EC_TAG_SERVERS_UPDATE_URL)) != NULL) {
 			thePrefs::SetEd2kServersUrl(oneTag->GetStringData());
-		}		
+		}
 	}
 
 	if ((thisTab = GetTagByName(EC_TAG_PREFS_FILES)) != NULL) {
@@ -506,20 +495,7 @@ void CEC_Prefs_Packet::Apply()
 		if ((oneTag = thisTab->GetTagByName(EC_TAG_FILES_MIN_FREE_SPACE)) != NULL) {
 			thePrefs::SetMinFreeDiskSpaceMB(oneTag->GetInt());
 		}
-	}
-
-	if ((thisTab = GetTagByName(EC_TAG_PREFS_SRCDROP)) != NULL) {
-		if ((oneTag = thisTab->GetTagByName(EC_TAG_SRCDROP_NONEEDED)) != NULL) {
-			thePrefs::SetNoNeededSources(oneTag->GetInt());
-		}
-		ApplyBoolean(use_tag, thisTab, thePrefs::SetDropFullQueueSources, EC_TAG_SRCDROP_DROP_FQS);
-		ApplyBoolean(use_tag, thisTab, thePrefs::SetDropHighQueueRankingSources, EC_TAG_SRCDROP_DROP_HQRS);
-		if ((oneTag = thisTab->GetTagByName(EC_TAG_SRCDROP_HQRS_VALUE)) != NULL) {
-			thePrefs::SetHighQueueRanking(oneTag->GetInt());
-		}
-		if ((oneTag = thisTab->GetTagByName(EC_TAG_SRCDROP_AUTODROP_TIMER)) != NULL) {
-			thePrefs::SetAutoDropTimer(oneTag->GetInt());
-		}
+		ApplyBoolean(use_tag, thisTab, thePrefs::CreateFilesNormal, EC_TAG_FILES_CREATE_NORMAL);
 	}
 
 	if ((thisTab = GetTagByName(EC_TAG_PREFS_DIRECTORIES)) != NULL) {
@@ -531,7 +507,7 @@ void CEC_Prefs_Packet::Apply()
 		}
 		if ((oneTag = thisTab->GetTagByName(EC_TAG_DIRECTORIES_SHARED)) != NULL) {
 			theApp->glob_prefs->shareddir_list.clear();
-			for (CECTag::const_iterator it = oneTag->begin(); it != oneTag->end(); it++) {
+			for (CECTag::const_iterator it = oneTag->begin(); it != oneTag->end(); ++it) {
 				theApp->glob_prefs->shareddir_list.push_back(CPath(it->GetStringData()));
 			}
 		}
@@ -578,7 +554,7 @@ void CEC_Prefs_Packet::Apply()
 			thePrefs::SetServerKeepAliveTimeout(oneTag->GetInt());
 		}
 	}
-	
+
 	if ((thisTab = GetTagByName(EC_TAG_PREFS_KADEMLIA)) != NULL) {
 		if ((oneTag = thisTab->GetTagByName(EC_TAG_KADEMLIA_UPDATE_URL)) != NULL) {
 			thePrefs::SetKadNodesUrl(oneTag->GetStringData());
