@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -40,14 +40,15 @@
 
 const uint32 MAX_PACKET_SIZE = 2000000;
 
+// cppcheck-suppress uninitMemberVar CEMSocket::pendingHeader
 CEMSocket::CEMSocket(const CProxyData *ProxyData)
-	: CEncryptedStreamSocket(wxSOCKET_NOWAIT, ProxyData)
+	: CEncryptedStreamSocket(MULE_SOCKET_NOWAIT, ProxyData)
 {
 	// If an interface has been specified,
 	// then we need to bind to it.
 	if (!thePrefs::GetAddress().IsEmpty()) {
 		amuleIPV4Address host;
-		
+
 		// No need to warn here, in case of failure to
 		// assign the hostname. That is already done
 		// in amule.cpp when starting ...
@@ -59,7 +60,7 @@ CEMSocket::CEMSocket(const CProxyData *ProxyData)
 	byConnected = ES_NOTCONNECTED;
 	m_uTimeOut = CONNECTION_TIMEOUT; // default timeout for ed2k sockets
 
-	// Download (pseudo) rate control	
+	// Download (pseudo) rate control
 	downloadLimit = 0;
 	downloadLimitEnable = false;
 	pendingOnReceive = false;
@@ -95,9 +96,6 @@ CEMSocket::CEMSocket(const CProxyData *ProxyData)
     m_hasSent = false;
 
 	lastFinishedStandard = 0;
-
-	DoingDestroy = false;
-	
 }
 
 CEMSocket::~CEMSocket()
@@ -105,7 +103,7 @@ CEMSocket::~CEMSocket()
     // need to be locked here to know that the other methods
     // won't be in the middle of things
     {
-    	wxMutexLocker lock(m_sendLocker);
+	wxMutexLocker lock(m_sendLocker);
 		byConnected = ES_DISCONNECTED;
 	}
 
@@ -116,16 +114,11 @@ CEMSocket::~CEMSocket()
 	}
 
     ClearQueues();
-	
-	SetNotify(0);
-	Notify(FALSE);
-}
 
-void CEMSocket::Destroy() {
-	if (!DoingDestroy) {		
-		DoingDestroy = true;
-		wxSocketClient::Destroy();
-	}	
+#ifndef ASIO_SOCKETS
+	SetNotify(0);	// this is already done in Destroy()
+	Notify(FALSE);
+#endif
 }
 
 
@@ -142,8 +135,8 @@ void CEMSocket::ClearQueues()
 		}
 		m_standard_queue.clear();
 	}
-	
-	// Download (pseudo) rate control	
+
+	// Download (pseudo) rate control
 	downloadLimit = 0;
 	downloadLimitEnable = false;
 	pendingOnReceive = false;
@@ -169,14 +162,14 @@ void CEMSocket::OnClose(int WXUNUSED(nErrorCode))
     // need to be locked here to know that the other methods
     // won't be in the middle of things
     {
-    	wxMutexLocker lock(m_sendLocker);
+	wxMutexLocker lock(m_sendLocker);
 		byConnected = ES_DISCONNECTED;
 	}
 
     // now that we know no other method will keep adding to the queue
     // we can remove ourself from the queue
     theApp->uploadBandwidthThrottler->RemoveFromAllQueues(this);
-	
+
 	ClearQueues();
 }
 
@@ -184,17 +177,16 @@ void CEMSocket::OnClose(int WXUNUSED(nErrorCode))
 void CEMSocket::OnReceive(int nErrorCode)
 {
 	if(nErrorCode) {
-		uint32 error = LastError(); 
-		if (error != wxSOCKET_WOULDBLOCK) {
+		if (LastError()) {
 			OnError(nErrorCode);
 			return;
 		}
 	}
-	
+
 	// Check current connection state
 	if (byConnected == ES_DISCONNECTED) {
 		return;
-	} else {	
+	} else {
 		byConnected = ES_CONNECTED; // ES_DISCONNECTED, ES_NOTCONNECTED, ES_CONNECTED
 	}
 
@@ -236,10 +228,11 @@ void CEMSocket::OnReceive(int nErrorCode)
 		if (readMax) {
 			wxMutexLocker lock(m_sendLocker);
 			ret = Read(buf, readMax);
-			if (Error() || (ret == 0)) {
-				if (LastError() == wxSOCKET_WOULDBLOCK) {
-					pendingOnReceive = true;
-				}
+			if (BlocksRead()) {
+				pendingOnReceive = true;
+				return;
+			}
+			if (LastError() || ret == 0) {
 				return;
 			}
 		}
@@ -293,8 +286,8 @@ void CEMSocket::OnReceive(int nErrorCode)
 void CEMSocket::SetDownloadLimit(uint32 limit)
 {
 	downloadLimit = limit;
-	downloadLimitEnable = true;	
-	
+	downloadLimitEnable = true;
+
 	// CPU load improvement
 	if(limit > 0 && pendingOnReceive == true){
 		OnReceive(0);
@@ -420,8 +413,8 @@ void CEMSocket::OnSend(int nErrorCode)
 		return;
 	}
 
-	CEncryptedStreamSocket::OnSend(0);	
-	
+	CEncryptedStreamSocket::OnSend(0);
+
 	wxMutexLocker lock( m_sendLocker );
     m_bBusy = false;
 
@@ -430,7 +423,7 @@ void CEMSocket::OnSend(int nErrorCode)
 
 	    if (m_currentPacket_is_controlpacket) {
 	        // queue up for control packet
-    	    theApp->uploadBandwidthThrottler->QueueForSendingControlPacket(this, HasSent());
+	    theApp->uploadBandwidthThrottler->QueueForSendingControlPacket(this, HasSent());
 		}
     }
 }
@@ -461,7 +454,7 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 	wxMutexLocker lock(m_sendLocker);
 
 	//printf("* Attempt to send a packet on socket %p\n", this);
-	
+
 	if (byConnected == ES_DISCONNECTED) {
 		//printf("* Disconnected socket %p\n", this);
         SocketSentBytes returnVal = { false, 0, 0 };
@@ -470,27 +463,27 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 		//printf("* Busy socket %p\n", this);
         SocketSentBytes returnVal = { true, 0, 0 };
         return returnVal;
-    }	
+    }
 
     bool anErrorHasOccured = false;
     uint32 sentStandardPacketBytesThisCall = 0;
     uint32 sentControlPacketBytesThisCall = 0;
-	
+
     if (byConnected == ES_CONNECTED && IsEncryptionLayerReady() && (!m_bBusy || onlyAllowedToSendControlPacket)) {
 
 		//printf("* Internal attemptto send on %p\n", this);
-		
+
 		if(minFragSize < 1) {
 			minFragSize = 1;
 		}
-	
+
 		maxNumberOfBytesToSend = GetNextFragSize(maxNumberOfBytesToSend, minFragSize);
-	
+
 		bool bWasLongTimeSinceSend = (::GetTickCount() - lastSent) > 1000;
-	
+
 		lastCalledSend = ::GetTickCount();
-	
-			
+
+
 		while(sentStandardPacketBytesThisCall + sentControlPacketBytesThisCall < maxNumberOfBytesToSend && anErrorHasOccured == false && // don't send more than allowed. Also, there should have been no error in earlier loop
 			  (!m_control_queue.empty() || !m_standard_queue.empty() || sendbuffer != NULL) && // there must exist something to send
 			  (onlyAllowedToSendControlPacket == false || // this means we are allowed to send both types of packets, so proceed
@@ -500,7 +493,7 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 			   (sendbuffer != NULL && m_currentPacket_is_controlpacket == false && bWasLongTimeSinceSend && !m_control_queue.empty() && m_standard_queue.empty() && (sentStandardPacketBytesThisCall + sentControlPacketBytesThisCall) < minFragSize) // We have waited to long to clean the current packet (which may be a standard packet that is in the way). Proceed no matter what the value of onlyAllowedToSendControlPacket.
 			  )
 			 ) {
-	
+
 			// If we are currently not in the progress of sending a packet, we will need to find the next one to send
 			if(sendbuffer == NULL) {
 				CPacket* curPacket = NULL;
@@ -516,7 +509,7 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 					m_standard_queue.pop_front();
 					curPacket = queueEntry.packet;
 					m_actualPayloadSize = queueEntry.actualPayloadSize;
-	
+
 					// remember this for statistics purposes.
 					m_currentPackageIsFromPartFile = curPacket->IsFromPF();
 				} else {
@@ -524,21 +517,21 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 					// if we reach this point, then there's something wrong with the while condition above!
 					wxFAIL;
 					AddDebugLogLineC(logGeneral, wxT("EMSocket: Couldn't get a new packet! There's an error in the first while condition in EMSocket::Send()"));
-	
+
 					SocketSentBytes returnVal = { true, sentStandardPacketBytesThisCall, sentControlPacketBytesThisCall };
 					return returnVal;
 				}
-	
+
 				// We found a packet to send. Get the data to send from the
 				// package container and dispose of the container.
 				sendblen = curPacket->GetRealPacketSize();
 				sendbuffer = curPacket->DetachPacket();
 				sent = 0;
 				delete curPacket;
-				
+
 				CryptPrepareSendData((byte*)sendbuffer, sendblen);
 			}
-	
+
 			// At this point we've got a packet to send in sendbuffer. Try to send it. Loop until entire packet
 			// is sent, or until we reach maximum bytes to send for this call, or until we get an error.
 			// NOTE! If send would block (returns WOULDBLOCK), we will return from this method INSIDE this loop.
@@ -564,37 +557,31 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 						tosend = nextFragMaxBytesToSent-(sentStandardPacketBytesThisCall + sentControlPacketBytesThisCall);
 				}
 				wxASSERT(tosend != 0 && tosend <= sendblen-sent);
-				
+
 				//DWORD tempStartSendTick = ::GetTickCount();
-	
+
 				lastSent = ::GetTickCount();
-	
+
 				uint32 result = CEncryptedStreamSocket::Write(sendbuffer+sent,tosend);
-				
-				if (Error()){
-					
-					uint32 error = LastError();
-					if (error == wxSOCKET_WOULDBLOCK){
-						m_bBusy = true;
-	
-						SocketSentBytes returnVal = { true, sentStandardPacketBytesThisCall, sentControlPacketBytesThisCall };
-						
-						return returnVal; // Send() blocked, onsend will be called when ready to send again
-					} else{
-						// Send() gave an error
-						anErrorHasOccured = true;
-					}
+
+				if (BlocksWrite()) {
+					m_bBusy = true;
+					SocketSentBytes returnVal = { true, sentStandardPacketBytesThisCall, sentControlPacketBytesThisCall };
+					return returnVal; // Send() blocked, onsend will be called when ready to send again
+				} else if (LastError()) {
+					// Send() gave an error
+					anErrorHasOccured = true;
 				} else {
 					// we managed to send some bytes. Perform bookkeeping.
 					m_bBusy = false;
 					m_hasSent = true;
-	
+
 					sent += result;
-	
+
 					// Log send bytes in correct class
 					if(m_currentPacket_is_controlpacket == false) {
 						sentStandardPacketBytesThisCall += result;
-	
+
 						if(m_currentPackageIsFromPartFile == true) {
 							m_numberOfSentBytesPartFile += result;
 						} else {
@@ -606,27 +593,27 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 					}
 				}
 			}
-	
+
 			if (sent == sendblen){
 				// we are done sending the current packet. Delete it and set
 				// sendbuffer to NULL so a new packet can be fetched.
 				delete[] sendbuffer;
 				sendbuffer = NULL;
 				sendblen = 0;
-	
+
 				if(!m_currentPacket_is_controlpacket) {
 					m_actualPayloadSizeSent += m_actualPayloadSize;
 					m_actualPayloadSize = 0;
-	
+
 					lastFinishedStandard = ::GetTickCount(); // reset timeout
 					m_bAccelerateUpload = false; // Safe until told otherwise
 				}
-	
+
 				sent = 0;
 			}
 		}
 	}
-	
+
 	if(onlyAllowedToSendControlPacket && (!m_control_queue.empty() || (sendbuffer != NULL && m_currentPacket_is_controlpacket))) {
 		// enter control packet send queue
 		// we might enter control packet queue several times for the same package,
@@ -637,9 +624,9 @@ SocketSentBytes CEMSocket::Send(uint32 maxNumberOfBytesToSend, uint32 minFragSiz
 	}
 
 	//printf("* Finishing send debug on %p\n",this);
-	
+
 	SocketSentBytes returnVal = { !anErrorHasOccured, sentStandardPacketBytesThisCall, sentControlPacketBytesThisCall };
-	
+
     return returnVal;
 }
 
@@ -656,7 +643,7 @@ uint32 CEMSocket::GetNextFragSize(uint32 current, uint32 minFragSize)
 
 /**
  * Decides the (minimum) amount the socket needs to send to prevent timeout.
- * 
+ *
  * @author SlugFiller
  */
 uint32 CEMSocket::GetNeededBytes()
@@ -673,17 +660,17 @@ uint32 CEMSocket::GetNeededBytes()
 		if (byConnected == ES_DISCONNECTED) {
 			return 0;
 		}
-	
+
 		if (!((sendbuffer && !m_currentPacket_is_controlpacket) || !m_standard_queue.empty())) {
 			// No standard packet to send. Even if data needs to be sent to prevent timout, there's nothing to send.
 			return 0;
 		}
-	
+
 		if (((sendbuffer && !m_currentPacket_is_controlpacket)) && !m_control_queue.empty())
 			m_bAccelerateUpload = true;	// We might be trying to send a block request, accelerate packet
-	
+
 		sendgap = ::GetTickCount() - lastCalledSend;
-	
+
 		timetotal = m_bAccelerateUpload?45000:90000;
 		timeleft = ::GetTickCount() - lastFinishedStandard;
 		if (sendbuffer && !m_currentPacket_is_controlpacket) {
@@ -732,7 +719,7 @@ void CEMSocket::TruncateQueues()
 	for (; it != m_standard_queue.end(); ++it) {
 		delete it->packet;
 	}
-	
+
 	m_standard_queue.clear();
 }
 
