@@ -16,7 +16,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -26,9 +26,10 @@
 
 #ifdef HAVE_CONFIG_H
 	#include "config.h"	// Needed for VERSION and readline detection
+#else
+	#include <common/ClientVersion.h>
 #endif
 
-#include <common/ClientVersion.h>
 #include <common/Format.h>		// Needed for CFormat
 #include <wx/tokenzr.h>		// For wxStringTokenizer
 
@@ -61,6 +62,8 @@
 
 #include <ec/cpp/ECFileConfig.h>	// Needed for CECFileConfig
 #include <common/MD5Sum.h>
+#include "OtherFunctions.h"		// Needed for GetPassword()
+#include "MuleVersion.h"		// Needed for GetMuleVersion()
 
 #ifdef _MSC_VER  // silly warnings about deprecated functions
 #pragma warning(disable:4996)
@@ -195,10 +198,12 @@ void CCommandTree::PrintHelpFor(const wxString& command) const
 CaMuleExternalConnector::CaMuleExternalConnector()
 	: m_configFile(NULL),
 	  m_port(-1),
+	  m_ZLIB(false),
 	  m_KeepQuiet(false),
 	  m_Verbose(false),
 	  m_interactive(false),
 	  m_commands(*this),
+	  m_appname(NULL),
 	  m_ECClient(NULL),
 	  m_InputLine(NULL),
 	  m_NeedsConfigSave(false),
@@ -231,7 +236,7 @@ void CaMuleExternalConnector::Show(const wxString &s)
 {
 	if( !m_KeepQuiet ) {
 		printf("%s", (const char *)unicode2char(s));
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
 		fflush(stdout);
 #endif
 	}
@@ -308,7 +313,7 @@ void CaMuleExternalConnector::GetCommand(const wxString &prompt, char* buffer, s
 {
 #ifdef HAVE_LIBREADLINE
 		char *text = readline(unicode2char(prompt + wxT("$ ")));
-		if (text && *text && 
+		if (text && *text &&
 		    (m_InputLine == 0 || strcmp(text,m_InputLine) != 0)) {
 		  add_history (text);
 		}
@@ -361,29 +366,13 @@ void CaMuleExternalConnector::ConnectAndRun(const wxString &ProgName, const wxSt
 
 	// HostName, Port and Password
 	if ( m_password.IsEmpty() ) {
-		wxString pass_plain;
-		#ifndef __WXMSW__
-			pass_plain = char2unicode(getpass("Enter password for mule connection: "));
-		#else
-			//#warning This way, pass enter is not hidden on windows. Bad thing.
-			char temp_str[512];
-			fflush(stdin);
-			printf("Enter password for mule connection: \n");
-			fflush(stdout);
-			fgets(temp_str, 512, stdin);
-			temp_str[strlen(temp_str)-1] = '\0';
-			pass_plain = char2unicode(temp_str);
-		#endif
-		wxCHECK2(m_password.Decode(MD5Sum(pass_plain).GetHash()), /* Do nothing. */ );
+		m_password = GetPassword(true);
 		// MD5 hash for an empty string, according to rfc1321.
 		if (m_password.Encode() == wxT("D41D8CD98F00B204E9800998ECF8427E")) {
 			m_password.Clear();
 		}
-
-		// Clear plain-text password
-		pass_plain		= wxT("01234567890123456789");
 	}
-	
+
 	if (!m_password.IsEmpty()) {
 
 		// Create the socket
@@ -468,8 +457,10 @@ bool CaMuleExternalConnector::OnCmdLineParsed(wxCmdLineParser& parser)
 	}
 
 	if (!parser.Found(wxT("config-file"), &m_configFileName)) {
-		m_configFileName = GetConfigDir() + wxT("remote.conf");
+		m_configFileName = wxT("remote.conf");
 	}
+	m_configDir = GetConfigDir(m_configFileName);
+	m_configFileName = m_configDir + m_configFileName;
 
 	wxString aMuleConfigFile;
 	if (parser.Found(wxT("create-config-from"), &aMuleConfigFile)) {
@@ -549,8 +540,8 @@ void CaMuleExternalConnector::LoadConfigFile()
 
 void CaMuleExternalConnector::SaveConfigFile()
 {
-	if (!wxFileName::DirExists(GetConfigDir())) {
-		wxFileName::Mkdir(GetConfigDir());
+	if (!wxFileName::DirExists(m_configDir)) {
+		wxFileName::Mkdir(m_configDir);
 	}
 	if (!m_configFile) {
 		m_configFile = new CECFileConfig(m_configFileName);
@@ -565,13 +556,17 @@ void CaMuleExternalConnector::SaveConfigFile()
 
 bool CaMuleExternalConnector::OnInit()
 {
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	#if wxUSE_ON_FATAL_EXCEPTION
 		// catch fatal exceptions
 		wxHandleFatalExceptions(true);
 	#endif
 #endif
 
+	// If we didn't know that OnInit is called only once when creating the
+	// object, it could cause a memory leak. The two pointers below should
+	// be free()'d before assigning the new value.
+	// cppcheck-suppress publicAllocationError
 	m_strFullVersion = strdup((const char *)unicode2char(GetMuleVersion()));
 	m_strOSDescription = strdup((const char *)unicode2char(wxGetOsDescription()));
 
@@ -630,21 +625,21 @@ wxAppTraits* CaMuleExternalConnector::CreateTraits()
 void CaMuleExternalConnector::OnFatalException()
 {
 	/* Print the backtrace */
-	fprintf(stderr, "\n--------------------------------------------------------------------------------\n");	
+	fprintf(stderr, "\n--------------------------------------------------------------------------------\n");
 	fprintf(stderr, "A fatal error has occurred and %s has crashed.\n", m_appname);
 	fprintf(stderr, "Please assist us in fixing this problem by posting the backtrace below in our\n");
 	fprintf(stderr, "'aMule Crashes' forum and include as much information as possible regarding the\n");
 	fprintf(stderr, "circumstances of this crash. The forum is located here:\n");
 	fprintf(stderr, "    http://forum.amule.org/index.php?board=67.0\n");
 	fprintf(stderr, "If possible, please try to generate a real backtrace of this crash:\n");
-	fprintf(stderr, "    http://wiki.amule.org/index.php/Backtraces\n\n");
+	fprintf(stderr, "    http://wiki.amule.org/wiki/Backtraces\n\n");
 	fprintf(stderr, "----------------------------=| BACKTRACE FOLLOWS: |=----------------------------\n");
 	fprintf(stderr, "Current version is: %s %s\n", m_appname, m_strFullVersion);
 	fprintf(stderr, "Running on: %s\n\n", m_strOSDescription);
-	
+
 	print_backtrace(1); // 1 == skip this function.
-	
-	fprintf(stderr, "\n--------------------------------------------------------------------------------\n");	
+
+	fprintf(stderr, "\n--------------------------------------------------------------------------------\n");
 }
 #endif
 
