@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -28,24 +28,25 @@
 
 #include <wx/panel.h>		// Needed for wxPanel
 
-class COScopeCtrl;	
+class COScopeCtrl;
 class wxListEvent;
 class wxCommandEvent;
 class wxMouseEvent;
 typedef struct UpdateInfo GraphUpdateInfo;
-	
+
 
 class CKadDlg : public wxPanel
 {
 public:
-	CKadDlg(wxWindow* pParent);   
+	CKadDlg(wxWindow* pParent);
 	~CKadDlg() {};
-	
+
 	void Init();
 	void SetUpdatePeriod(int step);
 	void SetGraphColors();
 	void UpdateGraph(const GraphUpdateInfo& update);
-		
+	void UpdateNodeCount(unsigned nodes);
+
 private:
 	COScopeCtrl* m_kad_scope;
 
