@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -36,12 +36,13 @@ DEFINE_LOCAL_EVENT_TYPE(wxEVT_COMMAND_MULENOTEBOOK_ALL_PAGES_CLOSED)
 BEGIN_EVENT_TABLE(CMuleNotebook, wxNotebook)
 	EVT_RIGHT_DOWN(CMuleNotebook::OnRMButton)
 
-	EVT_MENU(MP_CLOSE_TAB,			CMuleNotebook::OnPopupClose)
-	EVT_MENU(MP_CLOSE_ALL_TABS,		CMuleNotebook::OnPopupCloseAll)
-	EVT_MENU(MP_CLOSE_OTHER_TABS,	CMuleNotebook::OnPopupCloseOthers)	
-	
+	EVT_MENU(MP_CLOSE_TAB,		CMuleNotebook::OnPopupClose)
+	EVT_MENU(MP_CLOSE_ALL_TABS,	CMuleNotebook::OnPopupCloseAll)
+	EVT_MENU(MP_CLOSE_OTHER_TABS,	CMuleNotebook::OnPopupCloseOthers)
+
 	// Madcat - tab closing engine
-	EVT_LEFT_UP(CMuleNotebook::OnMouseLeftRelease)
+	EVT_LEFT_UP(CMuleNotebook::OnMouseButtonRelease)
+	EVT_MIDDLE_UP(CMuleNotebook::OnMouseButtonRelease)
 	EVT_MOTION(CMuleNotebook::OnMouseMotion)
 END_EVENT_TABLE()
 
@@ -79,7 +80,7 @@ bool CMuleNotebook::DeletePage(int nPage)
 	}
 
 	// Send a page change event to work around wx problem when newly selected page
-	// is identical with deleted page (wx sends a page change event during deletion, 
+	// is identical with deleted page (wx sends a page change event during deletion,
 	// but the control is still the one to be deleted at that moment).
 	if (GetPageCount()) {
 		// Select the tab that took the place of the one we just deleted.
@@ -110,9 +111,9 @@ bool CMuleNotebook::DeleteAllPages()
 	while ( GetPageCount() ) {
 		result &= DeletePage( 0 );
 	}
-	
+
 	Thaw();
-		
+
 	return result;
 }
 
@@ -153,15 +154,15 @@ void CMuleNotebook::OnRMButton(wxMouseEvent& event)
 	// Should we send the event to a specific widget?
 	if ( m_popup_widget ) {
 		wxMouseEvent evt = event;
-	
+
 		// Map the coordinates onto the parent
 		wxPoint point = evt.GetPosition();
 		point = ClientToScreen( point );
 		point = m_popup_widget->ScreenToClient( point );
-			
+
 		evt.m_x = point.x;
 		evt.m_y = point.y;
-			
+
 		m_popup_widget->GetEventHandler()->AddPendingEvent( evt );
 	} else {
 		wxMenu menu(_("Close"));
@@ -189,7 +190,7 @@ void CMuleNotebook::OnPopupCloseAll(wxCommandEvent& WXUNUSED(evt))
 void CMuleNotebook::OnPopupCloseOthers(wxCommandEvent& WXUNUSED(evt))
 {
 	wxNotebookPage* current = GetPage( GetSelection() );
-	
+
 	for ( int i = GetPageCount() - 1; i >= 0; i-- ) {
 		if ( current != GetPage( i ) )
 			DeletePage( i );
@@ -197,29 +198,30 @@ void CMuleNotebook::OnPopupCloseOthers(wxCommandEvent& WXUNUSED(evt))
 }
 
 
-void CMuleNotebook::OnMouseLeftRelease(wxMouseEvent &event)
+void CMuleNotebook::OnMouseButtonRelease(wxMouseEvent &event)
 {
 
 	if (GetImageList() == NULL) {
 		// This Mulenotebook has no images on tabs, so nothing to do.
 		event.Skip();
-		return; 
+		return;
 	}
 
 	long xpos, ypos;
 	event.GetPosition(&xpos, &ypos);
-	
+
 	long flags = 0;
-	int tab = HitTest(wxPoint(xpos,ypos),&flags);	
-	
-	if ((tab != -1) &&  (flags == wxNB_HITTEST_ONICON)) {
-		// User did click on a 'x'
+	int tab = HitTest(wxPoint(xpos,ypos),&flags);
+
+	if ((tab != -1) &&  (((flags == wxNB_HITTEST_ONICON) && event.LeftUp()) ||
+			((flags == wxNB_HITTEST_ONLABEL) && event.MiddleUp()))) {
+		// User did click on a 'x' or middle click on the label
 		DeletePage(tab);
 	} else {
 		// Is not a 'x'. Send this event up.
 		event.Skip();
 	}
-	
+
 }
 
 void CMuleNotebook::OnMouseMotion(wxMouseEvent &event)
@@ -230,18 +232,18 @@ void CMuleNotebook::OnMouseMotion(wxMouseEvent &event)
 		event.Skip();
 		return;
 	}
-	
+
 	long flags = 0;
-	int tab = HitTest(wxPoint(event.m_x,event.m_y),&flags);	
+	int tab = HitTest(wxPoint(event.m_x,event.m_y),&flags);
 
 	// Clear the highlight for all tabs.
 	for (int i=0;i<(int)GetPageCount();++i) {
 		SetPageImage(i, 0);
 	}
-	
+
 	if ((tab != -1) &&  (flags == wxNB_HITTEST_ONICON)) {
 		// Mouse is over a 'x'
-		SetPageImage(tab, 1);		
+		SetPageImage(tab, 1);
 	} else {
 		// Is not a 'x'. Send this event up.
 		event.Skip();
