@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -30,6 +30,7 @@
 
 #include "Types.h"		// Needed for uint16, uint32 and uint64
 #include "Preferences.h"	// Needed for AllCategoryFilter enumeration
+#include "MD4Hash.h"		// Needed for CMD4Hash
 
 #include <algorithm>		// Needed for std::for_each	// Do_not_auto_remove (mingw-gcc-3.4.5)
 
@@ -44,9 +45,9 @@ class CPath;
  * @param ArgB The value to compare ArgA against.
  * @return See below.
  *
- * Use this function to safely compare two arguments of a type that supports 
+ * Use this function to safely compare two arguments of a type that supports
  * the "<" operator. It works like strcmp and returns a negative value if ArgA
- * is less than ArgB, zero if ArgA is equal to ArgB and a positive value if 
+ * is less than ArgB, zero if ArgA is equal to ArgB and a positive value if
  * ArgA is greater than ArgB.
  */
 template <class TYPE>
@@ -97,7 +98,7 @@ unsigned int EraseFirstValue( LIST& list, const ITEM& item )
 	for (; it != list.end(); ++it) {
 		if (*it == item) {
 			list.erase(it);
-			
+
 			return true;
 		}
 	}
@@ -145,7 +146,7 @@ struct SDoDelete
 	template <typename FIRST, typename SECOND>
 	void operator()(const std::pair<FIRST, SECOND>& pair) {
 		delete pair.second;
-	}		
+	}
 };
 
 
@@ -156,7 +157,7 @@ void DeleteContents(STL_CONTAINER& container)
 	// Ensure that the actual container wont contain dangling pointers during
 	// this operation, to ensure that the destructors cant access them.
 	STL_CONTAINER copy;
-	
+
 	std::swap(copy, container);
 	std::for_each(copy.begin(), copy.end(), SDoDelete());
 }
@@ -172,18 +173,6 @@ OutputIterator STLCopy_n(InputIterator first, size_t n, OutputIterator result)
 }
 
 
-/**
- * Returns a description of the version of aMule being used.
- *
- * @return A detailed description of the aMule version, including wx information.
- *
- * Use this rather than just using the VERSION or CURRENT_VERSION_LONG
- * constants, when displaying information to the user. The purpose is to
- * help with debugging.
- */
-wxString GetMuleVersion();
-
-
 /**
  * Helperfunction for accessing a child of the calling widget.
  *
@@ -196,7 +185,7 @@ wxString GetMuleVersion();
  *
  * It has the advantage of validating the cast in debug builds and being much
  * shorter than than manually typing wxStaticCast + FindWindow. This mean that
- * we will be alerted in case of widget changing type, instead of getting just 
+ * we will be alerted in case of widget changing type, instead of getting just
  * getting bad mojo due to casting a pointer to the wrong type.
  */
 #define CastChild( IdOrName, type )			dynamic_cast<type*>( FindWindow( IdOrName ) )
@@ -262,12 +251,6 @@ wxString GetFiletypeByName(const CPath& filename, bool translated = true);
 // Returns the name associated with a category value.
 wxString GetCatTitle(AllCategoryFilter cat);
 
-/* Other */
-
-
-//! Returns the number of items in an array.
-#define itemsof(x) (sizeof(x)/sizeof(x[0]))
-
 
 ///////////////////////////////////////////////////////////////////////////////
 // ED2K File Type
@@ -300,7 +283,7 @@ public:
 	{
 		return s_t;
 	}
-	
+
 private:
 	EED2KFileType s_t;
 };
@@ -353,7 +336,7 @@ inline long int make_full_ed2k_version(int a, int b, int c) {
 }
 
 
-wxString GetConfigDir(const wxString &configFile = wxT("amule.conf"));
+wxString GetConfigDir(const wxString &configFile);
 
 #if !wxCHECK_VERSION(2, 9, 0)
 enum {
@@ -384,7 +367,7 @@ wxString wxLang2Str(const int lang);
 /**
  * Generate MD5Hash of prompt input
  */
-wxString GetPassword();
+CMD4Hash GetPassword(bool allowEmptyPassword = false);
 
 
 #if wxUSE_THREADS
