@@ -79,6 +79,7 @@ unsigned long		CPreferences::s_colors_ref[cntStatColors];
 CPreferences::CFGMap	CPreferences::s_CfgList;
 CPreferences::CFGList	CPreferences::s_MiscList;
 
+wxString	CPreferences::s_configDir;
 
 /* Proxy */
 CProxyData	CPreferences::s_ProxyData;
@@ -143,6 +144,7 @@ bool		CPreferences::s_checkDiskspace;
 uint32		CPreferences::s_uMinFreeDiskSpace;
 wxString	CPreferences::s_yourHostname;
 bool		CPreferences::s_bVerbose;
+bool		CPreferences::s_bVerboseLogfile;
 bool		CPreferences::s_bmanualhighprio;
 bool		CPreferences::s_bstartnextfile;
 bool		CPreferences::s_bstartnextfilesame;
@@ -161,7 +163,7 @@ bool		CPreferences::s_msgsecure;
 uint8		CPreferences::s_filterlevel;
 uint8		CPreferences::s_iFileBufferSize;
 uint8		CPreferences::s_iQueueSize;
-wxString 	CPreferences::s_datetimeformat;
+wxString	CPreferences::s_datetimeformat;
 wxString	CPreferences::s_sWebPath;
 wxString	CPreferences::s_sWebPassword;
 wxString	CPreferences::s_sWebLowPassword;
@@ -174,12 +176,7 @@ bool		CPreferences::s_bWebLowEnabled;
 wxString	CPreferences::s_WebTemplate;
 bool		CPreferences::s_showCatTabInfos;
 AllCategoryFilter CPreferences::s_allcatFilter;
-uint8		CPreferences::s_NoNeededSources;
-bool		CPreferences::s_DropFullQueueSources;
-bool		CPreferences::s_DropHighQueueRankingSources;
-uint32		CPreferences::s_HighQueueRanking;
-uint32		CPreferences::s_AutoDropTimer;
-bool 		CPreferences::s_AcceptExternalConnections;
+bool		CPreferences::s_AcceptExternalConnections;
 wxString	CPreferences::s_ECAddr;
 uint32		CPreferences::s_ECPort;
 wxString	CPreferences::s_ECPassword;
@@ -192,6 +189,7 @@ bool		CPreferences::s_Percent;
 bool		CPreferences::s_SecIdent;
 bool		CPreferences::s_ExtractMetaData;
 bool		CPreferences::s_allocFullFile;
+bool		CPreferences::s_createFilesSparse;
 wxString	CPreferences::s_CustomBrowser;
 bool		CPreferences::s_BrowserTab;
 CPath		CPreferences::s_OSDirectory;
@@ -199,14 +197,14 @@ wxString	CPreferences::s_Skin;
 bool		CPreferences::s_FastED2KLinksHandler;
 bool		CPreferences::s_ToolbarOrientation;
 bool		CPreferences::s_AICHTrustEveryHash;
-wxString 	CPreferences::s_CommentFilterString;
+wxString	CPreferences::s_CommentFilterString;
 bool		CPreferences::s_IPFilterAutoLoad;
 wxString	CPreferences::s_IPFilterURL;
 CMD4Hash	CPreferences::s_userhash;
 bool		CPreferences::s_MustFilterMessages;
-wxString 	CPreferences::s_MessageFilterString;
+wxString	CPreferences::s_MessageFilterString;
 bool		CPreferences::s_FilterAllMessages;
-bool 		CPreferences::s_FilterComments;
+bool		CPreferences::s_FilterComments;
 bool		CPreferences::s_FilterSomeMessages;
 bool		CPreferences::s_ShowMessagesInLog;
 bool		CPreferences::s_IsAdvancedSpamfilterEnabled;
@@ -224,13 +222,13 @@ bool		CPreferences::s_IsClientCryptLayerRequired;
 uint32		CPreferences::s_dwKadUDPKey;
 uint8		CPreferences::s_byCryptTCPPaddingLength;
 
-wxString 	CPreferences::s_Ed2kURL;
-wxString 	CPreferences::s_KadURL;
-bool	 	CPreferences::s_GeoIPEnabled;
-wxString 	CPreferences::s_GeoIPUpdateUrl;
+wxString	CPreferences::s_Ed2kURL;
+wxString	CPreferences::s_KadURL;
+bool		CPreferences::s_GeoIPEnabled;
+wxString	CPreferences::s_GeoIPUpdateUrl;
 bool		CPreferences::s_preventSleepWhileDownloading;
-wxString 	CPreferences::s_StatsServerName;
-wxString 	CPreferences::s_StatsServerURL;
+wxString	CPreferences::s_StatsServerName;
+wxString	CPreferences::s_StatsServerURL;
 
 /**
  * Template Cfg class for connecting with widgets.
@@ -658,6 +656,7 @@ static LangInfo aMuleLanguages[] = {
 	{ wxLANGUAGE_POLISH,				false,	wxEmptyString,	wxTRANSLATE("Polish") },
 	{ wxLANGUAGE_PORTUGUESE,			false,	wxEmptyString,	wxTRANSLATE("Portuguese") },
 	{ wxLANGUAGE_PORTUGUESE_BRAZILIAN,	false,	wxEmptyString,	wxTRANSLATE("Portuguese (Brazilian)") },
+	{ wxLANGUAGE_ROMANIAN,				false,	wxEmptyString,	wxTRANSLATE("Romanian") },
 	{ wxLANGUAGE_RUSSIAN,				false,	wxEmptyString,	wxTRANSLATE("Russian") },
 	{ wxLANGUAGE_SLOVENIAN,				false,	wxEmptyString,	wxTRANSLATE("Slovenian") },
 	{ wxLANGUAGE_SPANISH,				false,	wxEmptyString,	wxTRANSLATE("Spanish") },
@@ -672,6 +671,7 @@ typedef Cfg_Int<int> Cfg_PureInt;
 class Cfg_Lang : public Cfg_PureInt, public Cfg_Lang_Base
 {
 public:
+	// cppcheck-suppress uninitMemberVar m_selection, m_langSelector
 	Cfg_Lang()
 		: Cfg_PureInt( wxEmptyString, m_selection, 0 )
 	{
@@ -746,7 +746,7 @@ public:
 			for (unsigned int i = 1; i < itemsof(aMuleLanguages); ++i) {
 				if ((aMuleLanguages[i].id > wxLANGUAGE_USER_DEFINED) || wxLocale::IsAvailable(aMuleLanguages[i].id)) {
 					wxLogNull	logTarget;
-					wxLocale 	locale_to_check;
+					wxLocale	locale_to_check;
 					InitLocale(locale_to_check, aMuleLanguages[i].id);
 					if (locale_to_check.IsOk() && locale_to_check.IsLoaded(wxT(PACKAGE))) {
 						aMuleLanguages[i].displayname = wxString(wxGetTranslation(aMuleLanguages[i].name)) + wxT(" [") + aMuleLanguages[i].name + wxT("]");
@@ -850,7 +850,7 @@ public:
 		} else {
 			folder = wxT("webserver");
 		}
-		wxString dirName(JoinPaths(GetConfigDir(theApp->m_configFile), folder));
+		wxString dirName(JoinPaths(thePrefs::GetConfigDir(), folder));
 		wxString Filename;
 		wxDir d;
 
@@ -875,7 +875,7 @@ public:
 		} else {
 			dataDir = wxStandardPaths::Get().GetResourcesDir();
 		}
-#if !defined(__WXMSW__) && !defined(__WXMAC__)
+#if !defined(__WINDOWS__) && !defined(__WXMAC__)
 		dataDir = dataDir.BeforeLast(wxT('/')) + wxT("/amule");
 #endif
 		wxString systemDir(JoinPaths(dataDir,folder));
@@ -926,7 +926,7 @@ CPreferences::CPreferences()
 	srand( wxGetLocalTimeMillis().GetLo() ); // we need random numbers sometimes
 
 	// load preferences.dat or set standard values
-	wxString fullpath(theApp->ConfigDir + wxT("preferences.dat"));
+	wxString fullpath(s_configDir + wxT("preferences.dat"));
 	CFile preffile;
 	if (wxFileExists(fullpath)) {
 		if (preffile.Open(fullpath, CFile::read)) {
@@ -959,7 +959,7 @@ CPreferences::CPreferences()
 
 	// serverlist adresses
 	CTextFile slistfile;
-	if (slistfile.Open(theApp->ConfigDir + wxT("addresses.dat"), CTextFile::read)) {
+	if (slistfile.Open(s_configDir + wxT("addresses.dat"), CTextFile::read)) {
 		adresses_list = slistfile.ReadLines();
 	}
 #endif
@@ -1011,6 +1011,7 @@ void CPreferences::BuildItemList( const wxString& appdir )
 	 * Debugging
 	 **/
 	NewCfgItem(ID_VERBOSEDEBUG, (new Cfg_Bool( wxT("/eMule/VerboseDebug"), s_bVerbose, false )));
+	NewCfgItem(ID_VERBOSEDEBUGLOGFILE, (new Cfg_Bool( wxT("/eMule/VerboseDebugLogfile"), s_bVerboseLogfile, false )));
 #endif
 
 	/**
@@ -1065,9 +1066,9 @@ void CPreferences::BuildItemList( const wxString& appdir )
 	/**
 	 * Files
 	 **/
-	NewCfgItem(IDC_TEMPFILES,	(new Cfg_Path(  wxT("/eMule/TempDir"), 	s_tempdir, appdir + wxT("Temp") )));
+	NewCfgItem(IDC_TEMPFILES,	(new Cfg_Path(  wxT("/eMule/TempDir"),	s_tempdir, appdir + wxT("Temp") )));
 
-	#if defined(__WXMAC__) || defined(__WXMSW__)
+	#if defined(__WXMAC__) || defined(__WINDOWS__)
 		wxString incpath = wxStandardPaths::Get().GetDocumentsDir();
 		if (incpath.IsEmpty()) {
 			// There is a built-in possibility for this call to fail, though I can't imagine a reason for that.
@@ -1242,10 +1243,10 @@ void CPreferences::BuildItemList( const wxString& appdir )
 
 	s_MiscList.push_back( MkCfg_Int( wxT("/eMule/SmartIdState"), s_smartidstate, 0 ) );
 
-	s_MiscList.push_back( new Cfg_Bool( wxT("/eMule/DropSlowSources"), 		s_DropSlowSources, false ) );
+	s_MiscList.push_back( new Cfg_Bool( wxT("/eMule/DropSlowSources"),		s_DropSlowSources, false ) );
 
-	s_MiscList.push_back( new Cfg_Str(  wxT("/eMule/KadNodesUrl"),			s_KadURL, wxT("http://download.tuxfamily.org/technosalad/utils/nodes.dat") ) );
-	s_MiscList.push_back( new Cfg_Str(  wxT("/eMule/Ed2kServersUrl"),		s_Ed2kURL, wxT("http://gruk.org/server.met.gz") ) );
+	s_MiscList.push_back( new Cfg_Str(  wxT("/eMule/KadNodesUrl"),			s_KadURL, wxT("http://upd.emule-security.org/nodes.dat") ) );
+	s_MiscList.push_back( new Cfg_Str(	wxT("/eMule/Ed2kServersUrl"),		s_Ed2kURL, wxT("http://upd.emule-security.org/server.met") ) );
 	s_MiscList.push_back( MkCfg_Int( wxT("/eMule/ShowRatesOnTitle"),		s_showRatesOnTitle, 0 ));
 
 	s_MiscList.push_back( new Cfg_Str(  wxT("/eMule/GeoLiteCountryUpdateUrl"),		s_GeoIPUpdateUrl, wxT("http://geolite.maxmind.com/download/geoip/database/GeoLiteCountry/GeoIP.dat.gz") ) );
@@ -1257,6 +1258,7 @@ void CPreferences::BuildItemList( const wxString& appdir )
 	s_MiscList.push_back( new Cfg_Str( wxT("/eMule/StatsServerURL"),		s_StatsServerURL,	wxT("http://ed2k.shortypower.dyndns.org/?hash=") ) );
 
 	s_MiscList.push_back( new Cfg_Bool( wxT("/ExternalConnect/TransmitOnlyUploadingClients"),	s_TransmitOnlyUploadingClients, false ) );
+	s_MiscList.push_back( new Cfg_Bool( wxT("/eMule/CreateSparseFiles"),		s_createFilesSparse, true ) );
 
 #ifndef AMULE_DAEMON
 	// Colors have been moved from global prefs to CStatisticsDlg
@@ -1452,7 +1454,7 @@ void CPreferences::CheckUlDlRatio()
 
 void CPreferences::Save()
 {
-	wxString fullpath(theApp->ConfigDir + wxT("preferences.dat"));
+	wxString fullpath(s_configDir + wxT("preferences.dat"));
 
 	CFile preffile;
 	if (!wxFileExists(fullpath)) {
@@ -1472,9 +1474,9 @@ void CPreferences::Save()
 
 	#ifndef CLIENT_GUI
 	CTextFile sdirfile;
-	if (sdirfile.Open(theApp->ConfigDir + wxT("shareddir.dat"), CTextFile::write)) {
+	if (sdirfile.Open(s_configDir + wxT("shareddir.dat"), CTextFile::write)) {
 		for (size_t i = 0; i < shareddir_list.size(); ++i) {
-			sdirfile.WriteLine(CPath::ToUniv(shareddir_list[i]), wxConvUTF8);
+			sdirfile.WriteLine(shareddir_list[i].GetRaw(), wxConvUTF8);
 		}
 
 	}
@@ -1705,7 +1707,7 @@ bool CPreferences::UpdateCategory(
 wxString CPreferences::GetBrowser()
 {
 	wxString cmd(s_CustomBrowser);
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	if( s_BrowserTab ) {
 		// This is certainly not the best way to do it, but I'm lazy
 		if ((wxT("mozilla") == cmd.Right(7)) || (wxT("firefox") == cmd.Right(7))
@@ -1722,7 +1724,7 @@ wxString CPreferences::GetBrowser()
 			cmd += wxT(" -remote 'openURLs(%s,new-tab)'");
 		}
 	}
-#endif /* !__WXMSW__ */
+#endif /* !__WINDOWS__ */
 	return cmd;
 }
 
@@ -1778,16 +1780,16 @@ void CPreferences::ReloadSharedFolders()
 	shareddir_list.clear();
 
 	CTextFile file;
-	if (file.Open(theApp->ConfigDir + wxT("shareddir.dat"), CTextFile::read)) {
+	if (file.Open(s_configDir + wxT("shareddir.dat"), CTextFile::read)) {
 		wxArrayString lines = file.ReadLines(txtReadDefault, wxConvUTF8);
 
 		for (size_t i = 0; i < lines.size(); ++i) {
-			CPath path = CPath::FromUniv(lines[i]);
+			CPath path(lines[i]);
 
 			if (path.DirExists()) {
 				shareddir_list.push_back(path);
 			} else {
-				AddLogLineN(CFormat(_("Dropping non-existing shared directory: %s")) % path.GetRaw());
+				AddLogLineN(CFormat(_("Dropping non-existing shared directory: %s")) % path.GetPrintable());
 			}
 		}
 	}
