@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -48,18 +48,17 @@
 #include <common/Format.h>
 #include "IPFilter.h"
 #include "GuiEvents.h"		// Needed for Notify_*
+#ifdef ASIO_SOCKETS
+#	include <boost/system/error_code.hpp>
+#endif
 
 
+#ifndef ASIO_SOCKETS
 
 //------------------------------------------------------------------------------
 // CServerSocketHandler
 //------------------------------------------------------------------------------
 
-//------------------------------------------------------------------------------
-// CServerSocketHandler
-//------------------------------------------------------------------------------
-
-
 class CServerSocketHandler: public wxEvtHandler
 {
 public:
@@ -84,10 +83,10 @@ void CServerSocketHandler::ServerSocketHandler(wxSocketEvent& event)
 		return;
 	}
 
-	if (socket->OnDestroy()) {
+	if (socket->IsDestroying()) {
 		return;
 	}
-	
+
 	switch(event.GetSocketEvent()) {
 		case wxSOCKET_CONNECTION:
 			socket->OnConnect(wxSOCKET_NOERROR);
@@ -105,8 +104,8 @@ void CServerSocketHandler::ServerSocketHandler(wxSocketEvent& event)
 			wxFAIL;
 			break;
 	}
-	
-	
+
+
 }
 
 //
@@ -114,6 +113,8 @@ void CServerSocketHandler::ServerSocketHandler(wxSocketEvent& event)
 //
 static CServerSocketHandler g_serverSocketHandler;
 
+#endif /* !ASIO_SOCKETS */
+
 
 //------------------------------------------------------------------------------
 // CServerSocket
@@ -129,26 +130,30 @@ CEMSocket(ProxyData)
 	info.Clear();
 	m_bIsDeleting = false;
 
+#ifndef ASIO_SOCKETS
 	SetEventHandler(g_serverSocketHandler, ID_SERVERSOCKET_EVENT);
-	
+
 	SetNotify(
 		wxSOCKET_CONNECTION_FLAG |
 		wxSOCKET_INPUT_FLAG |
 		wxSOCKET_OUTPUT_FLAG |
 		wxSOCKET_LOST_FLAG);
+#endif
 	Notify(true);
 
-	m_dwLastTransmission = 0;	
+	m_dwLastTransmission = 0;
 	m_IsSolving = false;
 	m_bNoCrypt = false;
 }
 
 CServerSocket::~CServerSocket()
 {
+#ifndef ASIO_SOCKETS
 	// remove event handler...
 	SetNotify(0);
 	Notify(FALSE);
-	
+#endif
+
 	if (cur_server) {
 		delete cur_server;
 	}
@@ -156,14 +161,16 @@ CServerSocket::~CServerSocket()
 }
 
 
-void CServerSocket::OnConnect(wxSocketError nErrorCode)
+void CServerSocket::OnConnect(int nErrorCode)
 {
 	switch (nErrorCode) {
+#ifdef ASIO_SOCKETS
+		case boost::system::errc::success:
+#else
 		case wxSOCKET_NOERROR:
+#endif
 			if (cur_server->HasDynIP()) {
-				amuleIPV4Address tmpaddr;
-				GetPeer(tmpaddr);
-				uint32 server_ip = StringIPtoUint32(tmpaddr.IPAddress());
+				uint32 server_ip = GetPeerInt();
 				cur_server->SetID(server_ip);
 				// GetServerByAddress may return NULL, so we must test!
 				// This was the reason why amule would crash when trying to
@@ -180,35 +187,42 @@ void CServerSocket::OnConnect(wxSocketError nErrorCode)
 			SetConnectionState(CS_WAITFORLOGIN);
 			break;
 
+#ifdef ASIO_SOCKETS
+		case boost::system::errc::address_in_use:
+		case boost::system::errc::address_not_available:
+		case boost::system::errc::bad_address:
+		case boost::system::errc::connection_refused:
+		case boost::system::errc::host_unreachable:
+		case boost::system::errc::invalid_argument:
+		case boost::system::errc::timed_out:
+#else
 		case wxSOCKET_INVADDR:
 		case wxSOCKET_NOHOST:
 		case wxSOCKET_INVPORT:
 		case wxSOCKET_TIMEDOUT:
+#endif
 			m_bIsDeleting = true;
 			SetConnectionState(CS_SERVERDEAD);
 			serverconnect->DestroySocket(this);
 			return;
-		
-		case wxSOCKET_IOERR:
-		case wxSOCKET_MEMERR:
-		case wxSOCKET_INVOP:
+
 		default:
 			m_bIsDeleting = true;
 			SetConnectionState(CS_FATALERROR);
 			serverconnect->DestroySocket(this);
 			return;
-		
+
 	}
-	
+
 }
 
-void CServerSocket::OnReceive(wxSocketError nErrorCode)
+void CServerSocket::OnReceive(int nErrorCode)
 {
 	if (connectionstate != CS_CONNECTED && !serverconnect->IsConnecting()) {
 		serverconnect->DestroySocket(this);
 		return;
 	}
-	CEMSocket::OnReceive((int)nErrorCode);
+	CEMSocket::OnReceive(nErrorCode);
 	m_dwLastTransmission = GetTickCount();
 }
 
@@ -216,12 +230,12 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 {
 	try {
 		AddDebugLogLineN( logServer, wxT("Processing Server Packet: ") );
-		
+
 		switch(opcode) {
 			case OP_SERVERMESSAGE: {
 				/* Kry import of lugdunum 16.40 new features */
 				AddDebugLogLineN( logServer, wxT("Server: OP_SERVERMESSAGE") );
-				
+
 				theStats::AddDownOverheadServer(size);
 				char* buffer = new char[size-1];
 				memcpy(buffer,&packet[2],size-2);
@@ -230,7 +244,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 				wxString strMessages(char2unicode(buffer));
 
 				delete[] buffer;
-				
+
 				// 16.40 servers do not send separate OP_SERVERMESSAGE packets for each line;
 				// instead of this they are sending all text lines with one OP_SERVERMESSAGE packet.
 
@@ -252,8 +266,8 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						CServer* pServer = theApp->serverlist->GetServerByAddress(cur_server->GetAddress(),cur_server->GetPort());
 						wxString servername;
 						if (pServer) {
-							servername	= pServer->GetListName();	
-						} else {	
+							servername	= pServer->GetListName();
+						} else {
 							servername = _("Server");
 						}
 						AddLogLineN(CFormat( _("ERROR: %s (%s) - %s") )
@@ -267,8 +281,8 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						CServer* pServer = theApp->serverlist->GetServerByAddress(cur_server->GetAddress(),cur_server->GetPort());
 						wxString servername;
 						if (pServer) {
-							servername	= pServer->GetListName();	
-						} else {	
+							servername	= pServer->GetListName();
+						} else {
 							servername = _("Server");
 						}
 						AddLogLineN(CFormat( _("WARNING: %s (%s) - %s") )
@@ -287,7 +301,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 							if (eserver){
 								eserver->SetDynIP(dynip);
 								cur_server->SetDynIP(dynip);
-								Notify_ServerRefresh(eserver);	
+								Notify_ServerRefresh(eserver);
 							}
 						}
 					}
@@ -300,25 +314,25 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 			}
 			case OP_IDCHANGE: {
 				AddDebugLogLineN(logServer, wxT("Server: OP_IDCHANGE"));
-				
+
 				theStats::AddDownOverheadServer(size);
-				
+
 				if (size < 4 /* uint32 (ID)*/) {
 					throw wxString(wxT("Corrupt or invalid loginanswer from server received"));
 				}
 
-				CMemFile data(packet, size);			
-				
+				CMemFile data(packet, size);
+
 				uint32 new_id = data.ReadUInt32();
 
 				// save TCP flags in 'cur_server'
 				wxASSERT(cur_server);
-				uint32 ConnPort = 0;
 				CServer* pServer = NULL;
 				if (cur_server) {
+					uint32 ConnPort = 0;
 					uint32 rport = cur_server->GetConnPort();
 					pServer = theApp->serverlist->GetServerByAddress(cur_server->GetAddress(), rport);
-					if (size >= 4+4 /* uint32 (ID) + uint32 (TCP flags)*/) {			
+					if (size >= 4+4 /* uint32 (ID) + uint32 (TCP flags)*/) {
 						cur_server->SetTCPFlags(data.ReadUInt32());
 						if (size >= 4+4+4 /* uint32 (ID) + uint32 (TCP flags) + uint32 (aux port) */) {
 							// aux port login : we should use the 'standard' port of this server to advertize to other clients
@@ -344,9 +358,8 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						}
 					}
 				}
-				
+
 				uint32 dwServerReportedIP = 0;
-				uint32 dwObfuscationTCPPort = 0;
 				if (size >= 4 + 4 + 4 + 4 + 4 /* All of the above + reported ip + obfuscation port */) {
 					dwServerReportedIP = data.ReadUInt32();
 					if (::IsLowID(dwServerReportedIP)){
@@ -354,16 +367,17 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						dwServerReportedIP = 0;
 					}
 					wxASSERT( dwServerReportedIP == new_id || ::IsLowID(new_id) );
-					dwObfuscationTCPPort = data.ReadUInt32();
-					if (cur_server != NULL && dwObfuscationTCPPort != 0) {
-						cur_server->SetObfuscationPortTCP((uint16)dwObfuscationTCPPort);
+					uint32 dwObfuscationTCPPort = data.ReadUInt32();
+					if (dwObfuscationTCPPort != 0) {
+						if (cur_server != NULL) {
+							cur_server->SetObfuscationPortTCP(dwObfuscationTCPPort);
+						}
+						if (pServer != NULL) {
+							pServer->SetObfuscationPortTCP(dwObfuscationTCPPort);
+						}
 					}
-					
-					if (pServer != NULL && dwObfuscationTCPPort != 0) {
-						pServer->SetObfuscationPortTCP((uint16)dwObfuscationTCPPort);
-					}
-				}				
-				
+				}
+
 				if (new_id == 0) {
 					uint8 state = thePrefs::GetSmartIdState();
 					if ( state > 0 ) {
@@ -392,7 +406,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						}
 					}
 				}
-				
+
 				// we need to know our client when sending our shared files (done indirectly on SetConnectionState)
 
 				serverconnect->SetClientID(new_id);
@@ -400,10 +414,10 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 				if (::IsLowID(new_id) && dwServerReportedIP != 0) {
 					theApp->SetPublicIP(dwServerReportedIP);
 				}
-				
+
 				if (connectionstate != CS_CONNECTED) {
 					AddDebugLogLineN(logServer, wxT("Connected"));
-					
+
 					SetConnectionState(CS_CONNECTED);
 					theApp->OnlineSig();       // Added By Bouc7
 				}
@@ -416,26 +430,26 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 					AddLogLineN(_("\tMost likely this is because you're behind a firewall or router."));
 					AddLogLineN(_("\tFor more information, please refer to http://wiki.amule.org"));
 				}
-								
+
 				theApp->downloadqueue->ResetLocalServerRequests();
 				break;
 			}
 			case OP_SEARCHRESULT: {
 				AddDebugLogLineN(logServer, wxT("Server: OP_SEARCHRESULT"));
-				
+
 				theStats::AddDownOverheadServer(size);
-				CServer* cur_srv = (serverconnect) ? 
+				CServer* cur_srv = (serverconnect) ?
 					serverconnect->GetCurrentServer() : NULL;
 				theApp->searchlist->ProcessSearchAnswer(
 					packet,
-					size, 
+					size,
 					true /*(cur_srv && cur_srv->GetUnicodeSupport())*/,
 					cur_srv ? cur_srv->GetIP() : 0,
 					cur_srv ? cur_srv->GetPort() : 0);
 				theApp->searchlist->LocalSearchEnd();
 				break;
 			}
-			case OP_FOUNDSOURCES_OBFU:			
+			case OP_FOUNDSOURCES_OBFU:
 			case OP_FOUNDSOURCES: {
 				AddDebugLogLineN(logServer, CFormat(wxT("ServerMsg - OP_FoundSources; sources = %u")) % packet[16]);
 				theStats::AddDownOverheadServer(size);
@@ -453,7 +467,6 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 				// FIXME some statuspackets have a different size -> why? structur?
 				if (size < 8) {
 					throw wxString(wxT("Invalid server status packet"));
-					break;
 				}
 				CServer* update = theApp->serverlist->GetServerByAddress(cur_server->GetAddress(), cur_server->GetPort());
 				if (update) {
@@ -478,7 +491,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 				CServer* update = theApp->serverlist->GetServerByAddress(cur_server->GetAddress(),cur_server->GetPort());
 				if (update) {
 					CMemFile data(packet,size);
-					CMD4Hash hash = data.ReadHash();				
+					CMD4Hash hash = data.ReadHash();
 					if (RawPeekUInt32(hash.GetHash()) == 0x2A2A2A2A){ // No endian problem here
 						const wxString& rstrVersion = update->GetVersion();
 						if (!rstrVersion.IsEmpty()) {
@@ -490,8 +503,8 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 					// Unused
 					/*uint32 nServerIP = */data.ReadUInt32();
 					/*uint16 nServerPort = */data.ReadUInt16();
-				
-					uint32 nTags = data.ReadUInt32();					
+
+					uint32 nTags = data.ReadUInt32();
 					for (uint32 i = 0; i < nTags; i++){
 						CTag tag(data, update->GetUnicodeSupport());
 						if (tag.GetNameID() == ST_SERVERNAME){
@@ -499,8 +512,8 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						} else if (tag.GetNameID() == ST_DESCRIPTION){
 							update->SetDescription(tag.GetStr());
 						} // No more known tags from server
-					}				
-								
+					}
+
 					theApp->ShowConnectionState();
 					Notify_ServerRefresh(update);
 				}
@@ -509,7 +522,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 			// tecxx 1609 2002 - add server's serverlist to own serverlist
 			case OP_SERVERLIST: {
 				AddDebugLogLineN(logServer, wxT("Server: OP_SERVERLIST"));
-				
+
 				CMemFile* servers = new CMemFile(packet,size);
 				uint8 count = servers->ReadUInt8();
 				if (((int32)(count*6 + 1) > size)) {
@@ -521,7 +534,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 					uint16 port = servers->ReadUInt16();
 					CServer* srv = new CServer(
 								port ,				// Port
-								Uint32toStringIP(ip)); 	// Ip
+								Uint32toStringIP(ip));	// Ip
 					srv->SetListName(srv->GetFullIP());
 					if (!theApp->AddServer(srv)) {
 						delete srv;
@@ -540,20 +553,20 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 			}
 			case OP_CALLBACKREQUESTED: {
 				AddDebugLogLineN(logServer, wxT("Server: OP_CALLBACKREQUESTED"));
-				
+
 				theStats::AddDownOverheadServer(size);
 				if (size >= 6) {
 					CMemFile data(packet,size);
 					uint32 dwIP = data.ReadUInt32();
 					uint16 nPort = data.ReadUInt16();
-					
+
 					uint8 byCryptOptions = 0;
 					CMD4Hash achUserHash;
 					if (size >= 23){
 						byCryptOptions = data.ReadUInt8();;
 						achUserHash = data.ReadHash();
 					}
-					
+
 					CUpDownClient* client = theApp->clientlist->FindClientByIP(dwIP,nPort);
 
 					if (!client) {
@@ -574,7 +587,7 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 						client->SetUserHash(achUserHash);
 						client->SetConnectOptions(byCryptOptions, true, false);
 					}
-					
+
 					client->TryToConnect();
 				}
 				break;
@@ -603,36 +616,36 @@ bool CServerSocket::ProcessPacket(const byte* packet, uint32 size, int8 opcode)
 	// Don't disconnect because of wrong sources.
 	if (opcode==OP_SEARCHRESULT || opcode==OP_FOUNDSOURCES) {
 		return true;
-	}				
+	}
 
 	SetConnectionState(CS_DISCONNECTED);
-	return false;	
+	return false;
 }
 
 void CServerSocket::ConnectToServer(CServer* server, bool bNoCrypt)
 {
 	AddDebugLogLineN(logServer, wxT("Trying to connect"));
-	
+
 	if (cur_server){
 		wxFAIL;
 		delete cur_server;
 		cur_server = NULL;
 	}
-	
+
 	cur_server = new CServer(server);
-	
-	m_bNoCrypt = bNoCrypt;	
-	
+
+	m_bNoCrypt = bNoCrypt;
+
 	SetConnectionState(CS_CONNECTING);
-	
-	info = cur_server->GetListName();		
+
+	info = cur_server->GetListName();
 
 	// This must be used if we want to reverse-check the addr of the server
 	if (cur_server->HasDynIP() || !cur_server->GetIP()) {
 		m_IsSolving = true;
 		// Send it to solving thread.
 		CAsyncDNS* dns = new CAsyncDNS(server->GetAddress(), DNS_SERVER_CONNECT, theApp, this);
-	
+
 		if ( dns->Create() == wxTHREAD_NO_ERROR ) {
 			if ( dns->Run() != wxTHREAD_NO_ERROR ) {
 				dns->Delete();
@@ -645,14 +658,14 @@ void CServerSocket::ConnectToServer(CServer* server, bool bNoCrypt)
 	} else {
 		// Nothing to solve, we already have the IP
 		OnHostnameResolved(cur_server->GetIP());
-	}	
+	}
 
 }
 
-void CServerSocket::OnError(wxSocketError DEBUG_ONLY(nErrorCode))
+void CServerSocket::OnError(int DEBUG_ONLY(nErrorCode))
 {
 	AddDebugLogLineN(logServer, CFormat(wxT("Error in serversocket: %s(%s:%i): %u"))
-		% cur_server->GetListName() % cur_server->GetFullIP() % cur_server->GetPort() % (int)nErrorCode);
+		% cur_server->GetListName() % cur_server->GetFullIP() % cur_server->GetPort() % nErrorCode);
 	SetConnectionState(CS_DISCONNECTED);
 }
 
@@ -660,7 +673,7 @@ void CServerSocket::OnError(wxSocketError DEBUG_ONLY(nErrorCode))
 bool CServerSocket::PacketReceived(CPacket* packet)
 {
 	AddDebugLogLineN(logServer, CFormat(wxT("Server: Packet Received: Prot %x, Opcode %x, Length %u")) % packet->GetProtocol() % packet->GetOpCode() % packet->GetPacketSize());
-	
+
 	if (packet->GetProtocol() == OP_PACKEDPROT) {
 		if (!packet->UnPackPacket(250000)){
 			AddDebugLogLineN(logZLib, CFormat(wxT("Failed to decompress server TCP packet: protocol=0x%02x  opcode=0x%02x  size=%u"))
@@ -668,10 +681,10 @@ bool CServerSocket::PacketReceived(CPacket* packet)
 			theStats::AddDownOverheadServer(packet->GetPacketSize());
 			return true;
 		}
-		
+
 		packet->SetProtocol(OP_EDONKEYPROT);
 	}
-		
+
 	if (packet->GetProtocol() == OP_EDONKEYPROT) {
 		ProcessPacket(packet->GetDataBuffer(), packet->GetPacketSize(), packet->GetOpCode());
 	} else {
@@ -679,21 +692,21 @@ bool CServerSocket::PacketReceived(CPacket* packet)
 			% packet->GetProtocol() % packet->GetOpCode() % packet->GetPacketSize());
 		theStats::AddDownOverheadServer(packet->GetPacketSize());
 	}
-	
+
 	return true;
 }
 
 
-void CServerSocket::OnClose(wxSocketError WXUNUSED(nErrorCode))
+void CServerSocket::OnClose(int WXUNUSED(nErrorCode))
 {
 	CEMSocket::OnClose(0);
-	
+
 	switch (connectionstate) {
 		case CS_WAITFORLOGIN:	SetConnectionState(CS_SERVERFULL);		break;
 		case CS_CONNECTED:	SetConnectionState(CS_DISCONNECTED);	break;
-		default:				SetConnectionState(CS_NOTCONNECTED);	
+		default:				SetConnectionState(CS_NOTCONNECTED);
 	}
-	
+
 	serverconnect->DestroySocket(this);
 }
 
@@ -718,13 +731,17 @@ void CServerSocket::SendPacket(CPacket* packet, bool delpacket, bool controlpack
 
 
 void CServerSocket::OnHostnameResolved(uint32 ip) {
-	
+
 	m_IsSolving = false;
 	if (ip) {
 		if (theApp->ipfilter->IsFiltered(ip, true)) {
 			AddLogLineC(CFormat( _("Server IP %s (%s) is filtered.  Not connecting.") )
 				% Uint32toStringIP(ip) % cur_server->GetAddress() );
+#ifdef ASIO_SOCKETS
+			OnConnect(boost::system::errc::invalid_argument);
+#else
 			OnConnect(wxSOCKET_INVADDR);
+#endif
 		} else {
 			amuleIPV4Address addr;
 			addr.Hostname(ip);
@@ -738,17 +755,17 @@ void CServerSocket::OnHostnameResolved(uint32 ip) {
 				nPort = cur_server->GetConnPort();
 				SetConnectionEncryption(false, NULL, true);
 			}
-			
-			addr.Service(nPort);			
-			
+
+			addr.Service(nPort);
+
 			AddLogLineN(CFormat( _("Connecting to %s (%s - %s:%i) %s") )
 				% cur_server->GetListName()
 				% cur_server->GetAddress()
 				% cur_server->GetFullIP()
-				% nPort 
+				% nPort
 				% useObfuscation
 			);
-			
+
 			AddDebugLogLineN(logServer, CFormat(wxT("Server %s(%s) Port %i"))
 				% cur_server->GetAddress() % Uint32toStringIP(ip) % cur_server->GetConnPort());
 			Connect(addr, false);
@@ -756,9 +773,13 @@ void CServerSocket::OnHostnameResolved(uint32 ip) {
 	} else {
 		AddLogLineC(CFormat( _("Could not solve dns for server %s: Unable to connect!") )
 			% cur_server->GetAddress() );
+#ifdef ASIO_SOCKETS
+		OnConnect(boost::system::errc::host_unreachable);
+#else
 		OnConnect(wxSOCKET_NOHOST);
+#endif
 	}
-	
+
 }
 uint32 CServerSocket::GetServerIP() const
 {
