@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -62,8 +62,9 @@ BEGIN_EVENT_TABLE(CSharedFilesCtrl,CMuleListCtrl)
 	EVT_MENU( MP_GETSOURCEED2KLINK,			CSharedFilesCtrl::OnCreateURI )
 	EVT_MENU( MP_GETCRYPTSOURCEDED2KLINK,			CSharedFilesCtrl::OnCreateURI )
 	EVT_MENU( MP_GETHOSTNAMESOURCEED2KLINK,	CSharedFilesCtrl::OnCreateURI )
-	EVT_MENU( MP_GETHOSTNAMECRYPTSOURCEED2KLINK,			CSharedFilesCtrl::OnCreateURI )	
+	EVT_MENU( MP_GETHOSTNAMECRYPTSOURCEED2KLINK,			CSharedFilesCtrl::OnCreateURI )
 	EVT_MENU( MP_GETAICHED2KLINK,	CSharedFilesCtrl::OnCreateURI )
+	EVT_MENU( MP_GETAICHED2KLINKSRC,	CSharedFilesCtrl::OnCreateURI )
 	EVT_MENU( MP_RENAME,		CSharedFilesCtrl::OnRename )
 	EVT_MENU( MP_WS,		CSharedFilesCtrl::OnGetFeedback )
 
@@ -144,13 +145,13 @@ void CSharedFilesCtrl::OnRightClick(wxListEvent& event)
 		m_menu->Append(0,_("Priority"),prioMenu);
 		m_menu->AppendSeparator();
 
-		CKnownFile* file = (CKnownFile*)GetItemData(item_hit);
+		CKnownFile* file = reinterpret_cast<CKnownFile*>(GetItemData(item_hit));
 		if (file->GetFileComment().IsEmpty() && !file->GetFileRating()) {
 			m_menu->Append(MP_CMT, _("Add Comment/Rating"));
 		} else {
 			m_menu->Append(MP_CMT, _("Edit Comment/Rating"));
 		}
-		
+
 		m_menu->AppendSeparator();
 		m_menu->Append(MP_RENAME, _("Rename"));
 		m_menu->AppendSeparator();
@@ -164,11 +165,13 @@ void CSharedFilesCtrl::OnRightClick(wxListEvent& event)
 		m_menu->Append(MP_GETSOURCEED2KLINK,_("Copy eD2k link to clipboard (&Source)"));
 		m_menu->Append(MP_GETCRYPTSOURCEDED2KLINK,_("Copy eD2k link to clipboard (Source) (&With Crypt options)"));
 		m_menu->Append(MP_GETHOSTNAMESOURCEED2KLINK,_("Copy eD2k link to clipboard (&Hostname)"));
-		m_menu->Append(MP_GETHOSTNAMECRYPTSOURCEED2KLINK,_("Copy eD2k link to clipboard (Hostname) (With &Crypt options)"));		
+		m_menu->Append(MP_GETHOSTNAMECRYPTSOURCEED2KLINK,_("Copy eD2k link to clipboard (Hostname) (With &Crypt options)"));
 		m_menu->Append(MP_GETAICHED2KLINK,_("Copy eD2k link to clipboard (&AICH info)"));
+		m_menu->Append(MP_GETAICHED2KLINKSRC,_("Copy eD2k link to clipboard (&AICH info + Source)"));
 		m_menu->Append(MP_WS,_("Copy feedback to clipboard"));
-		
+
 		m_menu->Enable(MP_GETAICHED2KLINK, file->HasProperAICHHashSet());
+		m_menu->Enable(MP_GETAICHED2KLINKSRC, file->HasProperAICHHashSet());
 		m_menu->Enable(MP_GETHOSTNAMESOURCEED2KLINK, !thePrefs::GetYourHostname().IsEmpty());
 		m_menu->Enable(MP_GETHOSTNAMECRYPTSOURCEED2KLINK, !thePrefs::GetYourHostname().IsEmpty());
 
@@ -201,7 +204,7 @@ void CSharedFilesCtrl::OnGetFeedback(wxCommandEvent& WXUNUSED(event))
 		} else {
 			feed += wxT("\n");
 		}
-		feed += ((CKnownFile*)GetItemData(index))->GetFeedback();
+		feed += reinterpret_cast<CKnownFile*>(GetItemData(index))->GetFeedback();
 		index = GetNextItem(index, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
 	}
 
@@ -224,7 +227,7 @@ void CSharedFilesCtrl::ShowFileList()
 
 	SortList();
 	ShowFilesCount();
-	
+
 	Thaw();
 }
 
@@ -232,10 +235,10 @@ void CSharedFilesCtrl::ShowFileList()
 void CSharedFilesCtrl::RemoveFile(CKnownFile *toRemove)
 {
 	long index = FindItem( -1, reinterpret_cast<wxUIntPtr>(toRemove) );
-	
+
 	if ( index != -1 ) {
 		DeleteItem( index );
-		
+
 		ShowFilesCount();
 	}
 }
@@ -253,13 +256,13 @@ void CSharedFilesCtrl::DoShowFile(CKnownFile* file, bool batch)
 	if ((!batch) && (FindItem(-1, ptr) > -1)) {
 		return;
 	}
-	
+
 	const long insertPos = (batch ? GetItemCount() : GetInsertPos(ptr));
 
 	long newitem = InsertItem(insertPos, wxEmptyString);
 	SetItemPtrData( newitem, ptr );
 
-	if (!batch) {	
+	if (!batch) {
 		ShowFilesCount();
 	}
 }
@@ -278,9 +281,9 @@ void CSharedFilesCtrl::OnSetPriority( wxCommandEvent& event )
 	}
 
 	long index = GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
-	
+
 	while( index != -1 ) {
-		CKnownFile* file = (CKnownFile*)GetItemData( index );
+		CKnownFile* file = reinterpret_cast<CKnownFile*>(GetItemData(index));
 		CoreNotify_KnownFile_Up_Prio_Set( file, priority );
 
 		RefreshItem( index );
@@ -293,9 +296,9 @@ void CSharedFilesCtrl::OnSetPriority( wxCommandEvent& event )
 void CSharedFilesCtrl::OnSetPriorityAuto( wxCommandEvent& WXUNUSED(event) )
 {
 	long index = GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
-	
+
 	while( index != -1 ) {
-		CKnownFile* file = (CKnownFile*)GetItemData( index );
+		CKnownFile* file = reinterpret_cast<CKnownFile*>(GetItemData(index));
 		CoreNotify_KnownFile_Up_Prio_Auto(file);
 
 		RefreshItem( index );
@@ -320,22 +323,23 @@ void CSharedFilesCtrl::OnCreateURI( wxCommandEvent& event )
 	long index = GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
 
 	while( index != -1 ) {
-		CKnownFile* file = (CKnownFile*)GetItemData( index );
+		CKnownFile* file = reinterpret_cast<CKnownFile*>(GetItemData(index));
 
 		switch ( event.GetId() ) {
 			case MP_GETMAGNETLINK:				URIs += theApp->CreateMagnetLink( file ) + wxT("\n");				break;
 			case MP_GETED2KLINK:				URIs += theApp->CreateED2kLink( file ) + wxT("\n");					break;
 			case MP_GETSOURCEED2KLINK:			URIs += theApp->CreateED2kLink( file , true) + wxT("\n");			break;
-			case MP_GETCRYPTSOURCEDED2KLINK:			URIs += theApp->CreateED2kLink( file , true, false, true) + wxT("\n");			break;
+			case MP_GETCRYPTSOURCEDED2KLINK:	URIs += theApp->CreateED2kLink( file , true, false, true) + wxT("\n");			break;
 			case MP_GETHOSTNAMESOURCEED2KLINK:	URIs += theApp->CreateED2kLink( file , true, true) + wxT("\n");	break;
-			case MP_GETHOSTNAMECRYPTSOURCEED2KLINK:			URIs += theApp->CreateED2kLink( file, true, true, true ) + wxT("\n");			break;				
-			case MP_GETAICHED2KLINK:			URIs += theApp->CreateED2kAICHLink( file ) + wxT("\n");				break;
+			case MP_GETHOSTNAMECRYPTSOURCEED2KLINK:			URIs += theApp->CreateED2kLink( file, true, true, true ) + wxT("\n");	break;
+			case MP_GETAICHED2KLINK:			URIs += theApp->CreateED2kLink(file, false, false, false, true) + wxT("\n");		break;
+			case MP_GETAICHED2KLINKSRC:			URIs += theApp->CreateED2kLink(file, true,  false, false, true) + wxT("\n");		break;
 		}
 
 		index = GetNextItem( index, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
 	}
 
-	if ( !URIs.IsEmpty() ) {	
+	if ( !URIs.IsEmpty() ) {
 		theApp->CopyTextToClipboard( URIs.RemoveLast() );
 	}
 }
@@ -344,12 +348,12 @@ void CSharedFilesCtrl::OnCreateURI( wxCommandEvent& event )
 void CSharedFilesCtrl::OnEditComment( wxCommandEvent& WXUNUSED(event) )
 {
 	long index = GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
-	
+
 	if ( index != -1 ) {
-		CKnownFile* file = (CKnownFile*)GetItemData( index );
+		CKnownFile* file = reinterpret_cast<CKnownFile*>(GetItemData(index));
 
 		CCommentDialog dialog( this, file );
-	
+
 		dialog.ShowModal();
 	}
 }
@@ -357,8 +361,8 @@ void CSharedFilesCtrl::OnEditComment( wxCommandEvent& WXUNUSED(event) )
 
 int CSharedFilesCtrl::SortProc(wxUIntPtr item1, wxUIntPtr item2, long sortData)
 {
-	CKnownFile* file1 = (CKnownFile*)item1;
-	CKnownFile* file2 = (CKnownFile*)item2;
+	CKnownFile* file1 = reinterpret_cast<CKnownFile*>(item1);
+	CKnownFile* file2 = reinterpret_cast<CKnownFile*>(item2);
 
 	int mod = (sortData & CMuleListCtrl::SORT_DES) ? -1 : 1;
 	bool altSorting = (sortData & CMuleListCtrl::SORT_ALT) > 0;
@@ -367,7 +371,7 @@ int CSharedFilesCtrl::SortProc(wxUIntPtr item1, wxUIntPtr item2, long sortData)
 		// Sort by filename.
 		case  ID_SHARED_COL_NAME:
 			return mod * CmpAny(file1->GetFileName(), file2->GetFileName());
-		
+
 		// Sort by filesize.
 		case  ID_SHARED_COL_SIZE:
 			return mod * CmpAny( file1->GetFileSize(), file2->GetFileSize() );
@@ -433,7 +437,7 @@ int CSharedFilesCtrl::SortProc(wxUIntPtr item1, wxUIntPtr item2, long sortData)
 
 			return mod * CmpAny(file1->GetFilePath(), file2->GetFilePath());
 		}
-		
+
 		default:
 			return 0;
 	}
@@ -443,7 +447,7 @@ int CSharedFilesCtrl::SortProc(wxUIntPtr item1, wxUIntPtr item2, long sortData)
 void CSharedFilesCtrl::UpdateItem(CKnownFile* toupdate)
 {
 	long result = FindItem( -1, reinterpret_cast<wxUIntPtr>(toupdate) );
-	
+
 	if ( result > -1 ) {
 		RefreshItem(result);
 
@@ -457,7 +461,7 @@ void CSharedFilesCtrl::UpdateItem(CKnownFile* toupdate)
 void CSharedFilesCtrl::ShowFilesCount()
 {
 	wxStaticText* label = CastByName( wxT("sharedFilesLabel"), GetParent(), wxStaticText );
-	
+
 	label->SetLabel(CFormat(_("Shared Files (%i)")) % GetItemCount());
 	label->GetParent()->Layout();
 	// If file list was updated, the "selection" is involved too, if we chose to show clients for all files.
@@ -468,11 +472,11 @@ void CSharedFilesCtrl::ShowFilesCount()
 
 void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const wxRect& rectHL, bool highlighted )
 {
-	CKnownFile *file = (CKnownFile*)GetItemData(item);
+	CKnownFile *file = reinterpret_cast<CKnownFile*>(GetItemData(item));
 	wxASSERT( file );
 
 	if ( highlighted ) {
-		CMuleColour newcol(GetFocus() ? wxSYS_COLOUR_HIGHLIGHT : wxSYS_COLOUR_BTNSHADOW);	
+		CMuleColour newcol(GetFocus() ? wxSYS_COLOUR_HIGHLIGHT : wxSYS_COLOUR_BTNSHADOW);
 		dc->SetBackground(newcol.Blend(125).GetBrush());
 		dc->SetTextForeground( CMuleColour(wxSYS_COLOUR_HIGHLIGHTTEXT));
 		// The second blending goes over the first one.
@@ -482,7 +486,7 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 		dc->SetTextForeground(CMuleColour(wxSYS_COLOUR_WINDOWTEXT));
 		dc->SetPen(*wxTRANSPARENT_PEN);
 	}
-	
+
 	dc->SetBrush(dc->GetBackground());
 	dc->DrawRectangle(rectHL);
 	dc->SetPen(*wxTRANSPARENT_PEN);
@@ -494,7 +498,7 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 
 	// The leftmost position of the current column
 	int columnLeft = 0;
-	
+
 	for ( int i = 0; i < GetColumnCount(); ++i ) {
 		const int columnWidth = GetColumnWidth(i);
 
@@ -502,9 +506,9 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 			wxRect columnRect(
 				columnLeft + SPARE_PIXELS_HORZ, rect.y,
 				columnWidth - 2 * SPARE_PIXELS_HORZ, rect.height);
-			
+
 			wxDCClipper clipper(*dc, columnRect);
-			
+
 			wxString textBuffer;
 			switch ( i ) {
 				case ID_SHARED_COL_NAME:
@@ -514,13 +518,13 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 						int image = Client_CommentOnly_Smiley;
 						if (file->GetFileRating()) {
 							image = Client_InvalidRating_Smiley + file->GetFileRating() - 1;
-						}	
-							
+						}
+
 						wxASSERT(image >= Client_InvalidRating_Smiley);
 						wxASSERT(image <= Client_CommentOnly_Smiley);
 
 						int imgWidth = 16;
-						
+
 						theApp->amuledlg->m_imagelist.Draw(image, *dc, columnRect.x,
 								columnRect.y + 1, wxIMAGELIST_DRAW_TRANSPARENT);
 
@@ -529,7 +533,7 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 					}
 
 					break;
-				
+
 				case ID_SHARED_COL_SIZE:
 					textBuffer = CastItoXBytes(file->GetFileSize());
 					break;
@@ -545,7 +549,7 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 				case ID_SHARED_COL_ID:
 					textBuffer = file->GetFileHash().Encode();
 					break;
-				
+
 				case ID_SHARED_COL_REQ:
 					textBuffer = CFormat(wxT("%u (%u)"))
 							% file->statistic.GetRequests()
@@ -562,20 +566,20 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 					textBuffer = CastItoXBytes(file->statistic.GetTransferred())
 						+ wxT(" (") + CastItoXBytes(file->statistic.GetAllTimeTransferred()) + wxT(")");
 					break;
-					
+
 				case ID_SHARED_COL_RTIO:
 					textBuffer = CFormat(wxT("%.2f")) %	((double)file->statistic.GetAllTimeTransferred() / file->GetFileSize());
 					break;
-				
+
 				case ID_SHARED_COL_PART:
 					if ( file->GetPartCount() ) {
-						wxRect barRect(columnRect.x, columnRect. y + 1, 
+						wxRect barRect(columnRect.x, columnRect. y + 1,
 							columnRect.width, columnRect.height - 2);
-						
+
 						DrawAvailabilityBar(file, dc, barRect);
 					}
 					break;
-				
+
 				case ID_SHARED_COL_CMPL:
 					if ( file->m_nCompleteSourcesCountLo == 0 ) {
 						if ( file->m_nCompleteSourcesCountHi ) {
@@ -588,9 +592,9 @@ void CSharedFilesCtrl::OnDrawItem( int item, wxDC* dc, const wxRect& rect, const
 					} else {
 						textBuffer = CFormat(wxT("%u - %u")) % file->m_nCompleteSourcesCountLo % file->m_nCompleteSourcesCountHi;
 					}
-					
-					break;				
-				
+
+					break;
+
 				case ID_SHARED_COL_PATH:
 					if ( file->IsPartFile() ) {
 						textBuffer = _("[PartFile]");
@@ -634,7 +638,7 @@ void CSharedFilesCtrl::DrawAvailabilityBar(CKnownFile* file, wxDC* dc, const wxR
 {
 	// Reference to the availability list
 	const ArrayOfUInts16& list = file->IsPartFile() ?
-		((CPartFile*)file)->m_SrcpartFrequency :
+		static_cast<CPartFile*>(file)->m_SrcpartFrequency :
 		file->m_AvailPartFrequency;
 	wxPen   old_pen   = dc->GetPen();
 	wxBrush old_brush = dc->GetBrush();
@@ -659,7 +663,7 @@ void CSharedFilesCtrl::DrawAvailabilityBar(CKnownFile* file, wxDC* dc, const wxR
 		s_ChunkBar.FillRange(start, end, CMuleColour(list[i] ? 0 : 255, list[i] ? ((210-(22*( list[i] - 1 ) ) < 0) ? 0 : (210-(22*( list[i] - 1 ) ))) : 0, list[i] ? 255 : 0));
 	}
 	s_ChunkBar.FillRange(end + 1, file->GetFileSize() - 1, CMuleColour(255, 0, 0));
-	s_ChunkBar.Draw(dc, barRect.x, barRect.y, bFlat); 
+	s_ChunkBar.Draw(dc, barRect.x, barRect.y, bFlat);
 
 	if (!bFlat) {
 		// Draw black border
@@ -676,7 +680,7 @@ void CSharedFilesCtrl::OnRename( wxCommandEvent& WXUNUSED(event) )
 {
 	int item = GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
 	if ( item != -1 ) {
-		CKnownFile* file = (CKnownFile*)GetItemData(item);
+		CKnownFile* file = reinterpret_cast<CKnownFile*>(GetItemData(item));
 
 		wxString strNewName = ::wxGetTextFromUser(
 			_("Enter new name for this file:"),
@@ -695,7 +699,7 @@ void CSharedFilesCtrl::OnKeyPressed( wxKeyEvent& event )
 	if (event.GetKeyCode() == WXK_F2) {
 		wxCommandEvent evt;
 		OnRename(evt);
-		
+
 		return;
 	}
 	event.Skip();
@@ -706,16 +710,15 @@ void CSharedFilesCtrl::OnAddCollection( wxCommandEvent& WXUNUSED(evt) )
 {
 	int item = GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED );
 	if (item != -1) {
-		CKnownFile *file = (CKnownFile*)GetItemData(item);
+		CKnownFile *file = reinterpret_cast<CKnownFile*>(GetItemData(item));
 		wxString CollectionFile = file->GetFilePath().JoinPaths(file->GetFileName()).GetRaw();
 		CMuleCollection my_collection;
 		if (my_collection.Open( (std::string)CollectionFile.mb_str() )) {
 //#warning This is probably not working on Unicode
-			for (size_t e = 0; e < my_collection.GetFileCount(); ++e) {
-				theApp->downloadqueue->AddLink(
-					wxString(my_collection.GetEd2kLink(e).c_str(), wxConvUTF8));
+			for (size_t e = 0; e < my_collection.size(); ++e) {
+				theApp->downloadqueue->AddLink(wxString(my_collection[e].c_str(), wxConvUTF8));
 			}
-				
+
 		}
 	}
 }
