@@ -17,22 +17,23 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
-	
+
 
 #ifdef HAVE_CONFIG_H
 	#include "config.h"		// Needed for VERSION
+#else
+	#include <common/ClientVersion.h>
 #endif
 
-#include <common/ClientVersion.h>
 
 #include "TextClient.h"
 
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	#include <unistd.h> // Do_not_auto_remove
 #endif
 
@@ -48,13 +49,9 @@
 
 #include <common/Format.h>		// Needed for CFormat
 #include "OtherFunctions.h"
-#include "KnownFile.h"			// Needed for Priority Levels
-#include "DataToText.cpp"		// Needed for PriorityToStr
-
-#define APP_INIT_SIZE_X 640
-#define APP_INIT_SIZE_Y 480
-
-#define theApp (*((CamulecmdApp*)wxTheApp))
+#include "Constants.h"			// Needed for Priority Levels
+#include "DataToText.h"			// Needed for PriorityToStr
+#include "MuleVersion.h"		// Needed for GetMuleVersion()
 
 //-------------------------------------------------------------------
 
@@ -78,16 +75,16 @@ enum {
 	CMD_ID_RELOAD_IPFILTER_NET,
 	CMD_ID_SET_IPFILTER_ON,
 	CMD_ID_SET_IPFILTER_OFF,
- 	CMD_ID_SET_IPFILTER_CLIENTS_ON,
+	CMD_ID_SET_IPFILTER_CLIENTS_ON,
 	CMD_ID_SET_IPFILTER_CLIENTS_OFF,
- 	CMD_ID_SET_IPFILTER_SERVERS_ON,
+	CMD_ID_SET_IPFILTER_SERVERS_ON,
 	CMD_ID_SET_IPFILTER_SERVERS_OFF,
 	CMD_ID_SET_IPFILTER_LEVEL,
- 	CMD_ID_GET_IPFILTER,
- 	CMD_ID_GET_IPFILTER_STATE,
+	CMD_ID_GET_IPFILTER,
+	CMD_ID_GET_IPFILTER_STATE,
 	CMD_ID_GET_IPFILTER_STATE_CLIENTS,
 	CMD_ID_GET_IPFILTER_STATE_SERVERS,
- 	CMD_ID_GET_IPFILTER_LEVEL,
+	CMD_ID_GET_IPFILTER_LEVEL,
 	CMD_ID_SHOW_UL,
 	CMD_ID_SHOW_DL,
 	CMD_ID_SHOW_LOG,
@@ -95,10 +92,10 @@ enum {
 	CMD_ID_SHOW_SHARED,
 	CMD_ID_RESET_LOG,
 	CMD_ID_SHUTDOWN,
- 	CMD_ID_ADDLINK,
- 	CMD_ID_SET_BWLIMIT_UP,
- 	CMD_ID_SET_BWLIMIT_DOWN,
- 	CMD_ID_GET_BWLIMITS,
+	CMD_ID_ADDLINK,
+	CMD_ID_SET_BWLIMIT_UP,
+	CMD_ID_SET_BWLIMIT_DOWN,
+	CMD_ID_GET_BWLIMITS,
 	CMD_ID_STATTREE,
 	CMD_ID_SEARCH,
 	CMD_ID_SEARCH_GLOBAL,
@@ -113,7 +110,7 @@ enum {
 };
 
 // method to create a SearchFile
-SearchFile::SearchFile(CEC_SearchFile_Tag *tag)
+SearchFile::SearchFile(const CEC_SearchFile_Tag *tag)
 {
 	nHash = tag->FileHash();
 	sHash = nHash.Encode();
@@ -130,8 +127,8 @@ IMPLEMENT_APP (CamulecmdApp)
 void CamulecmdApp::OnInitCmdLine(wxCmdLineParser& parser)
 {
 	CaMuleExternalConnector::OnInitCmdLine(parser, "amulecmd");
-	parser.AddOption(wxT("c"), wxT("command"), 
-		_("Execute <str> and exit."), 
+	parser.AddOption(wxT("c"), wxT("command"),
+		_("Execute <str> and exit."),
 		wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL);
 }
 
@@ -179,7 +176,7 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			CmdId = CMD_ID_GET_IPFILTER_STATE;
 		}
 	}
-	
+
 	switch (CmdId) {
 		case CMD_ID_STATUS:
 			request_list.push_back(new CECPacket(EC_OP_STAT_REQ, EC_DETAIL_CMD));
@@ -189,22 +186,22 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			request_list.push_back(new CECPacket(EC_OP_SHUTDOWN));
 			break;
 
- 		case CMD_ID_CONNECT:
+		case CMD_ID_CONNECT:
 			if ( !args.IsEmpty() ) {
 				unsigned int ip[4];
 				unsigned int port;
 				// Not much we can do against this unicode2char.
-				int result = sscanf(unicode2char(args), "%d.%d.%d.%d:%d", &ip[0], &ip[1], &ip[2], &ip[3], &port);
+				int result = sscanf(unicode2char(args), "%3d.%3d.%3d.%3d:%5d", &ip[0], &ip[1], &ip[2], &ip[3], &port);
 				if (result != 5) {
 					// Try to resolve DNS -- good for dynamic IP servers
 					wxString serverName(args.BeforeFirst(wxT(':')));
 					long lPort;
 					bool ok = args.AfterFirst(wxT(':')).ToLong(&lPort);
 					port = (unsigned int)lPort;
-					wxIPV4address a;
+					amuleIPV4Address a;
 					a.Hostname(serverName);
 					a.Service(port);
-					result = sscanf(unicode2char(a.IPAddress()), "%d.%d.%d.%d", &ip[0], &ip[1], &ip[2], &ip[3]);
+					result = sscanf(unicode2char(a.IPAddress()), "%3d.%3d.%3d.%3d", &ip[0], &ip[1], &ip[2], &ip[3]);
 					if (serverName.IsEmpty() || !ok || (result != 4)) {
 						Show(_("Invalid IP format. Use xxx.xxx.xxx.xxx:xxxx\n"));
 						return 0;
@@ -228,11 +225,11 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			request_list.push_back(new CECPacket(EC_OP_SERVER_CONNECT));
 			break;
 
- 		case CMD_ID_CONNECT_KAD:
+		case CMD_ID_CONNECT_KAD:
 			request_list.push_back(new CECPacket(EC_OP_KAD_START));
 			break;
 
- 		case CMD_ID_DISCONNECT:
+		case CMD_ID_DISCONNECT:
 			request_list.push_back(new CECPacket(EC_OP_DISCONNECT));
 			break;
 
@@ -240,7 +237,7 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			request_list.push_back(new CECPacket(EC_OP_SERVER_DISCONNECT));
 			break;
 
- 		case CMD_ID_DISCONNECT_KAD:
+		case CMD_ID_DISCONNECT_KAD:
 			request_list.push_back(new CECPacket(EC_OP_KAD_STOP));
 			break;
 
@@ -331,7 +328,7 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 				CECPacket request_all(EC_OP_GET_DLOAD_QUEUE, EC_DETAIL_CMD);
 				const CECPacket *reply_all = SendRecvMsg_v2(&request_all);
 
-				if (reply_all) { 
+				if (reply_all) {
 					switch(CmdId) {
 						case CMD_ID_PAUSE:
 								request = new CECPacket(EC_OP_PARTFILE_PAUSE); break;
@@ -345,12 +342,12 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 					// We loop through all the arguments
 					while(argsTokenizer.HasMoreTokens()) {
 						token=argsTokenizer.GetNextToken();
-						
+
 						// If the user requested all, then we select all files and exit the loop
 						// since there is little point to add anything more to "everything"
 						if( token == wxT("all") ) {
-							for (CECPacket::const_iterator it = reply_all->begin(); it != reply_all->end(); it++) {
-								CEC_PartFile_Tag *tag = (CEC_PartFile_Tag *) & *it;
+							for (CECPacket::const_iterator it = reply_all->begin(); it != reply_all->end(); ++it) {
+								const CEC_PartFile_Tag *tag = static_cast<const CEC_PartFile_Tag *>(&*it);
 								request->AddTag(CECTag(EC_TAG_PARTFILE, tag->FileHash()));
 							}
 							break;
@@ -361,8 +358,8 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 							}
 						} else {
 							 // Go through the dl queue and look at each filename
-							for (CECPacket::const_iterator it = reply_all->begin(); it != reply_all->end(); it++) {
-								CEC_PartFile_Tag *tag = (CEC_PartFile_Tag *) & *it;
+							for (CECPacket::const_iterator it = reply_all->begin(); it != reply_all->end(); ++it) {
+								const CEC_PartFile_Tag *tag = static_cast<const CEC_PartFile_Tag *>(&*it);
 								wxString partmetname = tag->PartMetName();
 
 								// We check for filename, XXX.pat.met, XXX.part, XXX
@@ -372,9 +369,9 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 									partmetname.Truncate(partmetname.Len()-5) == token) {
 									Show(_("Processing by filename: "+token+wxT("\n")));
 									request->AddTag(CECTag(EC_TAG_PARTFILE, tag->FileHash()));
-								}		
-							}	
-						} // End of filename check else	
+								}
+							}
+						} // End of filename check else
 					} // End of argument token loop
 
 				request_list.push_back(request);
@@ -423,7 +420,7 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 					}
 				} else {
 						Show(_("Not a valid hash (length should be exactly 32 chars)\n"));
-						return 0;					
+						return 0;
 				}
 			}
 			break;
@@ -444,6 +441,10 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			request_list.push_back(new CECPacket(EC_OP_GET_SERVER_LIST, EC_DETAIL_CMD));
 			break;
 
+		case CMD_ID_SHOW_SHARED:
+			request_list.push_back(new CECPacket(EC_OP_GET_SHARED_FILES));
+			break;
+
 		case CMD_ID_RESET_LOG:
 			request_list.push_back(new CECPacket(EC_OP_RESET_LOG));
 			break;
@@ -514,13 +515,13 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			if (search_type != EC_SEARCH_GLOBAL && search_type != EC_SEARCH_LOCAL){
 				search_type = EC_SEARCH_KAD;
 			}
-			if (!args.IsEmpty()) 
-			{	
-				wxString search = args; 
+			if (!args.IsEmpty())
+			{
+				wxString search = args;
 				wxString type;
-				wxString extention; 
-				uint32 avail = 0; 
-				uint32 min_size = 0; 
+				wxString extention;
+				uint32 avail = 0;
+				uint32 min_size = 0;
 				uint32 max_size = 0;
 
 				request = new CECPacket(EC_OP_SEARCH_START);
@@ -529,9 +530,11 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			}
 			break;
 		case CMD_ID_SEARCH:
-			printf("No search type defined.\nType 'help search' to get more help.\n");
+			/* TRANSLATORS:
+			   'help search' is a command to the program, do not translate it. */
+			Show(_("No search type defined.\nType 'help search' to get more help.\n"));
 			break;
-			
+
 
 		case CMD_ID_SEARCH_RESULTS:
 			request_list.push_back(new CECPacket(EC_OP_SEARCH_RESULTS, EC_DETAIL_FULL));
@@ -542,13 +545,13 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 			break;
 
 		case CMD_ID_DOWNLOAD:
-			if (!args.IsEmpty()) 
-			{	
+			if (!args.IsEmpty())
+			{
 				unsigned long int id = 0;
 				if (args.ToULong(&id) == true && id < m_Results_map.size()) {
 
 					SearchFile* file = m_Results_map[id];
-					printf("Download File: %lu %s\n", id, (const char*)unicode2char(file->sFileName));
+					Show(CFormat(_("Download File: %lu %s\n")) % id % file->sFileName);
 					request = new CECPacket(EC_OP_DOWNLOAD_SEARCH_RESULT);
 					// get with id the hash and category=0
 					uint32 category = 0;
@@ -561,7 +564,7 @@ int CamulecmdApp::ProcessCommand(int CmdId)
 				}
 			}
 			break;
-		
+
 		default:
 			return CMD_ERR_PROCESS_CMD;
 	}
@@ -600,33 +603,33 @@ void CamulecmdApp::ShowResults(CResultMap results_map)
 	unsigned int nr_max = 5;
 	unsigned long int id = 0;
 	wxString output, name, sources, mb , kb;
-	
+
 	printf("Nr.    Filename:                                                                        Size(MB):  Sources: \n");
 	printf("-----------------------------------------------------------------------------------------------------------\n");
 
-	for( std::map<unsigned long int,SearchFile*>::iterator iter = results_map.begin(); iter != results_map.end(); iter++ ) {
-    		id = (*iter).first;
+	for( std::map<unsigned long int,SearchFile*>::iterator iter = results_map.begin(); iter != results_map.end(); ++iter ) {
+		id = (*iter).first;
 		SearchFile* file = (*iter).second;
-		
-		output.Printf(wxT("%i.      "), id);		
-		output = output.SubString(0, nr_max).Append(file->sFileName).Append(' ', name_max);		
+
+		output.Printf(wxT("%i.      "), id);
+		output = output.SubString(0, nr_max).Append(file->sFileName).Append(' ', name_max);
 		mb.Printf(wxT("     %d"), file->lFileSize/1024/1024);
 		kb.Printf(wxT(".%d"), file->lFileSize/1024%1024);
-		output = output.SubString(0, nr_max + name_max + mb_max - mb.Length() ).Append(mb).Append(kb);	
+		output = output.SubString(0, nr_max + name_max + mb_max - mb.Length() ).Append(mb).Append(kb);
 		printf("%s     %ld\n",(const char*)unicode2char(output), file->lSourceCount );
- 	}
+	}
 }
 
 
 // Formats a statistics (sub)tree to text
-wxString StatTree2Text(CEC_StatTree_Node_Tag *tree, int depth)
+wxString StatTree2Text(const CEC_StatTree_Node_Tag *tree, int depth)
 {
 	if (!tree) {
 		return wxEmptyString;
 	}
 	wxString result = wxString(wxChar(' '), depth) + tree->GetDisplayString() + wxT("\n");
-	for (CECTag::const_iterator it = tree->begin(); it != tree->end(); it++) {
-		CEC_StatTree_Node_Tag *tmp = (CEC_StatTree_Node_Tag*) & *it;
+	for (CECTag::const_iterator it = tree->begin(); it != tree->end(); ++it) {
+		const CEC_StatTree_Node_Tag *tmp = static_cast<const CEC_StatTree_Node_Tag*>(&*it);
 		if (tmp->GetTagName() == EC_TAG_STATTREE_NODE) {
 			result += StatTree2Text(tmp, depth + 1);
 		}
@@ -688,18 +691,18 @@ void CamulecmdApp::Process_Answer_v2(const CECPacket *response)
 			}
 			break;
 		case EC_OP_STRINGS:
-			for (CECPacket::const_iterator it = response->begin(); it != response->end(); it++) {
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
 				const CECTag &tag = *it;
 				s << tag.GetStringData() << wxT("\n");
 			}
 			break;
 		case EC_OP_STATS: {
-			CEC_ConnState_Tag *connState = (CEC_ConnState_Tag*)response->GetTagByName(EC_TAG_CONNSTATE);
+			const CEC_ConnState_Tag *connState = static_cast<const CEC_ConnState_Tag*>(response->GetTagByName(EC_TAG_CONNSTATE));
 			if (connState) {
 				s << _("eD2k") << wxT(": ");
 				if (connState->IsConnectedED2K()) {
-					CECTag *server = connState->GetTagByName(EC_TAG_SERVER);
-					CECTag *serverName = server ? server->GetTagByName(EC_TAG_SERVER_NAME) : NULL;
+					const CECTag *server = connState->GetTagByName(EC_TAG_SERVER);
+					const CECTag *serverName = server ? server->GetTagByName(EC_TAG_SERVER_NAME) : NULL;
 					if (server && serverName) {
 						s << CFormat(_("Connected to %s %s %s")) %
 						 serverName->GetStringData() %
@@ -737,42 +740,42 @@ void CamulecmdApp::Process_Answer_v2(const CECPacket *response)
 				s <<	CFormat(_("\nUpload:\t%s")) % CastItoSpeed(tmpTag->GetInt());
 			}
 			if ((tmpTag = response->GetTagByName(EC_TAG_STATS_UL_QUEUE_LEN)) != 0) {
-				s << 	CFormat(_("\nClients in queue:\t%d\n")) % tmpTag->GetInt();
+				s <<	CFormat(_("\nClients in queue:\t%d\n")) % tmpTag->GetInt();
 			}
 			if ((tmpTag = response->GetTagByName(EC_TAG_STATS_TOTAL_SRC_COUNT)) != 0) {
-				s << 	CFormat(_("\nTotal sources:\t%d\n")) % tmpTag->GetInt();
+				s <<	CFormat(_("\nTotal sources:\t%d\n")) % tmpTag->GetInt();
 			}
 			break;
 		}
 		case EC_OP_DLOAD_QUEUE:
-			for (CECPacket::const_iterator it = response->begin(); it != response->end(); it++) {
-				CEC_PartFile_Tag *tag =	(CEC_PartFile_Tag *) & *it;
-					uint64 filesize, donesize;
-					filesize = tag->SizeFull();
-					donesize = tag->SizeDone();
-					s <<	tag->FileHashString() << wxT(" ") <<
-						tag->FileName() <<
-						(CFormat(wxT("\n\t [%.1f%%] %4i/%4i "))
-							% ((float)donesize / ((float)filesize)*100.0)
-							% ((int)tag->SourceCount() - (int)tag->SourceNotCurrCount())
-							% (int)tag->SourceCount()) <<
-						((int)tag->SourceCountA4AF() ? wxString(CFormat(wxT("+%2.2i ")) % (int)tag->SourceCountA4AF()) : wxString(wxT("    "))) <<
-						((int)tag->SourceXferCount() ? wxString(CFormat(wxT("(%2.2i) - ")) % (int)tag->SourceXferCount()) : wxString(wxT("     - "))) <<
-						tag->GetFileStatusString();
-					s << wxT(" - ") << tag->PartMetName();
-                    if (tag->DownPrio() < 10) {
-                            s << wxT(" - ") << PriorityToStr((int)tag->DownPrio(), 0);
-                    } else {
-                            s << wxT(" - ") << PriorityToStr((tag->DownPrio() - 10), 1);
-                    }
-					if ( tag->SourceXferCount() > 0) {
-						s << wxT(" - ") + CastItoSpeed(tag->Speed());
-					}
-					s << wxT("\n");
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
+				const CEC_PartFile_Tag *tag = static_cast<const CEC_PartFile_Tag *>(&*it);
+				uint64 filesize, donesize;
+				filesize = tag->SizeFull();
+				donesize = tag->SizeDone();
+				s <<	tag->FileHashString() << wxT(" ") <<
+					tag->FileName() <<
+					(CFormat(wxT("\n\t [%.1f%%] %4i/%4i "))
+						% ((float)donesize / ((float)filesize)*100.0)
+						% ((int)tag->SourceCount() - (int)tag->SourceNotCurrCount())
+						% (int)tag->SourceCount()) <<
+					((int)tag->SourceCountA4AF() ? wxString(CFormat(wxT("+%2.2i ")) % (int)tag->SourceCountA4AF()) : wxString(wxT("    "))) <<
+					((int)tag->SourceXferCount() ? wxString(CFormat(wxT("(%2.2i) - ")) % (int)tag->SourceXferCount()) : wxString(wxT("     - "))) <<
+					tag->GetFileStatusString();
+				s << wxT(" - ") << tag->PartMetName();
+				if (tag->DownPrio() < 10) {
+					s << wxT(" - ") << PriorityToStr((int)tag->DownPrio(), 0);
+				} else {
+					s << wxT(" - ") << PriorityToStr((tag->DownPrio() - 10), 1);
+				}
+				if ( tag->SourceXferCount() > 0) {
+					s << wxT(" - ") + CastItoSpeed(tag->Speed());
+				}
+				s << wxT("\n");
 			}
 			break;
 		case EC_OP_ULOAD_QUEUE:
-			for (CECPacket::const_iterator it = response->begin(); it != response->end(); it++) {
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
 				const CECTag *tag = & *it;
 				const CECTag *clientName = tag->GetTagByName(EC_TAG_CLIENT_NAME);
 				const CECTag *partfileName = tag->GetTagByName(EC_TAG_PARTFILE_NAME);
@@ -789,13 +792,13 @@ void CamulecmdApp::Process_Answer_v2(const CECPacket *response)
 			}
 			break;
 		case EC_OP_LOG:
-			for (CECPacket::const_iterator it = response->begin(); it != response->end(); it++) {
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
 				const CECTag &tag = *it;
 				s << tag.GetStringData() << wxT("\n");
 			}
 			break;
 		case EC_OP_SERVER_LIST:
-			for (CECPacket::const_iterator it = response->begin(); it != response->end(); it++) {
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
 				const CECTag &tag = *it;
 				const CECTag *serverName = tag.GetTagByName(EC_TAG_SERVER_NAME);
 				if (serverName) {
@@ -805,8 +808,44 @@ void CamulecmdApp::Process_Answer_v2(const CECPacket *response)
 				}
 			}
 			break;
+
+		case EC_OP_SHARED_FILES:
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
+				const CEC_SharedFile_Tag *tag = static_cast<const CEC_SharedFile_Tag *>(&*it);
+				s << tag->FileHashString() << wxT(" ");
+				wxString filePath = tag->FilePath();
+				bool ispartfile = true;
+				if (filePath.EndsWith(wxT(".part"))) {
+					for (unsigned i = 0; i < filePath.Length() - 5; i++) {
+						if (filePath[i] < wxT('0') || filePath[i] > wxT('9')) {
+							ispartfile = false;
+							break;
+						}
+					}
+				} else {
+					ispartfile = false;
+				}
+				if (ispartfile) {
+					s << _("[PartFile]") << wxT(" ");
+				} else {
+					s << filePath
+#ifdef __WINDOWS__
+					  << wxT('\\');
+#else
+					  << wxT('/');
+#endif
+				}
+				s << tag->FileName()
+				  << wxT("\n\t") << PriorityToStr(tag->UpPrio() % 10, tag->UpPrio() >= 10) << wxT(" - ") << CFormat(wxT("%i(%i) / %i(%i) - %s (%s) - %.2f\n"))
+					% tag->GetRequests() % tag->GetAllRequests()
+					% tag->GetAccepts() % tag->GetAllAccepts()
+					% CastItoXBytes(tag->GetXferred()) % CastItoXBytes(tag->GetAllXferred())
+					% (static_cast<float>(tag->GetAllXferred()) / static_cast<float>(tag->SizeFull()));
+			}
+			break;
+
 		case EC_OP_STATSTREE:
-			s << StatTree2Text((CEC_StatTree_Node_Tag*)response->GetTagByName(EC_TAG_STATTREE_NODE), 0);
+			s << StatTree2Text(static_cast<const CEC_StatTree_Node_Tag*>(response->GetTagByName(EC_TAG_STATTREE_NODE)), 0);
 			break;
 
 		case EC_OP_SEARCH_RESULTS:
@@ -814,8 +853,8 @@ void CamulecmdApp::Process_Answer_v2(const CECPacket *response)
 			int i = 0;
 			m_Results_map.clear();
 			s += CFormat(_("Number of search results: %i\n")) % response->GetTagCount();
-			for (CECPacket::const_iterator it = response->begin(); it != response->end(); it++) {
-				CEC_SearchFile_Tag *tag = (CEC_SearchFile_Tag *) & *it;
+			for (CECPacket::const_iterator it = response->begin(); it != response->end(); ++it) {
+				const CEC_SearchFile_Tag *tag = static_cast<const CEC_SearchFile_Tag *>(&*it);
 				//printf("Tag FileName: %s \n",(const char*)unicode2char(tag->FileName()));
 				m_Results_map[i++] = new SearchFile(tag);
 			}
@@ -861,7 +900,7 @@ void CamulecmdApp::OnInitCommandSet()
 
 	tmp2 = tmp->AddCommand(wxT("IPFilter"), CMD_ID_RELOAD_IPFILTER_LOCAL, wxTRANSLATE("Reload IP filtering table."), wxEmptyString, CMD_PARAM_OPTIONAL);
 	tmp2->AddCommand(wxT("File"), CMD_ID_RELOAD_IPFILTER_LOCAL, wxTRANSLATE("Reload current IP filtering table."), wxEmptyString, CMD_PARAM_NEVER);
-	tmp2->AddCommand(wxT("Net"), CMD_ID_RELOAD_IPFILTER_NET, wxTRANSLATE("Update IP filtering table from URL."), 
+	tmp2->AddCommand(wxT("Net"), CMD_ID_RELOAD_IPFILTER_NET, wxTRANSLATE("Update IP filtering table from URL."),
 					wxTRANSLATE("If URL is omitted the URL from the preferences is used."), CMD_PARAM_OPTIONAL);
 
 	tmp = m_commands.AddCommand(wxT("Connect"), CMD_ID_CONNECT, wxTRANSLATE("Connect to the network."),
@@ -874,7 +913,7 @@ void CamulecmdApp::OnInitCommandSet()
 	tmp->AddCommand(wxT("ED2K"), CMD_ID_DISCONNECT_ED2K, wxTRANSLATE("Disconnect from eD2k only."), wxEmptyString, CMD_PARAM_NEVER);
 	tmp->AddCommand(wxT("Kad"), CMD_ID_DISCONNECT_KAD, wxTRANSLATE("Disconnect from Kad only."), wxEmptyString, CMD_PARAM_NEVER);
 
- 	m_commands.AddCommand(wxT("Add"), CMD_ID_ADDLINK, wxTRANSLATE("Add an eD2k or magnet link to core."),
+	m_commands.AddCommand(wxT("Add"), CMD_ID_ADDLINK, wxTRANSLATE("Add an eD2k or magnet link to core."),
 			      wxTRANSLATE("The eD2k link to be added can be:\n*) a file link (ed2k://|file|...), it will be added to the download queue,\n*) a server link (ed2k://|server|...), it will be added to the server list,\n*) or a serverlist link, in which case all servers in the list will be added to the\n   server list.\n\nThe magnet link must contain the eD2k hash and file length.\n"), CMD_PARAM_ALWAYS);
 
 	tmp = m_commands.AddCommand(wxT("Set"), CMD_ERR_INCOMPLETE, wxTRANSLATE("Set a preference value."),
@@ -895,9 +934,9 @@ void CamulecmdApp::OnInitCommandSet()
 	tmp2 = tmp->AddCommand(wxT("BwLimit"), CMD_ERR_INCOMPLETE, wxTRANSLATE("Set bandwidth limits."),
 			       wxTRANSLATE("The value given to these commands has to be in kilobytes/sec.\n"), CMD_PARAM_NEVER);
 	tmp2->AddCommand(wxT("Up"), CMD_ID_SET_BWLIMIT_UP, wxTRANSLATE("Set upload bandwidth limit."),
-			 wxT("The given value must be in kilobytes/sec.\n"), CMD_PARAM_ALWAYS);
+			 wxTRANSLATE("The given value must be in kilobytes/sec.\n"), CMD_PARAM_ALWAYS);
 	tmp2->AddCommand(wxT("Down"), CMD_ID_SET_BWLIMIT_DOWN, wxTRANSLATE("Set download bandwidth limit."),
-			 wxT("The given value must be in kilobytes/sec.\n"), CMD_PARAM_ALWAYS);
+			 wxTRANSLATE("The given value must be in kilobytes/sec.\n"), CMD_PARAM_ALWAYS);
 
 	tmp = m_commands.AddCommand(wxT("Get"), CMD_ERR_INCOMPLETE, wxTRANSLATE("Get and display a preference value."),
 				    wxEmptyString, CMD_PARAM_NEVER);
@@ -930,14 +969,14 @@ void CamulecmdApp::OnInitCommandSet()
 	// TODO: These commands below need implementation and/or rewrite!
 	//
 
-  	m_commands.AddCommand(wxT("Pause"), CMD_ID_PAUSE, wxTRANSLATE("Pause download."),
- 			      wxEmptyString, CMD_PARAM_ALWAYS);
+	m_commands.AddCommand(wxT("Pause"), CMD_ID_PAUSE, wxTRANSLATE("Pause download."),
+			      wxEmptyString, CMD_PARAM_ALWAYS);
 
-  	m_commands.AddCommand(wxT("Resume"), CMD_ID_RESUME, wxTRANSLATE("Resume download."),
- 			      wxEmptyString, CMD_PARAM_ALWAYS);
+	m_commands.AddCommand(wxT("Resume"), CMD_ID_RESUME, wxTRANSLATE("Resume download."),
+			      wxEmptyString, CMD_PARAM_ALWAYS);
 
-   	m_commands.AddCommand(wxT("Cancel"), CMD_ID_CANCEL, wxTRANSLATE("Cancel download."),
-  			      wxEmptyString, CMD_PARAM_ALWAYS);
+	m_commands.AddCommand(wxT("Cancel"), CMD_ID_CANCEL, wxTRANSLATE("Cancel download."),
+			      wxEmptyString, CMD_PARAM_ALWAYS);
 
 	tmp = m_commands.AddCommand(wxT("Priority"), CMD_ERR_INCOMPLETE, wxTRANSLATE("Set download priority."),
 				    wxTRANSLATE("Set priority of a download to Low, Normal, High or Auto.\n"), CMD_PARAM_ALWAYS);
@@ -945,14 +984,14 @@ void CamulecmdApp::OnInitCommandSet()
 	tmp->AddCommand(wxT("Normal"), CMD_ID_PRIORITY_NORMAL, wxTRANSLATE("Set priority to normal."), wxEmptyString, CMD_PARAM_ALWAYS);
 	tmp->AddCommand(wxT("High"), CMD_ID_PRIORITY_HIGH, wxTRANSLATE("Set priority to high."), wxEmptyString, CMD_PARAM_ALWAYS);
 	tmp->AddCommand(wxT("Auto"), CMD_ID_PRIORITY_AUTO, wxTRANSLATE("Set priority to auto."), wxEmptyString, CMD_PARAM_ALWAYS);
-				  
+
 	tmp = m_commands.AddCommand(wxT("Show"), CMD_ERR_INCOMPLETE, wxTRANSLATE("Show queues/lists."),
 				    wxTRANSLATE("Show upload/download queue, server list or shared files list.\n"), CMD_PARAM_ALWAYS);
 	tmp->AddCommand(wxT("UL"), CMD_ID_SHOW_UL, wxTRANSLATE("Show upload queue."), wxEmptyString, CMD_PARAM_NEVER);
 	tmp->AddCommand(wxT("DL"), CMD_ID_SHOW_DL, wxTRANSLATE("Show download queue."), wxEmptyString, CMD_PARAM_NEVER);
 	tmp->AddCommand(wxT("Log"), CMD_ID_SHOW_LOG, wxTRANSLATE("Show log."), wxEmptyString, CMD_PARAM_NEVER);
 	tmp->AddCommand(wxT("Servers"), CMD_ID_SHOW_SERVERS, wxTRANSLATE("Show servers list."), wxEmptyString, CMD_PARAM_NEVER);
-// 	tmp->AddCommand(wxT("Shared"), CMD_ID_SHOW_SHARED, wxTRANSLATE("Show shared files list."), wxEmptyString, CMD_PARAM_NEVER);
+	tmp->AddCommand(wxT("Shared"), CMD_ID_SHOW_SHARED, wxTRANSLATE("Show shared files list."), wxEmptyString, CMD_PARAM_NEVER);
 
 	m_commands.AddCommand(wxT("Reset"), CMD_ID_RESET_LOG, wxTRANSLATE("Reset log."), wxEmptyString, CMD_PARAM_NEVER);
 
@@ -990,4 +1029,12 @@ bool ECLogIsEnabled()
 void DoECLogLine(const wxString &)
 {
 }
+
+
+namespace MuleNotify
+{
+	void HandleNotification(const class CMuleNotiferBase&) {}
+	void HandleNotificationAlways(const class CMuleNotiferBase&) {}
+}
+
 // File_checked_for_headers
