@@ -18,7 +18,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -43,7 +43,7 @@
 
 //! This hash represents the value for an empty MD4 hashing
 const byte g_emptyMD4Hash[16] = {
-	0x31, 0xD6, 0xCF, 0xE0, 0xD1, 0x6A, 0xE9, 0x31, 
+	0x31, 0xD6, 0xCF, 0xE0, 0xD1, 0x6A, 0xE9, 0x31,
 	0xB7, 0x3C, 0x59, 0xD7, 0xE0, 0xC0, 0x89, 0xC0 };
 
 
@@ -58,9 +58,9 @@ CHashingTask::CHashingTask(const CPath& path, const CPath& filename, const CPart
 	  m_toHash((EHashes)(EH_MD4 | EH_AICH)),
 	  m_owner(part)
 {
-	// We can only create the AICH hashset if the file is a knownfile or 
+	// We can only create the AICH hashset if the file is a knownfile or
 	// if the partfile is complete, since the MD4 hashset is checked first,
-	// so that the AICH hashset only gets assigned if the MD4 hashset 
+	// so that the AICH hashset only gets assigned if the MD4 hashset
 	// matches what we expected. Due to the rareity of post-completion
 	// corruptions, this gives us a nice speedup in most cases.
 	if (part && !part->GetGapList().empty()) {
@@ -90,7 +90,7 @@ void CHashingTask::Entry()
 			CFormat(wxT("Warning, failed to open file, skipping: %s")) % fullPath);
 		return;
 	}
-	
+
 	uint64 fileLength = 0;
 	try {
 		fileLength = file.GetLength();
@@ -113,10 +113,10 @@ void CHashingTask::Entry()
 			AddDebugLogLineC(logHasher,
 				CFormat(wxT("Warning, 0-size file, skipping: %s")) % fullPath);
 		}
-		
+
 		return;
 	}
-	
+
 	// For thread-safety, results are passed via a temporary file object.
 	CScopedPtr<CKnownFile> knownfile;
 	knownfile->m_filePath = m_path;
@@ -126,7 +126,7 @@ void CHashingTask::Entry()
 	knownfile->m_AvailPartFrequency.insert(
 		knownfile->m_AvailPartFrequency.begin(),
 		knownfile->GetPartCount(), 0);
-	
+
 	if ((m_toHash & EH_MD4) && (m_toHash & EH_AICH)) {
 		knownfile->GetAICHHashset()->FreeHashSet();
 		AddDebugLogLineN( logHasher, CFormat(
@@ -143,23 +143,26 @@ void CHashingTask::Entry()
 		wxCHECK_RET(0, (CFormat(wxT("No hashes requested for file, skipping: %s"))
 			% m_filename).GetString());
 	}
-	
-	
+
 	// This loops creates the part-hashes, loop-de-loop.
 	try {
 		for (uint16 part = 0; part < knownfile->GetPartCount() && !TestDestroy(); part++) {
+			SetHashingProgress(part + 1);
 			if (CreateNextPartHash(file, part, knownfile.get(), m_toHash) == false) {
 				AddDebugLogLineC(logHasher,
 					CFormat(wxT("Error while hashing file, skipping: %s"))
 						% m_filename);
-			
+
+				SetHashingProgress(0);
 				return;
 			}
 		}
 	} catch (const CSafeIOException& e) {
 		AddDebugLogLineC(logHasher, wxT("IO exception while hashing file: ") + e.what());
+		SetHashingProgress(0);
 		return;
 	}
+	SetHashingProgress(0);
 
 	if ((m_toHash & EH_MD4) && !TestDestroy()) {
 		// If the file is < PARTSIZE, then the filehash is that one hash,
@@ -176,7 +179,7 @@ void CHashingTask::Entry()
 			wxFAIL;
 		}
 	}
-	
+
 	// Did we create a AICH hashset?
 	if ((m_toHash & EH_AICH) && !TestDestroy()) {
 		CAICHHashSet* AICHHashSet = knownfile->GetAICHHashset();
@@ -189,29 +192,39 @@ void CHashingTask::Entry()
 					CFormat(wxT("Warning, failed to save AICH hashset for file: %s"))
 						% m_filename );
 			}
+			// delete hashset now to free memory
+			AICHHashSet->FreeHashSet();
 		}
 	}
-	
+
 	if ((m_toHash == EH_AICH) && !TestDestroy()) {
 		CHashingEvent evt(MULE_EVT_AICH_HASHING, knownfile.release(), m_owner);
-		
+
 		wxPostEvent(wxTheApp, evt);
 	} else if (!TestDestroy()) {
 		CHashingEvent evt(MULE_EVT_HASHING, knownfile.release(), m_owner);
-		
+
 		wxPostEvent(wxTheApp, evt);
 	}
 }
 
 
+void CHashingTask::SetHashingProgress(uint16 part)
+{
+	if (m_owner) {
+		m_owner->SetHashingProgress(part);
+	}
+}
+
+
 bool CHashingTask::CreateNextPartHash(CFileAutoClose& file, uint16 part, CKnownFile* owner, EHashes toHash)
 {
 	wxCHECK_MSG(!file.Eof(), false, wxT("Unexpected EOF in CreateNextPartHash"));
-	
+
 	const uint64 offset = part * PARTSIZE;
 	// We'll read at most PARTSIZE bytes per cycle
 	const uint64 partLength = owner->GetPartSize(part);
-	
+
 	CMD4Hash hash;
 	CMD4Hash* md4Hash = ((toHash & EH_MD4) ? &hash : NULL);
 	CAICHHashTree* aichHash = NULL;
@@ -222,15 +235,15 @@ bool CHashingTask::CreateNextPartHash(CFileAutoClose& file, uint16 part, CKnownF
 	}
 
 	owner->CreateHashFromFile(file, offset, partLength, md4Hash, aichHash);
-	
+
 	if (toHash & EH_MD4) {
 		// Store the md4 hash
 		owner->m_hashlist.push_back(hash);
-	
-		// This is because of the ed2k implementation for parts. A 2 * PARTSIZE 
-		// file i.e. will have 3 parts (see CKnownFile::SetFileSize for comments). 
+
+		// This is because of the ed2k implementation for parts. A 2 * PARTSIZE
+		// file i.e. will have 3 parts (see CKnownFile::SetFileSize for comments).
 		// So we have to create the hash for the 0-size data, which will be the default
-		// md4 hash for null data: 31D6CFE0D16AE931B73C59D7E0C089C0	
+		// md4 hash for null data: 31D6CFE0D16AE931B73C59D7E0C089C0
 		if ((partLength == PARTSIZE) && file.Eof()) {
 			owner->m_hashlist.push_back(CMD4Hash(g_emptyMD4Hash));
 		}
@@ -243,7 +256,7 @@ bool CHashingTask::CreateNextPartHash(CFileAutoClose& file, uint16 part, CKnownF
 void CHashingTask::OnLastTask()
 {
 	if (GetType() == wxT("Hashing")) {
-		// To prevent rehashing in case of crashes, we 
+		// To prevent rehashing in case of crashes, we
 		// explicity save the list of hashed files here.
 		theApp->knownfiles->Save();
 
@@ -265,13 +278,13 @@ CAICHSyncTask::CAICHSyncTask()
 void CAICHSyncTask::Entry()
 {
 	ConvertToKnown2ToKnown264();
-	
+
 	AddDebugLogLineN( logAICHThread, wxT("Syncronization thread started.") );
-	
+
 	// We collect all masterhashs which we find in the known2.met and store them in a list
 	std::list<CAICHHash> hashlist;
-	const CPath fullpath = CPath(theApp->ConfigDir + KNOWN2_MET_FILENAME);
-	
+	const CPath fullpath = CPath(thePrefs::GetConfigDir() + KNOWN2_MET_FILENAME);
+
 	CFile file;
 	if (!fullpath.FileExists()) {
 		// File does not exist. Try to create it to see if it can be created at all (and don't start hashing otherwise).
@@ -283,7 +296,7 @@ void CAICHSyncTask::Entry()
 			file.WriteUInt8(KNOWN2_MET_VERSION);
 		} catch (const CIOFailureException& e) {
 			AddDebugLogLineC(logAICHThread, wxT("IO failure while creating hashlist (Aborting): ") + e.what());
-			return;		
+			return;
 		}
 	} else {
 		if (!file.Open(fullpath, CFile::read)) {
@@ -296,7 +309,7 @@ void CAICHSyncTask::Entry()
 			if (file.ReadUInt8() != KNOWN2_MET_VERSION) {
 				throw CEOFException(wxT("Invalid met-file header found, removing file."));
 			}
-			
+
 			uint64 nExistingSize = file.GetLength();
 			while (file.GetPosition() < nExistingSize) {
 				// Read the next hash
@@ -317,10 +330,10 @@ void CAICHSyncTask::Entry()
 			file.SetLength(nLastVerifiedPos);
 		} catch (const CIOFailureException& e) {
 			AddDebugLogLineC(logAICHThread, wxT("IO failure while reading hashlist (Aborting): ") + e.what());
-		
-			return;		
+
+			return;
 		}
-	
+
 		AddDebugLogLineN( logAICHThread, wxT("Masterhashes of known files have been loaded.") );
 	}
 
@@ -335,9 +348,9 @@ bool CAICHSyncTask::ConvertToKnown2ToKnown264()
 	// converting known2.met to known2_64.met to support large files
 	// changing hashcount from uint16 to uint32
 
-	const CPath oldfullpath = CPath(theApp->ConfigDir + OLD_KNOWN2_MET_FILENAME);
-	const CPath newfullpath = CPath(theApp->ConfigDir + KNOWN2_MET_FILENAME);
-	
+	const CPath oldfullpath = CPath(thePrefs::GetConfigDir() + OLD_KNOWN2_MET_FILENAME);
+	const CPath newfullpath = CPath(thePrefs::GetConfigDir() + KNOWN2_MET_FILENAME);
+
 	if (newfullpath.FileExists() || !oldfullpath.FileExists()) {
 		// In this case, there is nothing that we need to do.
 		return false;
@@ -348,7 +361,7 @@ bool CAICHSyncTask::ConvertToKnown2ToKnown264()
 
 	if (!oldfile.Open(oldfullpath, CFile::read)) {
 		AddDebugLogLineC(logAICHThread, wxT("Failed to open 'known2.met' file."));
-		
+
 		// else -> known2.met also doesn't exists, so nothing to convert
 		return false;
 	}
@@ -356,7 +369,7 @@ bool CAICHSyncTask::ConvertToKnown2ToKnown264()
 
 	if (!newfile.Open(newfullpath, CFile::write_excl)) {
 		AddDebugLogLineC(logAICHThread, wxT("Failed to create 'known2_64.met' file."));
-		
+
 		return false;
 	}
 
@@ -365,13 +378,13 @@ bool CAICHSyncTask::ConvertToKnown2ToKnown264()
 
 	try {
 		newfile.WriteUInt8(KNOWN2_MET_VERSION);
-		
+
 		while (newfile.GetPosition() < oldfile.GetLength()) {
 			CAICHHash aichHash(&oldfile);
 			uint32 nHashCount = oldfile.ReadUInt16();
-			
+
 			CScopedArray<byte> buffer(nHashCount * CAICHHash::GetHashSize());
-			
+
 			oldfile.Read(buffer.get(), nHashCount * CAICHHash::GetHashSize());
 			newfile.Write(aichHash.GetRawHash(), CAICHHash::GetHashSize());
 			newfile.WriteUInt32(nHashCount);
@@ -385,7 +398,7 @@ bool CAICHSyncTask::ConvertToKnown2ToKnown264()
 		AddDebugLogLineC(logAICHThread, wxT("IO error while converting 'known2.met' file: ") + e.what());
 		return false;
 	}
-	
+
 	// FIXME LARGE FILES (uncomment)
 	//DeleteFile(oldfullpath);
 
@@ -411,12 +424,12 @@ CCompletionTask::CCompletionTask(const CPartFile* file)
 	wxASSERT(m_metPath.IsOk());
 	wxASSERT(m_owner);
 }
-	
+
 
 void CCompletionTask::Entry()
 {
 	CPath targetPath;
-   
+
 	{
 #ifndef AMULE_DAEMON
 		// Prevent the preference values from changing underneeth us.
@@ -424,7 +437,7 @@ void CCompletionTask::Entry()
 #else
 		//#warning Thread-safety needed
 #endif
-		
+
 		targetPath = theApp->glob_prefs->GetCategory(m_category)->path;
 		if (!targetPath.DirExists()) {
 			targetPath = thePrefs::GetIncomingDir();
@@ -441,7 +454,7 @@ void CCompletionTask::Entry()
 	if (m_filename != dstName) {
 		AddLogLineC(CFormat(_("WARNING: The filename '%s' is invalid and has been renamed to '%s'.")) % m_filename % dstName);
 	}
-	
+
 	// Avoid saving to an already existing filename
 	CPath newName = targetPath.JoinPaths(dstName);
 	for (unsigned count = 0; newName.FileExists(); ++count) {
@@ -461,13 +474,13 @@ void CCompletionTask::Entry()
 			m_error = true;
 			return;
 		}
-		
+
 		if (!CPath::RemoveFile(partfilename)) {
 			AddDebugLogLineC(logPartFile, CFormat(wxT("WARNING: Could not remove original '%s' after creating backup")) % partfilename);
 		}
 	}
 
-	// Removes the various other data-files	
+	// Removes the various other data-files
 	const wxChar* otherMetExt[] = { wxT(""), PARTMET_BAK_EXT, wxT(".seeds"), NULL };
 	for (size_t i = 0; otherMetExt[i]; ++i) {
 		CPath toRemove = m_metPath.AppendExt(otherMetExt[i]);
@@ -487,7 +500,7 @@ void CCompletionTask::OnExit()
 {
 	// Notify the app that the completion has finished for this file.
 	CCompletionEvent evt(m_error, m_owner, m_newName);
-	
+
 	wxPostEvent(wxTheApp, evt);
 }
 
@@ -547,7 +560,7 @@ void CAllocateFileTask::Entry()
 	CFile file;
 	file.Open(m_file->GetFullName().RemoveExt(), CFile::read_write);
 
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
 	try {
 		// File is already created as non-sparse, so we only need to set the length.
 		// This will fail to allocate the file e.g. under wine on linux/ext3,
@@ -673,12 +686,12 @@ bool CCompletionEvent::ErrorOccured() const
 	return m_error;
 }
 
-	
+
 const CPartFile* CCompletionEvent::GetOwner() const
 {
 	return m_owner;
 }
-	
+
 
 const CPath& CCompletionEvent::GetFullPath() const
 {
