@@ -1,8 +1,8 @@
 //
 // This file is part of the aMule Project.
-// 
-// Copyright (C) 2005-2006aMule Team ( admin@amule.org / http://www.amule.org )
-// Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
+//
+// Copyright (c) 2005-2011 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2002-2011 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
 // or contributed by third-party developers are copyrighted by their
@@ -17,38 +17,25 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
-#include <cmath>
 #include "UploadBandwidthThrottler.h"
-#include "EMSocket.h"
-#include "OPCodes.h"
+
+#include <protocol/ed2k/Constants.h>
+#include <common/Macros.h>
+#include <common/Constants.h>
+
+#include <cmath>
 #include "OtherFunctions.h"
 #include "ThrottledSocket.h"
 #include "Logger.h"
 #include "Preferences.h"
-#include "amule.h"
 #include "Statistics.h"
 
-#include <algorithm>
-#include <limits>
-
-#ifdef _UI64_MAX
-#undef _UI64_MAX
-#endif
-
-#ifdef _I64_MAX
-#undef _I64_MAX
-#endif
-
-const uint32 _UI32_MAX = std::numeric_limits<uint32>::max();
-const sint32 _I32_MAX = std::numeric_limits<sint32>::max();
-const uint64 _UI64_MAX = std::numeric_limits<uint64>::max();
-const sint64 _I64_MAX = std::numeric_limits<sint64>::max();
 
 /////////////////////////////////////
 
@@ -61,7 +48,6 @@ UploadBandwidthThrottler::UploadBandwidthThrottler()
 {
 	m_SentBytesSinceLastCall = 0;
 	m_SentBytesSinceLastCallOverhead = 0;
-	m_highestNumberOfFullyActivatedSlots = 0;
 
 	m_doRun = true;
 
@@ -112,32 +98,6 @@ uint64 UploadBandwidthThrottler::GetNumberOfSentBytesOverheadSinceLastCallAndRes
 }
 
 
-/**
- * Find out the highest number of slots that has been fed data in the normal standard loop
- * of the thread since the last call of this method. This means all slots that haven't
- * been in the trickle state during the entire time since the last call.
- *
- * @return the highest number of fully activated slots during any loop since last call
- */
-uint32 UploadBandwidthThrottler::GetHighestNumberOfFullyActivatedSlotsSinceLastCallAndReset()
-{
-	wxMutexLocker lock( m_sendLocker );
-	
-	uint32 highestNumberOfFullyActivatedSlots = m_highestNumberOfFullyActivatedSlots;
-	m_highestNumberOfFullyActivatedSlots = 0;
-
-	return highestNumberOfFullyActivatedSlots;
-}
-
-
-uint32 UploadBandwidthThrottler::GetStandardListSize()
-{
-	wxMutexLocker lock( m_sendLocker );
-	
-	return m_StandardOrder_list.size();
-};
-
-
 /**
  * Add a socket to the list of sockets that have upload slots. The main thread will
  * continously call send on these sockets, to give them chance to work off their queues.
@@ -163,7 +123,7 @@ void UploadBandwidthThrottler::AddToStandardList(uint32 index, ThrottledFileSock
 		if (index > (uint32)m_StandardOrder_list.size()) {
 			index = m_StandardOrder_list.size();
 		}
-		
+
 		m_StandardOrder_list.insert(m_StandardOrder_list.begin() + index, socket);
 	}
 }
@@ -197,14 +157,7 @@ bool UploadBandwidthThrottler::RemoveFromStandardList(ThrottledFileSocket* socke
  */
 bool UploadBandwidthThrottler::RemoveFromStandardListNoLock(ThrottledFileSocket* socket)
 {
-	// Find the slot
-	bool foundSocket = EraseFirstValue( m_StandardOrder_list, socket );
-
-	if ( foundSocket && m_highestNumberOfFullyActivatedSlots > m_StandardOrder_list.size()) {
-		m_highestNumberOfFullyActivatedSlots = m_StandardOrder_list.size();
-	}
-
-	return foundSocket;
+	return (EraseFirstValue( m_StandardOrder_list, socket ) > 0);
 }
 
 
@@ -249,7 +202,7 @@ void UploadBandwidthThrottler::DoRemoveFromAllQueues(ThrottledControlSocket* soc
 		// Remove this socket from control packet queue
 		EraseValue( m_ControlQueue_list, socket );
 		EraseValue( m_ControlQueueFirst_list, socket );
-		
+
 		wxMutexLocker lock( m_tempQueueLocker );
 		EraseValue( m_TempControlQueue_list, socket );
 		EraseValue( m_TempControlQueueFirst_list, socket );
@@ -260,7 +213,7 @@ void UploadBandwidthThrottler::DoRemoveFromAllQueues(ThrottledControlSocket* soc
 void UploadBandwidthThrottler::RemoveFromAllQueues(ThrottledControlSocket* socket)
 {
 	wxMutexLocker lock( m_sendLocker );
-	
+
 	DoRemoveFromAllQueues( socket );
 }
 
@@ -268,8 +221,8 @@ void UploadBandwidthThrottler::RemoveFromAllQueues(ThrottledControlSocket* socke
 void UploadBandwidthThrottler::RemoveFromAllQueues(ThrottledFileSocket* socket)
 {
 	wxMutexLocker lock( m_sendLocker );
-	
-	if (m_doRun) {	
+
+	if (m_doRun) {
 		DoRemoveFromAllQueues(socket);
 
 		// And remove it from upload slots
@@ -285,14 +238,16 @@ void UploadBandwidthThrottler::RemoveFromAllQueues(ThrottledFileSocket* socket)
  */
 void UploadBandwidthThrottler::EndThread()
 {
-	{
-		wxMutexLocker lock(m_sendLocker);
+	if (m_doRun) {	// do it only once
+		{
+			wxMutexLocker lock(m_sendLocker);
 
-		// signal the thread to stop looping and exit.
-		m_doRun = false;
+			// signal the thread to stop looping and exit.
+			m_doRun = false;
+		}
+
+		Wait();
 	}
-	
-	Wait();
 }
 
 
@@ -309,26 +264,21 @@ void UploadBandwidthThrottler::EndThread()
 void* UploadBandwidthThrottler::Entry()
 {
 	const uint32 TIME_BETWEEN_UPLOAD_LOOPS = 1;
-	
-	uint32 lastLoopTick = ::GetTickCountFullRes();
-	sint64 realBytesToSpend = 0;
+
+	uint32 lastLoopTick = GetTickCountFullRes();
+	// Bytes to spend in current cycle. If we spend more this becomes negative and causes a wait next time.
+	sint32 bytesToSpend = 0;
 	uint32 allowedDataRate = 0;
 	uint32 rememberedSlotCounter = 0;
-	uint32 lastTickReachedBandwidth = ::GetTickCountFullRes();
 	uint32 extraSleepTime = TIME_BETWEEN_UPLOAD_LOOPS;
-	
-	while (m_doRun) {
-		uint32 timeSinceLastLoop = ::GetTickCountFullRes() - lastLoopTick;
 
-		// Get current speed from UploadSpeedSense
+	while (m_doRun && !TestDestroy()) {
+		uint32 timeSinceLastLoop = GetTickCountFullRes() - lastLoopTick;
+
+		// Calculate data rate
 		if (thePrefs::GetMaxUpload() == UNLIMITED) {
-			// Try to increase the upload rate
-			if (theApp.uploadqueue) {
-				allowedDataRate = (uint32)theStats::GetUploadRate() + 5 * 1024;
-			} else {
-				// App not created yet or already destroyed.
-				allowedDataRate = (uint32)(-1);
-			}
+			// Try to increase the upload rate from UploadSpeedSense
+			allowedDataRate = (uint32)theStats::GetUploadRate() + 5 * 1024;
 		} else {
 			allowedDataRate = thePrefs::GetMaxUpload() * 1024;
 		}
@@ -342,54 +292,43 @@ void* UploadBandwidthThrottler::Entry()
 
 
 		uint32 sleepTime;
-		if(allowedDataRate == 0 || allowedDataRate == _UI32_MAX || realBytesToSpend >= 1000) {
-			// we could send at once, but sleep a while to not suck up all cpu
-			sleepTime = extraSleepTime;
+		if (bytesToSpend < 1) {
+			// We have sent more than allowed in last cycle so we have to wait now
+			// until we can send at least 1 byte.
+			sleepTime = std::max((-bytesToSpend + 1) * 1000 / allowedDataRate + 2, // add 2 ms to allow for rounding inaccuracies
+									extraSleepTime);
 		} else {
-			// sleep for just as long as we need to get back to having one byte to send
-			sleepTime = std::max((uint32)ceil((double)(-realBytesToSpend + 1000)/allowedDataRate), TIME_BETWEEN_UPLOAD_LOOPS);
+			// We could send at once, but sleep a while to not suck up all cpu
+			sleepTime = extraSleepTime;
 		}
 
-		if(timeSinceLastLoop < sleepTime) {
+		if (timeSinceLastLoop < sleepTime) {
 			Sleep(sleepTime-timeSinceLastLoop);
 		}
 
-		const uint32 thisLoopTick = ::GetTickCountFullRes();
-		timeSinceLastLoop = thisLoopTick - lastLoopTick;
-
-		// Calculate how many bytes we can spend
-		sint64 bytesToSpend = 0;
-
-		if(allowedDataRate != 0 && allowedDataRate != _UI32_MAX) {
-			// prevent overflow
-			if(timeSinceLastLoop == 0) {
-				// no time has passed, so don't add any bytes. Shouldn't happen.
-				bytesToSpend = 0; //realBytesToSpend/1000;
-			} else if(_I64_MAX/timeSinceLastLoop > allowedDataRate && _I64_MAX-allowedDataRate*timeSinceLastLoop > realBytesToSpend) {
-				if(timeSinceLastLoop > sleepTime + 2000) {
-					AddDebugLogLineM(false, logGeneral, wxString::Format(wxT("UploadBandwidthThrottler: Time since last loop too long. time: %ims wanted: %ims Max: %ims"), timeSinceLastLoop, sleepTime, sleepTime + 2000));
-		
-					timeSinceLastLoop = sleepTime + 2000;
-					lastLoopTick = thisLoopTick - timeSinceLastLoop;
-				}
-
-				realBytesToSpend += allowedDataRate*timeSinceLastLoop;
-
-				bytesToSpend = realBytesToSpend/1000;
-			} else {
-				realBytesToSpend = _I64_MAX;
-				bytesToSpend = _I32_MAX;
-			}
-		} else {
-			realBytesToSpend = 0; //_I64_MAX;
-			bytesToSpend = _I32_MAX;
+		// Check after sleep in case the thread has been signaled to end
+		if (!m_doRun || TestDestroy()) {
+			break;
 		}
 
+		const uint32 thisLoopTick = GetTickCountFullRes();
+		timeSinceLastLoop = thisLoopTick - lastLoopTick;
 		lastLoopTick = thisLoopTick;
 
-		if(bytesToSpend >= 1) {
-			uint64 spentBytes = 0;
-			uint64 spentOverhead = 0;
+		if (timeSinceLastLoop > sleepTime + 2000) {
+			AddDebugLogLineN(logGeneral, CFormat(wxT("UploadBandwidthThrottler: Time since last loop too long. time: %ims wanted: %ims Max: %ims"))
+				% timeSinceLastLoop % sleepTime % (sleepTime + 2000));
+
+			timeSinceLastLoop = sleepTime + 2000;
+		}
+
+		// Calculate how many bytes we can spend
+
+		bytesToSpend += (sint32) (allowedDataRate / 1000.0 * timeSinceLastLoop);
+
+		if (bytesToSpend >= 1) {
+			sint32 spentBytes = 0;
+			sint32 spentOverhead = 0;
 
 			wxMutexLocker sendLock(m_sendLocker);
 
@@ -401,134 +340,98 @@ void* UploadBandwidthThrottler::Entry()
 													m_TempControlQueueFirst_list.begin(),
 													m_TempControlQueueFirst_list.end() );
 
-				m_ControlQueue_list.insert( m_ControlQueue_list.end(), 
+				m_ControlQueue_list.insert( m_ControlQueue_list.end(),
 											m_TempControlQueue_list.begin(),
 											m_TempControlQueue_list.end() );
 
 				m_TempControlQueue_list.clear();
 				m_TempControlQueueFirst_list.clear();
 			}
-	
+
 			// Send any queued up control packets first
-			while(bytesToSpend > 0 && spentBytes < (uint64)bytesToSpend && (!m_ControlQueueFirst_list.empty() || !m_ControlQueue_list.empty())) {
+			while (spentBytes < bytesToSpend && (!m_ControlQueueFirst_list.empty() || !m_ControlQueue_list.empty())) {
 				ThrottledControlSocket* socket = NULL;
-	
-				if(!m_ControlQueueFirst_list.empty()) {
+
+				if (!m_ControlQueueFirst_list.empty()) {
 					socket = m_ControlQueueFirst_list.front();
 					m_ControlQueueFirst_list.pop_front();
-				} else if(!m_ControlQueue_list.empty()) {
+				} else if (!m_ControlQueue_list.empty()) {
 					socket = m_ControlQueue_list.front();
 					m_ControlQueue_list.pop_front();
 				}
-	
-				if(socket != NULL) {
+
+				if (socket != NULL) {
 					SocketSentBytes socketSentBytes = socket->SendControlData(bytesToSpend-spentBytes, minFragSize);
-					uint32 lastSpentBytes = socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
-					spentBytes += lastSpentBytes;
+					spentBytes += socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
 					spentOverhead += socketSentBytes.sentBytesControlPackets;
 				}
 			}
-	
+
 			// Check if any sockets haven't gotten data for a long time. Then trickle them a package.
-			for ( uint32 slotCounter = 0; slotCounter < m_StandardOrder_list.size(); slotCounter++) {
+			uint32 slots = m_StandardOrder_list.size();
+			for (uint32 slotCounter = 0; slotCounter < slots; slotCounter++) {
 				ThrottledFileSocket* socket = m_StandardOrder_list[ slotCounter ];
-	
-				if(socket != NULL) {
-					if(thisLoopTick-socket->GetLastCalledSend() > SEC2MS(1)) {
+
+				if (socket != NULL) {
+					if (thisLoopTick-socket->GetLastCalledSend() > SEC2MS(1)) {
 						// trickle
 						uint32 neededBytes = socket->GetNeededBytes();
-	
-						if(neededBytes > 0) {
-							SocketSentBytes socketSentBytes = socket->SendFileAndControlData(neededBytes, minFragSize);
-							uint32 lastSpentBytes = socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
-							spentBytes += lastSpentBytes;
-							spentOverhead += socketSentBytes.sentBytesControlPackets;
 
-							if(lastSpentBytes > 0 && slotCounter < m_highestNumberOfFullyActivatedSlots) {
-								m_highestNumberOfFullyActivatedSlots = slotCounter;
-							}
+						if (neededBytes > 0) {
+							SocketSentBytes socketSentBytes = socket->SendFileAndControlData(neededBytes, minFragSize);
+							spentBytes += socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
+							spentOverhead += socketSentBytes.sentBytesControlPackets;
 						}
 					}
 				} else {
-					AddDebugLogLineM(false, logGeneral, wxString::Format( wxT("There was a NULL socket in the UploadBandwidthThrottler Standard list (trickle)! Prevented usage. Index: %i Size: %i"), slotCounter, m_StandardOrder_list.size()) );
+					AddDebugLogLineN(logGeneral, CFormat( wxT("There was a NULL socket in the UploadBandwidthThrottler Standard list (trickle)! Prevented usage. Index: %i Size: %i"))
+						% slotCounter % m_StandardOrder_list.size());
 				}
 			}
-	
-			// Equal bandwidth for all slots
-			uint32 maxSlot = m_StandardOrder_list.size();
-			if(maxSlot > 0 && allowedDataRate/maxSlot < UPLOAD_CLIENT_DATARATE) {
-				maxSlot = allowedDataRate/UPLOAD_CLIENT_DATARATE;
-			}
 
-			if(maxSlot > m_highestNumberOfFullyActivatedSlots) {
-				m_highestNumberOfFullyActivatedSlots = maxSlot;
-			}
-
-			for(uint32 maxCounter = 0; maxCounter < std::min(maxSlot, (uint32)m_StandardOrder_list.size()) && bytesToSpend > 0 && spentBytes < (uint64)bytesToSpend; maxCounter++) {
-				if(rememberedSlotCounter >= m_StandardOrder_list.size() ||
-				   rememberedSlotCounter >= maxSlot) {
+			// Give available bandwidth to slots, starting with the one we ended with last time.
+			// There are two passes. First pass gives packets of doubleSendSize, second pass
+			// gives as much as possible.
+			// Second pass starts with the last slot of the first pass actually.
+			for (uint32 slotCounter = 0; (slotCounter < slots * 2) && spentBytes < bytesToSpend; slotCounter++) {
+				if (rememberedSlotCounter >= slots) {	// wrap around pointer
 					rememberedSlotCounter = 0;
 				}
 
+				uint32 data = (slotCounter < slots - 1)	? doubleSendSize				// pass 1
+															: (bytesToSpend - spentBytes);	// pass 2
+
 				ThrottledFileSocket* socket = m_StandardOrder_list[ rememberedSlotCounter ];
 
-				if(socket != NULL) {
-					SocketSentBytes socketSentBytes = socket->SendFileAndControlData(std::min(doubleSendSize, (uint32)(bytesToSpend-spentBytes)), doubleSendSize);
-					uint32 lastSpentBytes = socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
-
-					spentBytes += lastSpentBytes;
+				if (socket != NULL) {
+					SocketSentBytes socketSentBytes = socket->SendFileAndControlData(data, doubleSendSize);
+					spentBytes += socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
 					spentOverhead += socketSentBytes.sentBytesControlPackets;
 				} else {
-					AddDebugLogLineM(false, logGeneral, wxString::Format( wxT("There was a NULL socket in the UploadBandwidthThrottler Standard list (equal-for-all)! Prevented usage. Index: %i Size: %i"), rememberedSlotCounter, m_StandardOrder_list.size()));
+					AddDebugLogLineN(logGeneral, CFormat(wxT("There was a NULL socket in the UploadBandwidthThrottler Standard list (equal-for-all)! Prevented usage. Index: %i Size: %i"))
+						% rememberedSlotCounter % m_StandardOrder_list.size());
 				}
 
 				rememberedSlotCounter++;
 			}
 
-			// Any bandwidth that hasn't been used yet are used first to last.
-			for(uint32 slotCounter = 0; slotCounter < m_StandardOrder_list.size() && bytesToSpend > 0 && spentBytes < (uint64)bytesToSpend; slotCounter++) {
-				ThrottledFileSocket* socket = m_StandardOrder_list[ slotCounter ];
+			// Do some limiting of what we keep for the next loop.
+			bytesToSpend -= spentBytes;
+			sint32 minBytesToSpend = (slots + 1) * minFragSize;
 
-				if(socket != NULL) {
-					uint32 bytesToSpendTemp = bytesToSpend-spentBytes;
-					SocketSentBytes socketSentBytes = socket->SendFileAndControlData(bytesToSpendTemp, doubleSendSize);
-					uint32 lastSpentBytes = socketSentBytes.sentBytesControlPackets + socketSentBytes.sentBytesStandardPackets;
-					spentBytes += lastSpentBytes;
-					spentOverhead += socketSentBytes.sentBytesControlPackets;
-
-					if(slotCounter+1 > m_highestNumberOfFullyActivatedSlots && (lastSpentBytes < bytesToSpendTemp || lastSpentBytes >= doubleSendSize)) { 
-						m_highestNumberOfFullyActivatedSlots = slotCounter+1;
-					}
-				} else {
-					AddDebugLogLineM( false, logGeneral, wxString::Format( wxT("There was a NULL socket in the UploadBandwidthThrottler Standard list (fully activated)! Prevented usage. Index: %i Size: %i"), slotCounter, m_StandardOrder_list.size()));
-				}
-			}
-			realBytesToSpend -= spentBytes*1000;
-
-			if(realBytesToSpend < -(((sint64)m_StandardOrder_list.size()+1)*minFragSize)*1000) {
-				sint64 newRealBytesToSpend = -(((sint64)m_StandardOrder_list.size()+1)*minFragSize)*1000;
-	
-				realBytesToSpend = newRealBytesToSpend;
-				lastTickReachedBandwidth = thisLoopTick;
+			if (bytesToSpend < - minBytesToSpend) {
+				bytesToSpend = - minBytesToSpend;
 			} else {
-				uint64 bandwidthSavedTolerance = m_StandardOrder_list.size()*512*1000;
-				if(realBytesToSpend > 0 && (uint64)realBytesToSpend > 999+bandwidthSavedTolerance) {
-					sint64 newRealBytesToSpend = 999+bandwidthSavedTolerance;
-					realBytesToSpend = newRealBytesToSpend;
-
-					if(thisLoopTick-lastTickReachedBandwidth > std::max((uint32)1000, (uint32)timeSinceLastLoop*2)) {
-						m_highestNumberOfFullyActivatedSlots = m_StandardOrder_list.size()+1;
-						lastTickReachedBandwidth = thisLoopTick;
-					}
-				} else {
-					lastTickReachedBandwidth = thisLoopTick;
+				sint32 bandwidthSavedTolerance = slots * 512 + 1;
+				if (bytesToSpend > bandwidthSavedTolerance) {
+					bytesToSpend = bandwidthSavedTolerance;
 				}
 			}
-			
+
 			m_SentBytesSinceLastCall += spentBytes;
 			m_SentBytesSinceLastCallOverhead += spentOverhead;
 
-			if ((spentBytes == 0) and (spentOverhead == 0)) {
+			if (spentBytes == 0) {	// spentBytes includes the overhead
 				extraSleepTime = std::min<uint32>(extraSleepTime * 5, 1000); // 1s at most
 			} else {
 				extraSleepTime = TIME_BETWEEN_UPLOAD_LOOPS;
@@ -548,3 +451,4 @@ void* UploadBandwidthThrottler::Entry()
 
 	return 0;
 }
+// File_checked_for_headers
