@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -29,7 +29,7 @@
 #include <csignal>
 #include <cstring>
 #include <wx/process.h>
-#include <wx/sstream.h>	
+#include <wx/sstream.h>
 
 #ifdef HAVE_CONFIG_H
 	#include "config.h"		// Needed for HAVE_GETRLIMIT, HAVE_SETRLIMIT,
@@ -42,6 +42,7 @@
 #include <wx/cmdline.h>			// Needed for wxCmdLineParser
 #include <wx/config.h>			// Do_not_auto_remove (win32)
 #include <wx/fileconf.h>
+#include <wx/socket.h>
 #include <wx/tokenzr.h>
 #include <wx/wfstream.h>
 
@@ -154,11 +155,11 @@ static void SetResourceLimits()
 // in the signal handler.
 bool g_shutdownSignal = false;
 
-void OnShutdownSignal( int /* sig */ ) 
+void OnShutdownSignal( int /* sig */ )
 {
 	signal(SIGINT, SIG_DFL);
 	signal(SIGTERM, SIG_DFL);
-	
+
 	g_shutdownSignal = true;
 
 #ifdef AMULE_DAEMON
@@ -172,12 +173,12 @@ CamuleApp::CamuleApp()
 	// Madcat - Initialize timer as the VERY FIRST thing to avoid any issues later.
 	// Kry - I love to init the vars on init, even before timer.
 	StartTickTimer();
-	
+
 	// Initialization
 	m_app_state = APP_STATE_STARTING;
 
 	theApp = &wxGetApp();
-	
+
 	clientlist	= NULL;
 	searchlist	= NULL;
 	knownfiles	= NULL;
@@ -201,16 +202,13 @@ CamuleApp::CamuleApp()
 	m_upnpMappings.resize(4);
 #endif
 	core_timer	= NULL;
-	
+
 	m_localip	= 0;
 	m_dwPublicIP	= 0;
 	webserver_pid	= 0;
 
 	enable_daemon_fork = false;
 
-	strFullMuleVersion = NULL;
-	strOSDescription = NULL;
-	
 	// Apprently needed for *BSD
 	SetResourceLimits();
 
@@ -224,13 +222,6 @@ CamuleApp::~CamuleApp()
 	// Closing the log-file as the very last thing, since
 	// wxWidgets log-events are saved in it as well.
 	theLogger.CloseLogfile();
-
-	if (strFullMuleVersion) {
-		free(strFullMuleVersion);
-	}
-	if (strOSDescription) {
-		free(strOSDescription);
-	}
 }
 
 int CamuleApp::OnExit()
@@ -243,7 +234,7 @@ int CamuleApp::OnExit()
 	// ...
 	// Note that you must delete this object (usually in wxApp::OnExit)
 	// in order to avoid memory leaks, wxWidgets won't do it automatically.
-	// 
+	//
 	// As it happens, you may even further simplify the procedure described
 	// above: you may forget about calling Set(). When Get() is called and
 	// there is no current object, it will create one using Create() function.
@@ -331,6 +322,13 @@ int CamuleApp::OnExit()
 	delete uploadBandwidthThrottler;
 	uploadBandwidthThrottler = NULL;
 
+#ifdef ASIO_SOCKETS
+	delete m_AsioService;
+	m_AsioService = NULL;
+#endif
+
+	wxSocketBase::Shutdown();	// needed because we also called Initialize() manually
+
 	if (m_app_state!=APP_STATE_STARTING) {
 		AddLogLineNS(_("aMule shutdown completed."));
 	}
@@ -376,10 +374,10 @@ bool CamuleApp::OnInit()
 
 	// Forward wxLog events to CLogger
 	wxLog::SetActiveTarget(new CLoggerTarget);
-	
+
 	m_localip = StringHosttoUint32(::wxGetFullHostName());
 
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	// get rid of sigpipe
 	signal(SIGPIPE, SIG_IGN);
 #else
@@ -405,18 +403,21 @@ bool CamuleApp::OnInit()
 	glob_prefs = new CPreferences();
 
 	CPath outDir;
-	if (CheckMuleDirectory(wxT("temp"), thePrefs::GetTempDir(), ConfigDir + wxT("Temp"), outDir)) {
+	if (CheckMuleDirectory(wxT("temp"), thePrefs::GetTempDir(), thePrefs::GetConfigDir() + wxT("Temp"), outDir)) {
 		thePrefs::SetTempDir(outDir);
 	} else {
 		return false;
 	}
-	
-	if (CheckMuleDirectory(wxT("incoming"), thePrefs::GetIncomingDir(), ConfigDir + wxT("Incoming"), outDir)) {
+
+	if (CheckMuleDirectory(wxT("incoming"), thePrefs::GetIncomingDir(), thePrefs::GetConfigDir() + wxT("Incoming"), outDir)) {
 		thePrefs::SetIncomingDir(outDir);
 	} else {
 		return false;
 	}
 
+	// Initialize wx sockets (needed for http download in background with Asio sockets)
+	wxSocketBase::Initialize();
+
 	// Some sanity check
 	if (!thePrefs::UseTrayIcon()) {
 		thePrefs::SetMinToTray(false);
@@ -425,39 +426,52 @@ bool CamuleApp::OnInit()
 	// Build the filenames for the two OS files
 	SetOSFiles(thePrefs::GetOSDir().GetRaw());
 
+	// Check if we have the old style locale config
+	bool old_localedef = false;
+	wxString langId = thePrefs::GetLanguageID();
+	if (!langId.IsEmpty() && (langId.GetChar(0) >= '0' && langId.GetChar(0) <= '9')) {
+		old_localedef = true;
+		thePrefs::SetLanguageID(wxLang2Str(wxLANGUAGE_DEFAULT));
+		glob_prefs->Save();
+	}
+
 #ifdef ENABLE_NLS
 	// Load localization settings
 	Localize_mule();
+
+	if (old_localedef) {
+		ShowAlert(_("Your locale has been changed to System Default due to a configuration change. Sorry."), _("Info"), wxCENTRE | wxOK | wxICON_ERROR);
+	}
 #endif
 
 	// Configure EC for amuled when invoked with ec-config
 	if (ec_config) {
 		AddLogLineNS(_("\nEC configuration"));
-		thePrefs::SetECPass(GetPassword());
+		thePrefs::SetECPass(GetPassword(false).Encode());
 		thePrefs::EnableExternalConnections(true);
 		AddLogLineNS(_("Password set and external connections enabled."));
 	}
-	
-#ifndef __WXMSW__
+
+#ifndef __WINDOWS__
 	if (getuid() == 0) {
-		wxString msg = 
+		wxString msg =
 			wxT("Warning! You are running aMule as root.\n")
 			wxT("Doing so is not recommended for security reasons,\n")
 			wxT("and you are advised to run aMule as an normal\n")
 			wxT("user instead.");
-		
+
 		ShowAlert(msg, _("WARNING"), wxCENTRE | wxOK | wxICON_ERROR);
-	
+
 		fprintf(stderr, "\n--------------------------------------------------\n");
 		fprintf(stderr, "%s", (const char*)unicode2UTF8(msg));
 		fprintf(stderr, "\n--------------------------------------------------\n\n");
 	}
 #endif
-	
+
 	// Display notification on new version or first run
-	wxTextFile vfile( ConfigDir + wxT("lastversion") );
+	wxTextFile vfile( thePrefs::GetConfigDir() + wxT("lastversion") );
 	wxString newMule(wxT( VERSION ));
-	
+
 	if ( !wxFileExists( vfile.GetName() ) ) {
 		vfile.Create();
 	}
@@ -477,38 +491,30 @@ bool CamuleApp::OnInit()
 		if ( !found ) {
 			// Insert new at top to provide faster searches
 			vfile.InsertLine( newMule, 0 );
-			
+
 			Trigger_New_version( newMule );
 		}
-		
+
 		// Keep at most 10 entires
 		while ( vfile.GetLineCount() > 10 )
 			vfile.RemoveLine( vfile.GetLineCount() - 1 );
-			
+
 		vfile.Write();
 		vfile.Close();
 	}
 
-	// Check if we have the old style locale config
-	wxString langId = thePrefs::GetLanguageID();
-	if (!langId.IsEmpty() && (langId.GetChar(0) >= '0' && langId.GetChar(0) <= '9')) {
-		wxString info(_("Your locale has been changed to System Default due to a configuration change. Sorry."));
-		thePrefs::SetLanguageID(wxLang2Str(wxLANGUAGE_DEFAULT));
-		ShowAlert(info, _("Info"), wxCENTRE | wxOK | wxICON_ERROR);
-	}
-
 	m_statistics = new CStatistics();
-	
+
 	clientlist	= new CClientList();
 	friendlist	= new CFriendList();
 	searchlist	= new CSearchList();
 	knownfiles	= new CKnownFileList();
 	canceledfiles	= new CCanceledFileList;
 	serverlist	= new CServerList();
-	
+
 	sharedfiles	= new CSharedFileList(knownfiles);
 	clientcredits	= new CClientCreditsList();
-	
+
 	// bugfix - do this before creating the uploadqueue
 	downloadqueue	= new CDownloadQueue();
 	uploadqueue	= new CUploadQueue();
@@ -524,16 +530,16 @@ bool CamuleApp::OnInit()
 	// Test if there's any new version
 	if (thePrefs::GetCheckNewVersion()) {
 		// We use the thread base because I don't want a dialog to pop up.
-		CHTTPDownloadThread* version_check = 
+		CHTTPDownloadThread* version_check =
 			new CHTTPDownloadThread(wxT("http://amule.sourceforge.net/lastversion"),
-				theApp->ConfigDir + wxT("last_version_check"), theApp->ConfigDir + wxT("last_version"), HTTP_VersionCheck, false, false);
+				thePrefs::GetConfigDir() + wxT("last_version_check"), thePrefs::GetConfigDir() + wxT("last_version"), HTTP_VersionCheck, false, false);
 		version_check->Create();
 		version_check->Run();
 	}
 
 	// Create main dialog, or fork to background (daemon).
 	InitGui(m_geometryEnabled, m_geometryString);
-	
+
 #ifdef AMULE_DAEMON
 	// Need to refresh wxSingleInstanceChecker after the daemon fork() !
 	if (enable_daemon_fork) {
@@ -542,25 +548,29 @@ bool CamuleApp::OnInit()
 	}
 #endif
 
-	// Has to be created after the call to InitGui, as fork 
+	// Has to be created after the call to InitGui, as fork
 	// (when using posix threads) only replicates the mainthread,
 	// and the UBT constructor creates a thread.
 	uploadBandwidthThrottler = new UploadBandwidthThrottler();
-	
+
+#ifdef ASIO_SOCKETS
+	m_AsioService = new CAsioService;
+#endif
+
 	// Start performing background tasks
 	// This will start loading the IP filter. It will start right away.
 	// Log is confusing, because log entries from background will only be printed
-	// once foreground becomes idle, and that will only be after loading 
+	// once foreground becomes idle, and that will only be after loading
 	// of the partfiles has finished.
 	CThreadScheduler::Start();
-	
+
 	// These must be initialized after the gui is loaded.
 	if (thePrefs::GetNetworkED2K()) {
 		serverlist->Init();
 	}
 	downloadqueue->LoadMetFiles(thePrefs::GetTempDir());
 	sharedfiles->Reload();
-	
+
 	// Ensure that the up/down ratio is used
 	CPreferences::CheckUlDlRatio();
 
@@ -569,11 +579,10 @@ bool CamuleApp::OnInit()
 
 	// The user can start pressing buttons like mad if he feels like it.
 	m_app_state = APP_STATE_RUNNING;
-	
+
 	if (!serverlist->GetServerCount() && thePrefs::GetNetworkED2K()) {
 		// There are no servers and ED2K active -> ask for download.
 		// As we cannot ask in amuled, we just update there
-		// Kry TODO: Store server.met URL on preferences and use it here and in GUI.
 #ifndef AMULE_DAEMON
 		if (wxYES == wxMessageBox(
 			wxString(
@@ -583,15 +592,11 @@ bool CamuleApp::OnInit()
 			static_cast<wxWindow*>(theApp->amuledlg)))
 #endif
 		{
-		// workaround amuled crash
-#ifndef AMULE_DAEMON
-			serverlist->UpdateServerMetFromURL(
-				wxT("http://gruk.org/server.met.gz"));
-#endif
+			serverlist->UpdateServerMetFromURL(thePrefs::GetEd2kServersUrl());
 		}
 	}
-	
-	
+
+
 	// Autoconnect if that option is enabled
 	if (thePrefs::DoAutoConnect()) {
 		// IP filter is still loading and will be finished on event.
@@ -611,7 +616,7 @@ bool CamuleApp::OnInit()
 
 	// Run webserver?
 	if (thePrefs::GetWSIsEnabled()) {
-		wxString aMuleConfigFile = ConfigDir + m_configFile;
+		wxString aMuleConfigFile = thePrefs::GetConfigDir() + m_configFile;
 		wxString amulewebPath = thePrefs::GetWSPath();
 
 #if defined(__WXMAC__) && !defined(AMULE_DAEMON)
@@ -635,7 +640,7 @@ bool CamuleApp::OnInit()
 		}
 #endif
 
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
 #	define QUOTE	wxT("\"")
 #else
 #	define QUOTE	wxT("\'")
@@ -667,12 +672,12 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 {
 	bool ok = true;
 	static bool firstTime = true;
-	
+
 	if (!firstTime) {
 		// TODO: Destroy previously created sockets
 	}
 	firstTime = false;
-	
+
 	// Some sanity checks first
 	if (thePrefs::ECPort() == thePrefs::GetPort()) {
 		// Select a random usable port in the range 1025 ... 2^16 - 1
@@ -681,10 +686,10 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 			port = (uint16)rand();
 		}
 		thePrefs::SetECPort( port );
-		
+
 		wxString err =
 			wxT("Network configuration failed! You cannot use the same port\n")
-			wxT("for the main TCP port and the External Connections port.\n") 
+			wxT("for the main TCP port and the External Connections port.\n")
 			wxT("The EC port has been changed to avoid conflict, see the\n")
 			wxT("preferences for the new value.\n");
 		*msg << err;
@@ -695,7 +700,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 
 		ok = false;
 	}
-	
+
 	if (thePrefs::GetUDPPort() == thePrefs::GetPort() + 3) {
 		// Select a random usable value in the range 1025 ... 2^16 - 1
 		uint16 port = thePrefs::GetUDPPort();
@@ -704,7 +709,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 		}
 		thePrefs::SetUDPPort( port );
 
-		wxString err = 
+		wxString err =
 			wxT("Network configuration failed! You set your UDP port to\n")
 			wxT("the value of the main TCP port plus 3.\n")
 			wxT("This port has been reserved for the Server-UDP port. The\n")
@@ -715,10 +720,10 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 		AddLogLineN(wxEmptyString );
 		AddLogLineC(err );
 		AddLogLineN(wxEmptyString );
-		
+
 		ok = false;
 	}
-	
+
 	// Create the address where we are going to listen
 	// TODO: read this from configuration file
 	amuleIPV4Address myaddr[4];
@@ -731,7 +736,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 	}
 	myaddr[0].Service(thePrefs::ECPort());
 	ECServerHandler = new ExternalConn(myaddr[0], msg);
-	
+
 	// Create the UDP socket TCP+3.
 	// Used for source asking on servers.
 	if (thePrefs::GetAddress().IsEmpty()) {
@@ -739,7 +744,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 	} else if (!myaddr[1].Hostname(thePrefs::GetAddress())) {
 		myaddr[1].AnyAddress();
 		AddLogLineC(CFormat(_("Could not bind ports to the specified address: %s"))
-			% thePrefs::GetAddress());				
+			% thePrefs::GetAddress());
 	}
 
 	wxString ip = myaddr[1].IPAddress();
@@ -747,7 +752,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 	serverconnect = new CServerConnect(serverlist, myaddr[1]);
 	*msg << CFormat( wxT("*** Server UDP socket (TCP+3) at %s:%u\n") )
 		% ip % ((unsigned int)thePrefs::GetPort() + 3u);
-	
+
 	// Create the ListenSocket (aMule TCP socket).
 	// Used for Client Port / Connections from other clients,
 	// Client to Client Source Exchange.
@@ -757,12 +762,9 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 	listensocket = new CListenSocket(myaddr[2]);
 	*msg << CFormat( wxT("*** TCP socket (TCP) listening on %s:%u\n") )
 		% ip % (unsigned int)(thePrefs::GetPort());
-	// This command just sets a flag to control maximum number of connections.
 	// Notify(true) has already been called to the ListenSocket, so events may
 	// be already comming in.
-	if (listensocket->Ok()) {
-		listensocket->StartListening();
-	} else {
+	if (!listensocket->IsOk()) {
 		// If we wern't able to start listening, we need to warn the user
 		wxString err;
 		err = CFormat(_("Port %u is not available. You will be LOWID\n")) %
@@ -771,7 +773,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 		AddLogLineC(err);
 		err.Clear();
 		err = CFormat(
-			_("Port %u is not available!\n\nThis means that you will be LOWID.\n\nCheck your network to make sure the port is open for output and input.")) % 
+			_("Port %u is not available!\n\nThis means that you will be LOWID.\n\nCheck your network to make sure the port is open for output and input.")) %
 			(unsigned int)(thePrefs::GetPort());
 		ShowAlert(err, _("ERROR"), wxOK | wxICON_ERROR);
 	}
@@ -788,7 +790,7 @@ bool CamuleApp::ReinitializeNetwork(wxString* msg)
 			% ip % thePrefs::GetUDPPort();
 	} else {
 		*msg << wxT("*** Client UDP socket (extended eMule) disabled on preferences");
-	}	
+	}
 
 #ifdef ENABLE_UPNP
 	if (thePrefs::GetUPnPEnabled()) {
@@ -847,7 +849,7 @@ void CamuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 
 	wxTextFile amulesig_out;
 	wxTextFile emulesig_out;
-	
+
 	// Open both files if needed
 	if ( !emulesig_out.Create( m_emulesig_path) ) {
 		AddLogLineC(_("Failed to create OnlineSig File"));
@@ -867,7 +869,7 @@ void CamuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 
 	wxString emulesig_string;
 	wxString temp;
-	
+
 	if (zero) {
 		emulesig_string = wxT("0\xA0.0|0.0|0");
 		amulesig_out.AddLine(wxT("0\n0\n0\n0\n0\n0\n0.0\n0.0\n0\n0"));
@@ -875,7 +877,7 @@ void CamuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 		if (IsConnectedED2K()) {
 
 			temp = CFormat(wxT("%d")) % serverconnect->GetCurrentServer()->GetPort();
-			
+
 			// We are online
 			emulesig_string =
 				// Connected
@@ -947,7 +949,7 @@ void CamuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 		// Number of users waiting for upload
 		temp = CFormat(wxT("%d")) % theStats::GetWaitingUserCount();
 
-		emulesig_string += temp; 
+		emulesig_string += temp;
 		amulesig_out.AddLine(temp);
 
 		// Number of shared files (not on eMule)
@@ -1003,21 +1005,23 @@ void CamuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 void CamuleApp::OnFatalException()
 {
 	/* Print the backtrace */
-	fprintf(stderr, "\n--------------------------------------------------------------------------------\n");	
-	fprintf(stderr, "A fatal error has occurred and aMule has crashed.\n");
-	fprintf(stderr, "Please assist us in fixing this problem by posting the backtrace below in our\n");
-	fprintf(stderr, "'aMule Crashes' forum and include as much information as possible regarding the\n");
-	fprintf(stderr, "circumstances of this crash. The forum is located here:\n");
-	fprintf(stderr, "    http://forum.amule.org/index.php?board=67.0\n");
-	fprintf(stderr, "If possible, please try to generate a real backtrace of this crash:\n");
-	fprintf(stderr, "    http://wiki.amule.org/index.php/Backtraces\n\n");
-	fprintf(stderr, "----------------------------=| BACKTRACE FOLLOWS: |=----------------------------\n");
-	fprintf(stderr, "Current version is: %s\n", strFullMuleVersion);
-	fprintf(stderr, "Running on: %s\n\n", strOSDescription);
-	
-	print_backtrace(1); // 1 == skip this function.
-	
-	fprintf(stderr, "\n--------------------------------------------------------------------------------\n");	
+	wxString msg;
+	msg	<< wxT("\n--------------------------------------------------------------------------------\n")
+		<< wxT("A fatal error has occurred and aMule has crashed.\n")
+		<< wxT("Please assist us in fixing this problem by posting the backtrace below in our\n")
+		<< wxT("'aMule Crashes' forum and include as much information as possible regarding the\n")
+		<< wxT("circumstances of this crash. The forum is located here:\n")
+		<< wxT("    http://forum.amule.org/index.php?board=67.0\n")
+		<< wxT("If possible, please try to generate a real backtrace of this crash:\n")
+		<< wxT("    http://wiki.amule.org/wiki/Backtraces\n\n")
+		<< wxT("----------------------------=| BACKTRACE FOLLOWS: |=----------------------------\n")
+		<< wxT("Current version is: ") << FullMuleVersion
+		<< wxT("\nRunning on: ") << OSDescription
+		<< wxT("\n\n")
+		<< get_backtrace(1) // 1 == skip this function.
+		<< wxT("\n--------------------------------------------------------------------------------\n");
+
+	theLogger.EmergencyLog(msg, true);
 }
 #endif
 
@@ -1043,7 +1047,7 @@ void CamuleApp::Trigger_New_version(wxString new_version)
 		info += _("we give no warranty it won't break anything, burn your house,\n");
 		info += _("or kill your dog. But it *should* be safe to use anyway.\n");
 	}
-	
+
 	// General info
 	info += wxT("\n");
 	info += _("More information, support and new releases can found at our homepage,\n");
@@ -1055,7 +1059,7 @@ void CamuleApp::Trigger_New_version(wxString new_version)
 }
 
 
-void CamuleApp::SetOSFiles(const wxString new_path)
+void CamuleApp::SetOSFiles(const wxString& new_path)
 {
 	if ( thePrefs::IsOnlineSignatureEnabled() ) {
 		if ( ::wxDirExists(new_path) ) {
@@ -1077,26 +1081,27 @@ void CamuleApp::SetOSFiles(const wxString new_path)
 #ifndef wxUSE_STACKWALKER
 #define wxUSE_STACKWALKER 0
 #endif
-void CamuleApp::OnAssertFailure(const wxChar* file, int line, 
+void CamuleApp::OnAssertFailure(const wxChar* file, int line,
 				const wxChar* func, const wxChar* cond, const wxChar* msg)
 {
-	if (!wxUSE_STACKWALKER || !wxThread::IsMain() || !IsRunning()) {
-		wxString errmsg = CFormat( wxT("%s:%s:%d: Assertion '%s' failed. %s") )
-			% file % func % line % cond % ( msg ? msg : wxT("") );
+	wxString errmsg = CFormat( wxT("Assertion failed: %s:%s:%d: Assertion '%s' failed. %s\nBacktrace follows:\n%s\n") )
+		% file % func % line % cond % ( msg ? msg : wxT("") )
+		% get_backtrace(2);		// Skip the function-calls directly related to the assert call.
+	theLogger.EmergencyLog(errmsg, false);
 
-		fprintf(stderr, "Assertion failed: %s\n", (const char*)unicode2char(errmsg));
-		
-		// Skip the function-calls directly related to the assert call.
-		fprintf(stderr, "\nBacktrace follows:\n");
-		print_backtrace(3);
-		fprintf(stderr, "\n");
-	}
-		
 	if (wxThread::IsMain() && IsRunning()) {
 		AMULE_APP_BASE::OnAssertFailure(file, line, func, cond, msg);
-	} else {	
+	} else {
+#ifdef _MSC_VER
+		wxString s = CFormat(wxT("%s in %s")) % cond % func;
+		if (msg) {
+			s << wxT(" : ") << msg;
+		}
+		_wassert(s.wc_str(), file, line);
+#else
 		// Abort, allows gdb to catch the assertion
 		raise( SIGABRT );
+#endif
 	}
 }
 #endif
@@ -1104,7 +1109,7 @@ void CamuleApp::OnAssertFailure(const wxChar* file, int line,
 
 void CamuleApp::OnUDPDnsDone(CMuleInternalEvent& evt)
 {
-	CServerUDPSocket* socket =(CServerUDPSocket*)evt.GetClientData();	
+	CServerUDPSocket* socket =reinterpret_cast<CServerUDPSocket*>(evt.GetClientData());
 	socket->OnHostnameResolved(evt.GetExtraLong());
 }
 
@@ -1161,7 +1166,7 @@ void CamuleApp::OnCoreTimer(CTimerEvent& WXUNUSED(evt))
 #endif
 
 	// There is a theoretical chance that the core time function can recurse:
-	// if an event function gets blocked on a mutex (communicating with the 
+	// if an event function gets blocked on a mutex (communicating with the
 	// UploadBandwidthThrottler) wx spawns a new event loop and processes more events.
 	// If CPU load gets high a new core timer event could be generated before the last
 	// one was finished and so recursion could occur, which would be bad.
@@ -1184,20 +1189,20 @@ void CamuleApp::OnCoreTimer(CTimerEvent& WXUNUSED(evt))
 		// history list keeps an average of one node per second and gets thinned out
 		// correctly as time progresses.
 		msPrevHist += 1000;
-		
+
 		m_statistics->RecordHistory();
-		
+
 	}
-	
-	
+
+
 	if (msCur-msPrev1 > 1000) {  // approximately every second
 		msPrev1 = msCur;
 		clientcredits->Process();
 		clientlist->Process();
-		
+
 		// Publish files to server if needed.
 		sharedfiles->Process();
-		
+
 		if( Kademlia::CKademlia::IsRunning() ) {
 			Kademlia::CKademlia::Process();
 			if(Kademlia::CKademlia::GetPrefs()->HasLostConnection()) {
@@ -1209,7 +1214,7 @@ void CamuleApp::OnCoreTimer(CTimerEvent& WXUNUSED(evt))
 				}
 			}
 		}
-			
+
 		if( serverconnect->IsConnecting() && !serverconnect->IsSingleConnect() ) {
 			serverconnect->TryAnotherConnectionrequest();
 		}
@@ -1217,10 +1222,10 @@ void CamuleApp::OnCoreTimer(CTimerEvent& WXUNUSED(evt))
 			serverconnect->CheckForTimeout();
 		}
 		listensocket->UpdateConnectionsStatus();
-		
+
 	}
 
-	
+
 	if (msCur-msPrev5 > 5000) {  // every 5 seconds
 		msPrev5 = msCur;
 		listensocket->Process();
@@ -1233,17 +1238,17 @@ void CamuleApp::OnCoreTimer(CTimerEvent& WXUNUSED(evt))
 
 	// Special
 	if (msCur - msPrevOS >= thePrefs::GetOSUpdate() * 1000ull) {
-		OnlineSig(); // Added By Bouc7		
+		OnlineSig(); // Added By Bouc7
 		msPrevOS = msCur;
 	}
-	
+
 	if (msCur - msPrevKnownMet >= 30*60*1000/*There must be a prefs option for this*/) {
 		// Save Shared Files data
 		knownfiles->Save();
 		msPrevKnownMet = msCur;
 	}
 
-	
+
 	// Recomended by lugdunummaster himself - from emule 0.30c
 	serverconnect->KeepConnectionAlive();
 
@@ -1255,10 +1260,10 @@ void CamuleApp::OnCoreTimer(CTimerEvent& WXUNUSED(evt))
 void CamuleApp::OnFinishedHashing(CHashingEvent& evt)
 {
 	wxCHECK_RET(evt.GetResult(), wxT("No result of hashing"));
-	
+
 	CKnownFile* owner = const_cast<CKnownFile*>(evt.GetOwner());
 	CKnownFile* result = evt.GetResult();
-	
+
 	if (owner) {
 		// Check if the partfile still exists, as it might have
 		// been deleted in the mean time.
@@ -1276,8 +1281,8 @@ void CamuleApp::OnFinishedHashing(CHashingEvent& evt)
 			sharedfiles->SafeAddKFile(result);
 
 			bytecount += result->GetFileSize();
-			// If we have added files with a total size of ~300mb
-			if (bytecount >= 314572800) {
+			// If we have added files with a total size of ~3000mb
+			if (bytecount >= wxULL(3145728000)) {
 				AddDebugLogLineN(logKnownFiles, wxT("Failsafe for crash on file hashing creation"));
 				if ( m_app_state != APP_STATE_SHUTTINGDOWN ) {
 					knownfiles->Save();
@@ -1296,10 +1301,10 @@ void CamuleApp::OnFinishedHashing(CHashingEvent& evt)
 void CamuleApp::OnFinishedAICHHashing(CHashingEvent& evt)
 {
 	wxCHECK_RET(evt.GetResult(), wxT("No result of AICH-hashing"));
-	
+
 	CKnownFile* owner = const_cast<CKnownFile*>(evt.GetOwner());
 	CScopedPtr<CKnownFile> result(evt.GetResult());
-	
+
 	if (result->GetAICHHashset()->GetStatus() == AICH_HASHSETCOMPLETE) {
 		CAICHHashSet* oldSet = owner->GetAICHHashset();
 		CAICHHashSet* newSet = result->GetAICHHashset();
@@ -1318,7 +1323,7 @@ void CamuleApp::OnFinishedCompletion(CCompletionEvent& evt)
 	CPartFile* completed = const_cast<CPartFile*>(evt.GetOwner());
 	wxCHECK_RET(completed, wxT("Completion event sent for unspecified file"));
 	wxASSERT_MSG(downloadqueue->IsPartFile(completed), wxT("CCompletionEvent for unknown partfile."));
-	
+
 	completed->CompleteFileEnded(evt.ErrorOccured(), evt.GetFullPath());
 	if (evt.ErrorOccured()) {
 		CUserEvents::ProcessEvent(CUserEvents::ErrorOnCompletion, completed);
@@ -1372,9 +1377,15 @@ void CamuleApp::ShutDown()
 
 	// Signal the hashing thread to terminate
 	m_app_state = APP_STATE_SHUTTINGDOWN;
-	
+
+	// Stop ASIO thread
+#ifdef ASIO_SOCKETS			// only needed to suppress the log message in non-Asio build
+	AddDebugLogLineN(logGeneral, wxT("Terminate ASIO thread."));
+	m_AsioService->Stop();
+#endif
+
 	StopKad();
-	
+
 	// Kry - Save the sources seeds on app exit
 	if (thePrefs::GetSrcSeedsOn()) {
 		downloadqueue->SaveSourceSeeds();
@@ -1394,9 +1405,9 @@ void CamuleApp::ShutDown()
 	// Close sockets to avoid new clients coming in
 	if (listensocket) {
 		listensocket->Close();
-		listensocket->KillAllSockets();	
+		listensocket->KillAllSockets();
 	}
-	
+
 	if (serverconnect) {
 		serverconnect->Disconnect();
 	}
@@ -1410,7 +1421,7 @@ void CamuleApp::ShutDown()
 		}
 	}
 #endif
-	
+
 	// saving data & stuff
 	if (knownfiles) {
 		knownfiles->Save();
@@ -1418,13 +1429,13 @@ void CamuleApp::ShutDown()
 
 	theStats::Save();
 
-	CPath configFileName = CPath(ConfigDir + m_configFile);
+	CPath configFileName = CPath(thePrefs::GetConfigDir() + m_configFile);
 	CPath::BackupFile(configFileName, wxT(".bak"));
 
 	if (clientlist) {
 		clientlist->DeleteAll();
 	}
-	
+
 	// Log
 	AddDebugLogLineN(logGeneral, wxT("CamuleApp::ShutDown() has ended."));
 }
@@ -1449,15 +1460,15 @@ uint32 CamuleApp::GetPublicIP(bool ignorelocal) const
 			return ignorelocal ? 0 : m_localip;
 		}
 	}
-	
-	return m_dwPublicIP;	
+
+	return m_dwPublicIP;
 }
 
 
 void CamuleApp::SetPublicIP(const uint32 dwIP)
 {
 	wxASSERT((dwIP == 0) || !IsLowID(dwIP));
-	
+
 	if (dwIP != 0 && dwIP != m_dwPublicIP && serverlist != NULL) {
 		m_dwPublicIP = dwIP;
 		serverlist->CheckForExpiredUDPKeys();
@@ -1470,7 +1481,7 @@ void CamuleApp::SetPublicIP(const uint32 dwIP)
 wxString CamuleApp::GetLog(bool reset)
 {
 	wxFile logfile;
-	logfile.Open(ConfigDir + wxT("logfile"));
+	logfile.Open(thePrefs::GetConfigDir() + wxT("logfile"));
 	if ( !logfile.IsOpened() ) {
 		return _("ERROR: can't open logfile");
 	}
@@ -1493,7 +1504,7 @@ wxString CamuleApp::GetLog(bool reset)
 	delete [] tmp_buffer;
 	if ( reset ) {
 		theLogger.CloseLogfile();
-		if (theLogger.OpenLogfile(ConfigDir + wxT("logfile"))) {
+		if (theLogger.OpenLogfile(thePrefs::GetConfigDir() + wxT("logfile"))) {
 			AddLogLineN(_("Log has been reset"));
 		}
 		ECServerHandler->ResetAllLogs();
@@ -1532,7 +1543,11 @@ void CamuleApp::OnFinishedHTTPDownload(CMuleInternalEvent& event)
 			ipfilter->DownloadFinished(event.GetExtraLong());
 			break;
 		case HTTP_ServerMet:
-			serverlist->DownloadFinished(event.GetExtraLong());
+			if (serverlist->DownloadFinished(event.GetExtraLong()) && !IsConnectedED2K()) {
+				// If successfully downloaded a server list, and are not connected at the moment, try to connect.
+				// This happens when no server met is available on startup.
+				serverconnect->ConnectToAnyServer();
+			}
 			break;
 		case HTTP_ServerMetAuto:
 			serverlist->AutoDownloadFinished(event.GetExtraLong());
@@ -1542,8 +1557,8 @@ void CamuleApp::OnFinishedHTTPDownload(CMuleInternalEvent& event)
 			break;
 		case HTTP_NodesDat:
 			if (event.GetExtraLong() == HTTP_Success) {
-				
-				wxString file = ConfigDir + wxT("nodes.dat");
+
+				wxString file = thePrefs::GetConfigDir() + wxT("nodes.dat");
 				if (wxFileExists(file)) {
 					wxRemoveFile(file);
 				}
@@ -1553,10 +1568,10 @@ void CamuleApp::OnFinishedHTTPDownload(CMuleInternalEvent& event)
 				}
 
 				wxRenameFile(file + wxT(".download"),file);
-				
+
 				Kademlia::CKademlia::Start();
 				theApp->ShowConnectionState();
-				
+			// cppcheck-suppress duplicateBranch
 			} else if (event.GetExtraLong() == HTTP_Skipped) {
 				AddLogLineN(CFormat(_("Skipped download of %s, because requested file is not newer.")) % wxT("nodes.dat"));
 			} else {
@@ -1574,11 +1589,11 @@ void CamuleApp::OnFinishedHTTPDownload(CMuleInternalEvent& event)
 }
 
 void CamuleApp::CheckNewVersion(uint32 result)
-{	
+{
 	if (result == HTTP_Success) {
-		wxString filename = ConfigDir + wxT("last_version_check");
+		wxString filename = thePrefs::GetConfigDir() + wxT("last_version_check");
 		wxTextFile file;
-		
+
 		if (!file.Open(filename)) {
 			AddLogLineC(_("Failed to open the downloaded version check file") );
 			return;
@@ -1587,9 +1602,9 @@ void CamuleApp::CheckNewVersion(uint32 result)
 		} else {
 			wxString versionLine = file.GetFirstLine();
 			wxStringTokenizer tkz(versionLine, wxT("."));
-			
+
 			AddDebugLogLineN(logGeneral, wxString(wxT("Running: ")) + wxT(VERSION) + wxT(", Version check: ") + versionLine);
-			
+
 			long fields[] = {0, 0, 0};
 			for (int i = 0; i < 3; ++i) {
 				if (!tkz.HasMoreTokens()) {
@@ -1597,7 +1612,7 @@ void CamuleApp::CheckNewVersion(uint32 result)
 					return;
 				} else {
 					wxString token = tkz.GetNextToken();
-					
+
 					if (!token.ToLong(&fields[i])) {
 						AddLogLineC(_("Corrupted version check file"));
 						return;
@@ -1607,9 +1622,10 @@ void CamuleApp::CheckNewVersion(uint32 result)
 
 			long curVer = make_full_ed2k_version(VERSION_MJR, VERSION_MIN, VERSION_UPDATE);
 			long newVer = make_full_ed2k_version(fields[0], fields[1], fields[2]);
-			
+
 			if (curVer < newVer) {
 				AddLogLineC(_("You are using an outdated version of aMule!"));
+				// cppcheck-suppress zerodiv
 				AddLogLineN(CFormat(_("Your aMule version is %i.%i.%i and the latest version is %li.%li.%li")) % VERSION_MJR % VERSION_MIN % VERSION_UPDATE % fields[0] % fields[1] % fields[2]);
 				AddLogLineN(_("The latest version can always be found at http://www.amule.org"));
 				#ifdef AMULE_DAEMON
@@ -1620,13 +1636,13 @@ void CamuleApp::CheckNewVersion(uint32 result)
 				AddLogLineN(_("Your copy of aMule is up to date."));
 			}
 		}
-		
+
 		file.Close();
 		wxRemoveFile(filename);
 	} else {
 		AddLogLineC(_("Failed to download the version check file"));
-	}	
-	
+	}
+
 }
 
 
@@ -1644,7 +1660,7 @@ bool CamuleApp::IsConnectedED2K() const
 
 bool CamuleApp::IsConnectedKad() const
 {
-	return Kademlia::CKademlia::IsConnected(); 
+	return Kademlia::CKademlia::IsConnected();
 }
 
 
@@ -1733,6 +1749,11 @@ uint32	CamuleApp::GetBuddyPort() const
 	return clientlist->GetBuddyPort();
 }
 
+const Kademlia::CUInt128& CamuleApp::GetKadID() const
+{
+	return Kademlia::CKademlia::GetKadID();
+}
+
 bool CamuleApp::CanDoCallback(uint32 clientServerIP, uint16 clientServerPort)
 {
 	if (Kademlia::CKademlia::IsConnected()) {
@@ -1784,14 +1805,14 @@ bool CamuleApp::CanDoCallback(uint32 clientServerIP, uint16 clientServerPort)
 
 void CamuleApp::ShowUserCount() {
 	uint32 totaluser = 0, totalfile = 0;
-	
+
 	theApp->serverlist->GetUserFileStatus( totaluser, totalfile );
-	
+
 	wxString buffer;
-	
+
 	static const wxString s_singlenetstatusformat = _("Users: %s | Files: %s");
 	static const wxString s_bothnetstatusformat = _("Users: E: %s K: %s | Files: E: %s K: %s");
-	
+
 	if (thePrefs::GetNetworkED2K() && thePrefs::GetNetworkKademlia()) {
 		buffer = CFormat(s_bothnetstatusformat) % CastItoIShort(totaluser) % CastItoIShort(Kademlia::CKademlia::GetKademliaUsers()) % CastItoIShort(totalfile) % CastItoIShort(Kademlia::CKademlia::GetKademliaFiles());
 	} else if (thePrefs::GetNetworkED2K()) {
@@ -1806,37 +1827,39 @@ void CamuleApp::ShowUserCount() {
 }
 
 
+#ifndef ASIO_SOCKETS
 void CamuleApp::ListenSocketHandler(wxSocketEvent& event)
 {
 	{ wxCHECK_RET(listensocket, wxT("Connection-event for NULL'd listen-socket")); }
 	{ wxCHECK_RET(event.GetSocketEvent() == wxSOCKET_CONNECTION,
 		wxT("Invalid event received for listen-socket")); }
-	
+
 	if (m_app_state == APP_STATE_RUNNING) {
-		listensocket->OnAccept(0);
+		listensocket->OnAccept();
 	} else if (m_app_state == APP_STATE_STARTING) {
 		// When starting up, connection may be made before we are able
 		// to handle them. However, if these are ignored, no futher
 		// connection-events will be triggered, so we have to accept it.
-		wxSocketBase* socket = listensocket->Accept(false);
-		
+		CLibSocket* socket = listensocket->Accept(false);
+
 		wxCHECK_RET(socket, wxT("NULL returned by Accept() during startup"));
-		
+
 		socket->Destroy();
 	}
 }
+#endif
 
 
 void CamuleApp::ShowConnectionState(bool forceUpdate)
 {
 	static uint8 old_state = (1<<7); // This flag doesn't exist
-	
+
 	uint8 state = 0;
-	
+
 	if (theApp->serverconnect->IsConnected()) {
 		state |= CONNECTED_ED2K;
 	}
-	
+
 	if (Kademlia::CKademlia::IsRunning()) {
 		if (Kademlia::CKademlia::IsConnected()) {
 			if (!Kademlia::CKademlia::IsFirewalled()) {
@@ -1848,11 +1871,11 @@ void CamuleApp::ShowConnectionState(bool forceUpdate)
 			state |= CONNECTED_KAD_NOT;
 		}
 	}
-	
+
 	if (old_state != state) {
-		// Get the changed value 
+		// Get the changed value
 		int changed_flags = old_state ^ state;
-		
+
 		if (changed_flags & CONNECTED_ED2K) {
 			// ED2K status changed
 			wxString connected_server;
@@ -1866,6 +1889,7 @@ void CamuleApp::ShowConnectionState(bool forceUpdate)
 
 				AddLogLineC(CFormat(_("Connected to %s %s")) % connected_server % id);
 			} else {
+				// cppcheck-suppress duplicateBranch
 				if ( theApp->serverconnect->IsConnecting() ) {
 					AddLogLineC(CFormat(_("Connecting to %s")) % connected_server);
 				} else {
@@ -1873,17 +1897,19 @@ void CamuleApp::ShowConnectionState(bool forceUpdate)
 				}
 			}
 		}
-		
+
 		if (changed_flags & CONNECTED_KAD_NOT) {
+			// cppcheck-suppress duplicateBranch
 			if (state & CONNECTED_KAD_NOT) {
 				AddLogLineC(_("Kad started."));
 			} else {
 				AddLogLineC(_("Kad stopped."));
 			}
 		}
-		
+
 		if (changed_flags & (CONNECTED_KAD_OK | CONNECTED_KAD_FIREWALLED)) {
 			if (state & (CONNECTED_KAD_OK | CONNECTED_KAD_FIREWALLED)) {
+				// cppcheck-suppress duplicateBranch
 				if (state & CONNECTED_KAD_OK) {
 					AddLogLineC(_("Connected to Kad (ok)"));
 				} else {
@@ -1893,20 +1919,21 @@ void CamuleApp::ShowConnectionState(bool forceUpdate)
 				AddLogLineC(_("Disconnected from Kad"));
 			}
 		}
-		
+
 		old_state = state;
-	
+
 		theApp->downloadqueue->OnConnectionState(IsConnected());
 	}
-	
+
 	ShowUserCount();
 	Notify_ShowConnState(forceUpdate);
 }
 
 
+#ifndef ASIO_SOCKETS
 void CamuleApp::UDPSocketHandler(wxSocketEvent& event)
 {
-	CMuleUDPSocket* socket = (CMuleUDPSocket*)(event.GetClientData());
+	CMuleUDPSocket* socket = reinterpret_cast<CMuleUDPSocket*>(event.GetClientData());
 	wxCHECK_RET(socket, wxT("No socket owner specified."));
 
 	if (IsOnShutDown() || thePrefs::IsUDPDisabled()) return;
@@ -1927,7 +1954,7 @@ void CamuleApp::UDPSocketHandler(wxSocketEvent& event)
 		case wxSOCKET_OUTPUT:
 			socket->OnSend(0);
 			break;
-		
+
 		case wxSOCKET_LOST:
 			socket->OnDisconnected(0);
 			break;
@@ -1937,12 +1964,13 @@ void CamuleApp::UDPSocketHandler(wxSocketEvent& event)
 			break;
 	}
 }
+#endif
 
 
 void CamuleApp::OnUnhandledException()
 {
 	// Call the generic exception-handler.
-	fprintf(stderr, "\taMule Version: %s\n", (const char*)unicode2char(GetFullMuleVersion()));	
+	fprintf(stderr, "\taMule Version: %s\n", (const char*)unicode2char(GetFullMuleVersion()));
 	::OnUnhandledException();
 }
 
@@ -1979,16 +2007,16 @@ void CamuleApp::BootstrapKad(uint32 ip, uint16 port)
 		Kademlia::CKademlia::Start();
 		theApp->ShowConnectionState();
 	}
-	
+
 	Kademlia::CKademlia::Bootstrap(ip, port);
 }
 
 
 void CamuleApp::UpdateNotesDat(const wxString& url)
 {
-	wxString strTempFilename(theApp->ConfigDir + wxT("nodes.dat.download"));
-		
-	CHTTPDownloadThread *downloader = new CHTTPDownloadThread(url, strTempFilename, theApp->ConfigDir + wxT("nodes.dat"), HTTP_NodesDat, true, false);
+	wxString strTempFilename(thePrefs::GetConfigDir() + wxT("nodes.dat.download"));
+
+	CHTTPDownloadThread *downloader = new CHTTPDownloadThread(url, strTempFilename, thePrefs::GetConfigDir() + wxT("nodes.dat"), HTTP_NodesDat, true, false);
 	downloader->Create();
 	downloader->Run();
 }
@@ -2013,7 +2041,7 @@ uint32 CamuleApp::GetED2KID() const {
 
 uint32 CamuleApp::GetID() const {
 	uint32 ID;
-	
+
 	if( Kademlia::CKademlia::IsConnected() && !Kademlia::CKademlia::IsFirewalled() ) {
 		// We trust Kad above ED2K
 		ID = ENDIAN_NTOHL(Kademlia::CKademlia::GetIPAddress());
@@ -2025,8 +2053,8 @@ uint32 CamuleApp::GetID() const {
 	} else {
 		ID = 0;
 	}
-	
-	return ID;	
+
+	return ID;
 }
 
 DEFINE_LOCAL_EVENT_TYPE(wxEVT_CORE_FINISHED_HTTP_DOWNLOAD)
