@@ -34,10 +34,14 @@
 
 #include "Types.h"		// Needed for int32, uint16 and uint64
 #include <map>
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	#include <signal.h>
 //	#include <wx/unix/execute.h>
-#endif // __WXMSW__
+#endif // __WINDOWS__
+
+#ifdef HAVE_CONFIG_H
+#	include "config.h"		// Needed for ASIO_SOCKETS
+#endif
 
 
 class CAbstractFile;
@@ -63,12 +67,16 @@ class CFriendList;
 class CClientUDPSocket;
 class CIPFilter;
 class UploadBandwidthThrottler;
+#ifdef ASIO_SOCKETS
+class CAsioService;
+#else
+class wxSocketEvent;
+#endif
 #ifdef ENABLE_UPNP
 class CUPnPControlPoint;
 class CUPnPPortMapping;
 #endif
 class CStatistics;
-class wxSocketEvent;
 class wxCommandEvent;
 class wxCloseEvent;
 class wxFFileOutputStream;
@@ -87,10 +95,14 @@ namespace MuleNotify {
 	class CMuleGUIEvent;
 }
 
-
 using MuleNotify::CMuleGUIEvent;
 
 
+namespace Kademlia {
+	class CUInt128;
+}
+
+
 #ifdef AMULE_DAEMON
 #define AMULE_APP_BASE wxAppConsole
 #define CORE_TIMER_PERIOD 300
@@ -114,8 +126,8 @@ private:
 
 	bool		CheckPassedLink(const wxString &in, wxString &out, int cat);
 protected:
-	char		*strFullMuleVersion;
-	char		*strOSDescription;
+	wxString	FullMuleVersion;
+	wxString	OSDescription;
 	wxString	OSType;
 	bool		enable_daemon_fork;
 	bool		ec_config;
@@ -130,7 +142,6 @@ protected:
 	void		RefreshSingleInstanceChecker();
 	bool		CheckMuleDirectory(const wxString& desc, const class CPath& directory, const wxString& alternative, class CPath& outDir);
 public:
-	wxString	ConfigDir;
 	wxString	m_configFile;
 
 	CamuleAppCommon();
@@ -138,8 +149,7 @@ public:
 	void		AddLinksFromFile();
 	// URL functions
 	wxString	CreateMagnetLink(const CAbstractFile *f);
-	wxString	CreateED2kLink(const CAbstractFile* f, bool add_source = false, bool use_hostname = false, bool addcryptoptions = false);
-	wxString	CreateED2kAICHLink(const CKnownFile* f);
+	wxString	CreateED2kLink(const CAbstractFile* f, bool add_source = false, bool use_hostname = false, bool add_cryptoptions = false, bool add_AICH = false);
 	// Who am I ?
 #ifdef AMULE_DAEMON
 	bool		IsDaemon() const { return true; }
@@ -180,10 +190,11 @@ public:
 	// derived classes may override those
 	virtual int InitGui(bool geometry_enable, wxString &geometry_string);
 
+#ifndef ASIO_SOCKETS
 	// Socket handlers
 	void ListenSocketHandler(wxSocketEvent& event);
-	void ServerSocketHandler(wxSocketEvent& event);
 	void UDPSocketHandler(wxSocketEvent& event);
+#endif
 
 	virtual int ShowAlert(wxString msg, wxString title, int flags) = 0;
 
@@ -221,6 +232,8 @@ public:
 	uint8	GetBuddyStatus() const;
 	uint32	GetBuddyIP() const;
 	uint32	GetBuddyPort() const;
+	// Kad ID
+	const Kademlia::CUInt128& GetKadID() const;
 
 	// Check if we should callback this client
 	bool CanDoCallback(uint32 clientServerIP, uint16 clientServerPort);
@@ -259,6 +272,9 @@ public:
 	CStatistics*		m_statistics;
 	CIPFilter*		ipfilter;
 	UploadBandwidthThrottler* uploadBandwidthThrottler;
+#ifdef ASIO_SOCKETS
+	CAsioService*		m_AsioService;
+#endif
 #ifdef ENABLE_UPNP
 	CUPnPControlPoint*	m_upnp;
 	std::vector<CUPnPPortMapping> m_upnpMappings;
@@ -276,7 +292,7 @@ public:
 #ifdef __DEBUG__
 	void AddSocketDeleteDebug(uint32 socket_pointer, uint32 creation_time);
 #endif
-	void SetOSFiles(const wxString new_path);
+	void SetOSFiles(const wxString& new_path);
 
 	const wxString& GetOSType() const { return OSType; }
 
@@ -356,7 +372,6 @@ public:
 
 	wxString	m_FrameTitle;
 	CamuleDlg*	amuledlg;
-	int		m_FileDetailDialogActive;
 
 	bool CopyTextToClipboard( wxString strText );
 	void ResetTitle();
@@ -424,15 +439,24 @@ extern CamuleGuiApp *theApp;
 // but works only with 2.9
 
 #if !wxCHECK_VERSION(2, 9, 0)
-	#ifdef __WXMSW__
-		// MSW: can't run amuled with 2.8 anyway, just get it compiled
-		#define AMULED_DUMMY
-	#else
-		#define AMULED28
+	// wx 2.8 needs a hand-made event loop in any case
+	#define AMULED28_EVENTLOOP
+
+	// wx 2.8 also needs extra socket code, unless we have ASIO sockets
+	//
+	#ifdef HAVE_CONFIG_H
+	#	include "config.h"		// defines ASIO_SOCKETS
+	#endif
+
+	#ifndef ASIO_SOCKETS
+		// MSW: can't run amuled with 2.8 without ASIO sockets, just get it compiled
+		#ifndef __WINDOWS__
+			#define AMULED28_SOCKETS
+		#endif
 	#endif
 #endif
 
-#ifdef AMULED28
+#ifdef AMULED28_SOCKETS
 #include <wx/socket.h>
 
 class CSocketSet;
@@ -463,10 +487,18 @@ public:
 };
 
 
-#endif // AMULED28
+#endif // AMULED28_SOCKETS
 
-// no AppTraits used on Windows
-#ifndef __WXMSW__
+// AppTrait functionality is required for 2.8 wx sockets
+// Otherwise it's used to prevent zombie child processes,
+// which stops working with wx 2.9.5.
+// So disable it there (no idea if this has a noticeable impact).
+
+#if !wxCHECK_VERSION(2, 9, 5) && !defined(__WINDOWS__)
+#define AMULED_APPTRAITS
+#endif
+
+#ifdef AMULED_APPTRAITS
 
 typedef std::map<int, class wxEndProcessData *> EndProcessDataMap;
 
@@ -478,7 +510,7 @@ private:
 	struct sigaction m_oldSignalChildAction;
 	struct sigaction m_newSignalChildAction;
 
-#ifdef AMULED28
+#ifdef AMULED28_SOCKETS
 	CAmuledGSocketFuncTable *m_table;
 	wxMutex m_lock;
 	std::list<wxObject *> m_sched_delete;
@@ -489,10 +521,10 @@ public:
 	virtual void RemoveFromPendingDelete(wxObject *object);
 
 	void DeletePending();
-#else	// AMULED28
+#else	// AMULED28_SOCKETS
 public:
 	CDaemonAppTraits();
-#endif	// !AMULED28
+#endif	// !AMULED28_SOCKETS
 
 	virtual int WaitForChild(wxExecuteData& execData);
 
@@ -503,14 +535,17 @@ public:
 
 void OnSignalChildHandler(int signal, siginfo_t *siginfo, void *ucontext);
 pid_t AmuleWaitPid(pid_t pid, int *status, int options, wxString *msg);
-#endif // __WXMSW__
+
+#endif // AMULED_APPTRAITS
 
 
 class CamuleDaemonApp : public CamuleApp
 {
 private:
-#ifdef AMULED28
+#ifdef AMULED28_EVENTLOOP
 	bool m_Exit;
+#endif
+#ifdef AMULED28_SOCKETS
 	CAmuledGSocketFuncTable *m_table;
 #endif
 	bool OnInit();
@@ -519,25 +554,21 @@ private:
 
 	virtual int InitGui(bool geometry_enable, wxString &geometry_string);
 
-#ifndef __WXMSW__
+#ifdef AMULED_APPTRAITS
 	struct sigaction m_oldSignalChildAction;
 	struct sigaction m_newSignalChildAction;
 public:
 	wxAppTraits *CreateTraits();
-#endif // __WXMSW__
+#endif // AMULED_APPTRAITS
 
 public:
 
-#ifdef AMULED28
+#ifdef AMULED28_EVENTLOOP
 	CamuleDaemonApp();
 
 	void ExitMainLoop() { m_Exit = true; }
 #endif
 
-#ifdef AMULED_DUMMY
-	void ExitMainLoop() {}
-#endif
-
 	bool CopyTextToClipboard(wxString strText);
 
 	virtual int ShowAlert(wxString msg, wxString title, int flags);
