@@ -17,7 +17,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -26,35 +26,52 @@
 #ifndef AMULEIPV4ADDRESS_H
 #define AMULEIPV4ADDRESS_H
 
-#include <wx/object.h>			// Needed by wx/sckaddr.h
+#include "NetworkFunctions.h"	// Needed for Uint32toStringIP
 
-#include "NetworkFunctions.h"	// Needed for StringIPtoUint32
-
-class amuleIPV4Address : public wxIPV4address
+class amuleIPV4Address
 {
 public:
-	amuleIPV4Address() {}
-	amuleIPV4Address(const wxIPV4address &a) : wxIPV4address(a) {}
+	amuleIPV4Address();
+	amuleIPV4Address(const amuleIPV4Address &a);
+	amuleIPV4Address(const class CamuleIPV4Endpoint &ep);
+	virtual ~amuleIPV4Address();
+	amuleIPV4Address& operator=(const amuleIPV4Address &a);
+	amuleIPV4Address& operator=(const class CamuleIPV4Endpoint &a);
 
-	virtual bool Hostname(const wxString& name)
-	{
-		// Some people are sometimes fools.
-		if (name.IsEmpty()) {
-			return false;
-		}
-		
-		return wxIPV4address::Hostname(name);
-	}
+	virtual bool Hostname(const wxString& name);
 
-	virtual bool Hostname(uint32 ip) 
+	virtual bool Hostname(uint32 ip)
 	{
 		// Some people are sometimes fools.
 		if (!ip) {
 			return false;
 		}
-		
-		return wxIPV4address::Hostname(Uint32toStringIP(ip));
+
+		return Hostname(Uint32toStringIP(ip));
 	}
+
+
+	// Set the port to that corresponding to the specified service.
+	// Returns true on success, false if something goes wrong (invalid service).
+	virtual bool Service(uint16 service);
+
+	// Returns the current service.
+	virtual uint16 Service() const;
+
+	// Determines if current address is set to localhost.
+	virtual bool IsLocalHost() const;
+
+	// Returns a wxString containing the IP address.
+	virtual wxString IPAddress() const;
+
+	// Set address to any of the addresses of the current machine.
+	virtual bool AnyAddress();
+
+	const class CamuleIPV4Endpoint & GetEndpoint() const;
+	class CamuleIPV4Endpoint & GetEndpoint();
+
+private:
+	class CamuleIPV4Endpoint * m_endpoint;
 };
 
 #endif // AMULEIPV4ADDRESS_H
