@@ -16,7 +16,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -65,19 +65,25 @@
 #include <sys/resource.h> // Do_not_auto_remove
 #endif
 
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	#ifdef  HAVE_SYS_WAIT_H
-		#include <sys/wait.h> // Do_not_auto_remove 
+		#include <sys/wait.h> // Do_not_auto_remove
 	#endif
+	#include <wx/ffile.h>
+#endif
 
+#ifdef AMULED_APPTRAITS
 	#include <wx/unix/execute.h>
 #endif
 
+
 BEGIN_EVENT_TABLE(CamuleDaemonApp, wxAppConsole)
+
+#ifndef ASIO_SOCKETS
 	//
 	// Socket handlers
 	//
-	
+
 	// Listen Socket
 	EVT_SOCKET(ID_LISTENSOCKET_EVENT, CamuleDaemonApp::ListenSocketHandler)
 
@@ -85,6 +91,7 @@ BEGIN_EVENT_TABLE(CamuleDaemonApp, wxAppConsole)
 	EVT_SOCKET(ID_SERVERUDPSOCKET_EVENT, CamuleDaemonApp::UDPSocketHandler)
 	// UDP Socket (clients)
 	EVT_SOCKET(ID_CLIENTUDPSOCKET_EVENT, CamuleDaemonApp::UDPSocketHandler)
+#endif
 
 	// Socket timer (TCP)
 	EVT_MULE_TIMER(ID_SERVER_RETRY_TIMER_EVENT, CamuleDaemonApp::OnTCPTimer)
@@ -96,7 +103,7 @@ BEGIN_EVENT_TABLE(CamuleDaemonApp, wxAppConsole)
 
 	// Async dns handling
 	EVT_MULE_INTERNAL(wxEVT_CORE_UDP_DNS_DONE, -1, CamuleDaemonApp::OnUDPDnsDone)
-	
+
 	EVT_MULE_INTERNAL(wxEVT_CORE_SOURCE_DNS_DONE, -1, CamuleDaemonApp::OnSourceDnsDone)
 
 	EVT_MULE_INTERNAL(wxEVT_CORE_SERVER_DNS_DONE, -1, CamuleDaemonApp::OnServerDnsDone)
@@ -104,7 +111,7 @@ BEGIN_EVENT_TABLE(CamuleDaemonApp, wxAppConsole)
 	// Hash ended notifier
 	EVT_MULE_HASHING(CamuleDaemonApp::OnFinishedHashing)
 	EVT_MULE_AICH_HASHING(CamuleDaemonApp::OnFinishedAICHHashing)
-	
+
 	// File completion ended notifier
 	EVT_MULE_FILE_COMPLETED(CamuleDaemonApp::OnFinishedCompletion)
 
@@ -117,10 +124,10 @@ END_EVENT_TABLE()
 
 IMPLEMENT_APP(CamuleDaemonApp)
 
-#ifdef AMULED28
+#ifdef AMULED28_SOCKETS
 /*
  * Socket handling in wxBase
- * 
+ *
  */
 class CSocketSet {
 		int m_count;
@@ -133,9 +140,9 @@ class CSocketSet {
 		void AddSocket(GSocket *);
 		void RemoveSocket(GSocket *);
 		void FillSet(int &max_fd);
-		
+
 		void Detected(void (GSocket::*func)());
-		
+
 		fd_set *Set() { return &m_set; }
 };
 
@@ -152,7 +159,7 @@ CSocketSet::CSocketSet()
 void CSocketSet::AddSocket(GSocket *socket)
 {
 	wxASSERT(socket);
-	
+
 	int fd = socket->m_fd;
 
 	if ( fd == -1 ) {
@@ -160,7 +167,7 @@ void CSocketSet::AddSocket(GSocket *socket)
 	}
 
 	wxASSERT( (fd > 2) && (fd < FD_SETSIZE) );
-	
+
 	if ( m_gsocks[fd] ) {
 		return;
 	}
@@ -173,15 +180,15 @@ void CSocketSet::AddSocket(GSocket *socket)
 void CSocketSet::RemoveSocket(GSocket *socket)
 {
 	wxASSERT(socket);
-	
+
 	int fd = socket->m_fd;
 
 	if ( fd == -1 ) {
 		return;
 	}
-	
+
 	wxASSERT( (fd > 2) && (fd < FD_SETSIZE) );
-	
+
 	int i = m_fd_idx[fd];
 	if ( i == 0xffff ) {
 		return;
@@ -202,7 +209,7 @@ void CSocketSet::FillSet(int &max_fd)
 	for(int i = 0; i < m_count; i++) {
 	    FD_SET(m_fds[i], &m_set);
 	    if ( m_fds[i] > max_fd ) {
-	    	max_fd = m_fds[i];
+		max_fd = m_fds[i];
 	    }
 	}
 }
@@ -222,7 +229,7 @@ CAmuledGSocketFuncTable::CAmuledGSocketFuncTable() : m_lock(wxMUTEX_RECURSIVE)
 {
 	m_in_set = new CSocketSet;
 	m_out_set = new CSocketSet;
-	
+
 	m_lock.Unlock();
 }
 
@@ -259,7 +266,7 @@ void CAmuledGSocketFuncTable::RunSelect()
 	struct timeval tv;
 	tv.tv_sec = 0;
 	tv.tv_usec = 10000; // 10ms
-	
+
 	int result = select(max_fd + 1, m_in_set->Set(), m_out_set->Set(), 0, &tv);
 	if ( result > 0 ) {
 		m_in_set->Detected(&GSocket::Detected_Read);
@@ -321,11 +328,6 @@ void CAmuledGSocketFuncTable::Disable_Events(GSocket *socket)
 	Uninstall_Callback(socket, GSOCK_OUTPUT);
 }
 
-#endif	// AMULED28
-
-#ifndef __WXMSW__
-
-#ifdef AMULED28
 
 CDaemonAppTraits::CDaemonAppTraits(CAmuledGSocketFuncTable *table)
 :
@@ -378,7 +380,9 @@ wxAppTraits *CamuleDaemonApp::CreateTraits()
 	return new CDaemonAppTraits(m_table);
 }
 
-#else	// AMULED28
+#else	// AMULED28_SOCKETS
+
+#ifdef AMULED_APPTRAITS
 
 CDaemonAppTraits::CDaemonAppTraits()
 :
@@ -393,9 +397,9 @@ wxAppTraits *CamuleDaemonApp::CreateTraits()
 	return new CDaemonAppTraits();
 }
 
-#endif	// !AMULED28
+#endif	// AMULED_APPTRAITS
 
-#endif	// __WXMSW__
+#endif	// !AMULED28_SOCKETS
 
 #if defined(__WXMAC__) && !wxCHECK_VERSION(2, 9, 0)
 #include <wx/stdpaths.h> // Do_not_auto_remove (guess)
@@ -407,25 +411,26 @@ wxStandardPathsBase& CDaemonAppTraits::GetStandardPaths()
 #endif
 
 
-#ifdef AMULED28
+#ifdef AMULED28_EVENTLOOP
 
 CamuleDaemonApp::CamuleDaemonApp()
 :
-m_Exit(false),
-m_table(new CAmuledGSocketFuncTable())
+m_Exit(false)
+#ifdef AMULED28_SOCKETS
+,m_table(new CAmuledGSocketFuncTable())
+#endif
 {
+	// work around problem from http://trac.wxwidgets.org/ticket/2145
 	wxPendingEventsLocker = new wxCriticalSection;
 }
 
-#endif	// !AMULED28
+#endif	// AMULED28_EVENTLOOP
 
 
-#ifndef __WXMSW__
-
+#ifdef AMULED_APPTRAITS
 
 static EndProcessDataMap endProcDataMap;
 
-
 int CDaemonAppTraits::WaitForChild(wxExecuteData &execData)
 {
 	int status = 0;
@@ -441,7 +446,7 @@ int CDaemonAppTraits::WaitForChild(wxExecuteData &execData)
 		if (result == -1 || (!WIFEXITED(status) && !WIFSIGNALED(status))) {
 			msg << wxT(" Waiting for subprocess termination failed.");
 			AddDebugLogLineN(logGeneral, msg);
-		}	
+		}
 	} else {
 		/** wxEXEC_ASYNC */
 		// Give the process a chance to start or forked child to exit
@@ -460,7 +465,7 @@ int CDaemonAppTraits::WaitForChild(wxExecuteData &execData)
 			status = execData.pid;
 		} else {
 			// if result != 0, then either waitpid() failed (result == -1)
-			// and there is nothing we can do, or the child has changed 
+			// and there is nothing we can do, or the child has changed
 			// status, which means it is probably dead.
 			status = 0;
 		}
@@ -550,8 +555,35 @@ pid_t AmuleWaitPid(pid_t pid, int *status, int options, wxString *msg)
 	return result;
 }
 
+#endif	// AMULED_APPTRAITS
 
-#endif // __WXMSW__
+
+#ifdef __WINDOWS__
+//
+// CTRL-C-Handler
+// see http://msdn.microsoft.com/en-us/library/windows/desktop/ms685049%28v=vs.85%29.aspx
+//
+static BOOL CtrlHandler(DWORD fdwCtrlType)
+{
+	switch (fdwCtrlType) {
+		case CTRL_C_EVENT:
+		case CTRL_CLOSE_EVENT:
+		case CTRL_BREAK_EVENT:
+			// handle these
+			AddLogLineNS(wxT("Received break event, exit main loop"));
+			theApp->ExitMainLoop();
+			return TRUE;
+			break;
+		case CTRL_LOGOFF_EVENT:
+		case CTRL_SHUTDOWN_EVENT:
+		default:
+			// don't handle these
+			return FALSE;
+			break;
+	}
+}
+
+#endif // __WINDOWS__
 
 
 int CamuleDaemonApp::OnRun()
@@ -564,47 +596,52 @@ int CamuleDaemonApp::OnRun()
 		return 0;
 	}
 
-#ifndef __WXMSW__
-	// Process the return code of dead children so that we do not create 
+#ifdef __WINDOWS__
+	SetConsoleCtrlHandler((PHANDLER_ROUTINE) CtrlHandler, TRUE);
+#endif // __WINDOWS__
+
+#ifdef AMULED_APPTRAITS
+	// Process the return code of dead children so that we do not create
 	// zombies. wxBase does not implement wxProcess callbacks, so no one
 	// actualy calls wxHandleProcessTermination() in console applications.
 	// We do our best here.
-	int ret = 0;
-	ret = sigaction(SIGCHLD, NULL, &m_oldSignalChildAction);
+	DEBUG_ONLY( int ret = 0; )
+	DEBUG_ONLY( ret = ) sigaction(SIGCHLD, NULL, &m_oldSignalChildAction);
 	m_newSignalChildAction = m_oldSignalChildAction;
 	m_newSignalChildAction.sa_sigaction = OnSignalChildHandler;
 	m_newSignalChildAction.sa_flags |=  SA_SIGINFO;
 	m_newSignalChildAction.sa_flags &= ~SA_RESETHAND;
-	ret = sigaction(SIGCHLD, &m_newSignalChildAction, NULL);
+	DEBUG_ONLY( ret = ) sigaction(SIGCHLD, &m_newSignalChildAction, NULL);
+#ifdef __DEBUG__
 	if (ret == -1) {
 		AddDebugLogLineC(logStandard, CFormat(wxT("CamuleDaemonApp::OnRun(): Installation of SIGCHLD callback with sigaction() failed: %m.")));
 	} else {
 		AddDebugLogLineN(logGeneral, wxT("CamuleDaemonApp::OnRun(): Installation of SIGCHLD callback with sigaction() succeeded."));
 	}
-#endif // __WXMSW__
-	
-#ifdef AMULED28
+#endif
+#endif	// AMULED_APPTRAITS
+
+#ifdef AMULED28_EVENTLOOP
 
 	while ( !m_Exit ) {
+#ifdef AMULED28_SOCKETS
 		m_table->RunSelect();
 		ProcessPendingEvents();
 		((CDaemonAppTraits *)GetTraits())->DeletePending();
+#else
+		wxMilliSleep(10);
+		ProcessPendingEvents();
+#endif
 	}
-	
+
 	// ShutDown is beeing called twice. Once here and again in OnExit().
 	ShutDown();
 
 	return 0;
 
-#else
-
-#ifdef AMULED_DUMMY
-	return 0;
 #else
 	return wxApp::OnRun();
 #endif
-
-#endif
 }
 
 bool CamuleDaemonApp::OnInit()
@@ -617,13 +654,13 @@ bool CamuleDaemonApp::OnInit()
 	core_timer->Start(CORE_TIMER_PERIOD);
 	glob_prefs->GetCategory(0)->title = GetCatTitle(thePrefs::GetAllcatFilter());
 	glob_prefs->GetCategory(0)->path = thePrefs::GetIncomingDir();
-	
+
 	return true;
 }
 
 int CamuleDaemonApp::InitGui(bool ,wxString &)
 {
-#ifndef __WXMSW__
+#ifndef __WINDOWS__
 	if ( !enable_daemon_fork ) {
 		return 0;
 	}
@@ -636,16 +673,16 @@ int CamuleDaemonApp::InitGui(bool ,wxString &)
 	for(int i_fd = 0;i_fd < 3; i_fd++) {
 		close(i_fd);
 	}
-  	int fd = open("/dev/null",O_RDWR);
+	int fd = open("/dev/null",O_RDWR);
 	if (dup(fd)){}	// prevent GCC warning
 	if (dup(fd)){}
-  	pid_t pid = fork();
+	pid_t pid = fork();
 
 	wxASSERT(pid != -1);
 
-  	if ( pid ) {
-  		exit(0);
-  	} else {
+	if ( pid ) {
+		exit(0);
+	} else {
 		pid = setsid();
 		//
 		// Create a Pid file with the Pid of the Child, so any daemon-manager
@@ -661,8 +698,8 @@ int CamuleDaemonApp::InitGui(bool ,wxString &)
 				AddLogLineNS(_("Cannot Create Pid File"));
 			}
 		}
-  	}
-  	
+	}
+
 #endif
 	return 0;
 }
@@ -670,7 +707,7 @@ int CamuleDaemonApp::InitGui(bool ,wxString &)
 
 int CamuleDaemonApp::OnExit()
 {
-#ifdef AMULED28
+#ifdef AMULED28_SOCKETS
 	/*
 	 * Stop all socket threads before entering
 	 * shutdown sequence.
@@ -685,22 +722,19 @@ int CamuleDaemonApp::OnExit()
 
 	ShutDown();
 
-#ifndef __WXMSW__
-	int ret = sigaction(SIGCHLD, &m_oldSignalChildAction, NULL);
+#ifdef AMULED_APPTRAITS
+	DEBUG_ONLY( int ret = ) sigaction(SIGCHLD, &m_oldSignalChildAction, NULL);
+#ifdef __DEBUG__
 	if (ret == -1) {
 		AddDebugLogLineC(logStandard, CFormat(wxT("CamuleDaemonApp::OnRun(): second sigaction() failed: %m.")));
 	} else {
 		AddDebugLogLineN(logGeneral, wxT("CamuleDaemonApp::OnRun(): Uninstallation of SIGCHLD callback with sigaction() succeeded."));
 	}
-#endif // __WXMSW__
-	
-	// lfroen: delete socket threads
-	if (ECServerHandler) {
-		ECServerHandler = 0;
-	}
+#endif
+#endif // AMULED_APPTRAITS
 
 	delete core_timer;
-	
+
 	return CamuleApp::OnExit();
 }
 
