@@ -18,7 +18,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -54,6 +54,8 @@ there client on the eMule forum..
 #pragma warning(disable:4996)
 #endif
 
+const CUInt128	Kademlia::s_nullUInt128(false);
+
 ////////////////////////////////////////
 using namespace Kademlia;
 ////////////////////////////////////////
@@ -245,7 +247,7 @@ void CKademlia::Process()
 						zone->m_nextBigTimer = HR2S(1) + now;
 						m_bigTimer = SEC(10) + now;
 					}
-				} 
+				}
 			}
 		}
 
@@ -254,7 +256,7 @@ void CKademlia::Process()
 			zone->m_nextSmallTimer = MIN2S(1) + now;
 		}
 	}
-	
+
 	// This is a convenient place to add this, although not related to routing
 	if (m_nextSearchJumpStart <= now) {
 		CSearchManager::JumpStart();
@@ -328,6 +330,7 @@ void CKademlia::RecheckFirewalled()
 	}
 }
 
+#if 0	// currently unused function
 bool CKademlia::FindNodeIDByIP(CKadClientSearcher& requester, uint32_t ip, uint16_t tcpPort, uint16_t udpPort)
 {
 	wxCHECK(IsRunning() && instance && GetUDPListener() && GetRoutingZone(), false);
@@ -343,6 +346,7 @@ bool CKademlia::FindNodeIDByIP(CKadClientSearcher& requester, uint32_t ip, uint1
 		return GetUDPListener()->FindNodeIDByIP(&requester, wxUINT32_SWAP_ALWAYS(ip), tcpPort, udpPort);
 	}
 }
+#endif
 
 bool CKademlia::FindIPByNodeID(CKadClientSearcher& requester, const uint8_t* nodeID)
 {
@@ -505,11 +509,11 @@ void KadGetKeywordHash(const wxString& rstrKeyword, Kademlia::CUInt128* pKadID)
 
 	// This should be safe - we assume rstrKeyword is ANSI anyway.
 	char* ansi_buffer = strdup(unicode2UTF8(rstrKeyword));
-	
+
 	//printf("Kad keyword hash: UTF8 %s\n",ansi_buffer);
 	md4_hasher.CalculateDigest(Output,(const unsigned char*)ansi_buffer,strlen(ansi_buffer));
 	//DumpMem(Output,16);
 	free(ansi_buffer);
-	
+
 	pKadID->SetValueBE(Output);
 }
