@@ -16,7 +16,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
@@ -71,7 +71,7 @@ CECTag::CECTag(ec_tagname_t name, unsigned int length, const void *data) : m_tag
 		NewData();
 		memcpy(m_tagData, data, m_dataLen);
 	} else {
-		wxASSERT(length == 0);
+		EC_ASSERT(length == 0);
 		m_dataLen = 0;
 		m_tagData = NULL;
 	}
@@ -81,8 +81,8 @@ CECTag::CECTag(ec_tagname_t name, unsigned int length, const void *data) : m_tag
 /**
  * Creates a new CECTag instance for custom data
  *
- * @param name	 	TAG name
- * @param length 	length of data buffer that will be alloc'ed
+ * @param name		TAG name
+ * @param length	length of data buffer that will be alloc'ed
  * @param dataptr	pointer to a void pointer which will be assigned the internal TAG data buffer
  *
  * \note TAG data buffer has to be filled with valid data after the ctor
@@ -110,8 +110,8 @@ CECTag::CECTag(ec_tagname_t name, const EC_IPv4_t& data) : m_tagName(name)
 
 	m_dataLen = sizeof(EC_IPv4_t);
 	NewData();
-	RawPokeUInt32( ((EC_IPv4_t *)m_tagData)->m_ip, RawPeekUInt32( data.m_ip ) );
-	((EC_IPv4_t *)m_tagData)->m_port = ENDIAN_HTONS(data.m_port);
+	RawPokeUInt32( reinterpret_cast<EC_IPv4_t *>(m_tagData)->m_ip, RawPeekUInt32( data.m_ip ) );
+	reinterpret_cast<EC_IPv4_t *>(m_tagData)->m_port = ENDIAN_HTONS(data.m_port);
 	m_dataType = EC_TAGTYPE_IPV4;
 }
 
@@ -218,22 +218,22 @@ void CECTag::InitInt(uint64 data)
 	} else {
 		m_dataType = EC_TAGTYPE_UINT64;
 		m_dataLen = 8;
-	}	
-	
+	}
+
 	NewData();
-	
+
 	switch (m_dataType) {
 		case EC_TAGTYPE_UINT8:
 			PokeUInt8( m_tagData, (uint8) data );
 			break;
 		case EC_TAGTYPE_UINT16:
-			PokeUInt16( m_tagData, wxUINT16_SWAP_ALWAYS((uint16) data ));
+			RawPokeUInt16( m_tagData, ENDIAN_HTONS((uint16) data ));
 			break;
 		case EC_TAGTYPE_UINT32:
-			PokeUInt32( m_tagData, wxUINT32_SWAP_ALWAYS((uint32) data ));
+			RawPokeUInt32( m_tagData, ENDIAN_HTONL((uint32) data ));
 			break;
 		case EC_TAGTYPE_UINT64:
-			PokeUInt64( m_tagData, wxUINT64_SWAP_ALWAYS(data) );
+			RawPokeUInt64( m_tagData, ENDIAN_HTONLL(data) );
 			break;
 	}
 }
@@ -290,7 +290,7 @@ CECTag& CECTag::operator=(const CECTag& tag)
 			m_tagData = NULL;
 		}
 		m_tagList.clear();
-		for (const_iterator it = tag.begin(); it != tag.end(); it++) {
+		for (const_iterator it = tag.begin(); it != tag.end(); ++it) {
 			m_tagList.push_back(*it);
 		}
 	}
@@ -314,7 +314,7 @@ bool CECTag::operator==(const CECTag& tag) const
 /**
  * Add a child tag to this one. The tag argument is reset to an empty tag.
  *
- * Be very careful that this method swallows the content of \e tag, leaving \e tag empty. 
+ * Be very careful that this method swallows the content of \e tag, leaving \e tag empty.
  * Thus, the following code won't work as expected:
  * \code
  * {
@@ -352,8 +352,9 @@ bool CECTag::operator==(const CECTag& tag) const
  * \endcode
  *
  * @param tag a CECTag class instance to add.
- * @return \b true if tag was really added, 
- * \b false when it was omitted through valuemap.
+ * @return \b true if tag was really added,
+ * \b false when it was omitted through valuemap or the limit for children
+ * is exceeded.
  */
 bool CECTag::AddTag(const CECTag& tag, CValueMap* valuemap)
 {
@@ -361,7 +362,9 @@ bool CECTag::AddTag(const CECTag& tag, CValueMap* valuemap)
 		return valuemap->AddTag(tag, this);
 	}
 	// cannot have more than 64k tags
-	wxASSERT(m_tagList.size() < 0xffff);
+	if (m_tagList.size() >= 0xffff) {
+		return false;
+	}
 
 	// First add an empty tag.
 	m_tagList.push_back(CECEmptyTag());
@@ -417,11 +420,11 @@ bool CECTag::ReadFromSocket(CECSocket& socket)
 	}
 	m_tagName = tmp_tagName >> 1;
 	bool hasChildren = (tmp_tagName & 0x01) != 0;
-	
+
 	if (!socket.ReadNumber(&m_dataType, sizeof(ec_tagtype_t))) {
 		return false;
 	}
-	
+
 	if (!socket.ReadNumber(&m_dataLen, sizeof(ec_taglen_t))) {
 		return false;
 	}
@@ -429,7 +432,7 @@ bool CECTag::ReadFromSocket(CECSocket& socket)
 	if (hasChildren && !ReadChildren(socket)) {
 		return false;
 	}
-	
+
 	unsigned int tmp_len = m_dataLen;
 	m_dataLen = 0;
 	m_dataLen = tmp_len - GetTagLen();
@@ -451,22 +454,22 @@ bool CECTag::WriteTag(CECSocket& socket) const
 	ec_tagname_t tmp_tagName = (m_tagName << 1) | (m_tagList.empty() ? 0 : 1);
 	ec_tagtype_t type = m_dataType;
 	ec_taglen_t tagLen = GetTagLen();
-	wxASSERT(type != EC_TAGTYPE_UNKNOWN);
-	
+	EC_ASSERT(type != EC_TAGTYPE_UNKNOWN);
+
 	if (!socket.WriteNumber(&tmp_tagName, sizeof(ec_tagname_t))) return false;
 	if (!socket.WriteNumber(&type, sizeof(ec_tagtype_t))) return false;
 	if (!socket.WriteNumber(&tagLen, sizeof(ec_taglen_t))) return false;
-	
+
 	if (!m_tagList.empty()) {
 		if (!WriteChildren(socket)) return false;
 	}
-	
+
 	if (m_dataLen > 0) {
 		if (m_tagData != NULL) {	// This is here only to make sure everything, it should not be NULL at this point
 			if (!socket.WriteBuffer(m_tagData, m_dataLen)) return false;
 		}
 	}
-	
+
 	return true;
 }
 
@@ -489,10 +492,9 @@ bool CECTag::ReadChildren(CECSocket& socket)
 
 bool CECTag::WriteChildren(CECSocket& socket) const
 {
-	wxASSERT(m_tagList.size() < 0xFFFF);
-    uint16 tmp = (uint16)m_tagList.size();
+	uint16 tmp = (uint16)m_tagList.size();
 	if (!socket.WriteNumber(&tmp, sizeof(tmp))) return false;
-	for (const_iterator it = begin(); it != end(); it++) {
+	for (const_iterator it = begin(); it != end(); ++it) {
 		if (!it->WriteTag(socket)) return false;
 	}
 	return true;
@@ -506,7 +508,7 @@ bool CECTag::WriteChildren(CECSocket& socket) const
  */
 const CECTag* CECTag::GetTagByName(ec_tagname_t name) const
 {
-	for (const_iterator it = begin(); it != end(); it++) {
+	for (const_iterator it = begin(); it != end(); ++it) {
 		if (it->m_tagName == name) return & *it;
 	}
 	return NULL;
@@ -520,7 +522,7 @@ const CECTag* CECTag::GetTagByName(ec_tagname_t name) const
  */
 CECTag* CECTag::GetTagByName(ec_tagname_t name)
 {
-	for (TagList::iterator it = m_tagList.begin(); it != m_tagList.end(); it++) {
+	for (TagList::iterator it = m_tagList.begin(); it != m_tagList.end(); ++it) {
 		if (it->m_tagName == name) return & *it;
 	}
 	return NULL;
@@ -543,7 +545,7 @@ const CECTag* CECTag::GetTagByNameSafe(ec_tagname_t name) const
 }
 
 /**
- * Query TAG length that is suitable for the TAGLEN field (i.e.\ 
+ * Query TAG length that is suitable for the TAGLEN field (i.e.\
  * without it's own header size).
  *
  * @return Tag length, containing its childs' length.
@@ -551,7 +553,7 @@ const CECTag* CECTag::GetTagByNameSafe(ec_tagname_t name) const
 uint32 CECTag::GetTagLen(void) const
 {
 	uint32 length = m_dataLen;
-	for (const_iterator it = begin(); it != end(); it++) {
+	for (const_iterator it = begin(); it != end(); ++it) {
 		length += it->GetTagLen();
 		length += sizeof(ec_tagname_t) + sizeof(ec_tagtype_t) + sizeof(ec_taglen_t) + (it->HasChildTags() ? 2 : 0);
 	}
@@ -587,7 +589,7 @@ uint64_t CECTag::GetInt() const
 
 
 std::string CECTag::GetStringDataSTL() const
-{ 
+{
 	if (m_dataType != EC_TAGTYPE_STRING) {
 		EC_ASSERT(m_dataType == EC_TAGTYPE_UNKNOWN);
 		return std::string();
@@ -602,14 +604,14 @@ std::string CECTag::GetStringDataSTL() const
 
 #ifdef USE_WX_EXTENSIONS
 wxString CECTag::GetStringData() const
-{ 
+{
 	return UTF82unicode(GetStringDataSTL().c_str());
 }
 #endif
 
 
 CMD4Hash CECTag::GetMD4Data() const
-{ 
+{
 	if (m_dataType != EC_TAGTYPE_HASH16) {
 		EC_ASSERT(m_dataType == EC_TAGTYPE_UNKNOWN);
 		return CMD4Hash();
@@ -617,9 +619,9 @@ CMD4Hash CECTag::GetMD4Data() const
 
 	EC_ASSERT(m_tagData != NULL);
 
-	// Doesn't matter if m_tagData is NULL in CMD4Hash(), 
+	// Doesn't matter if m_tagData is NULL in CMD4Hash(),
 	// that'll just result in an empty hash.
-	return CMD4Hash((const unsigned char *)m_tagData); 
+	return CMD4Hash((const unsigned char *)m_tagData);
 }
 
 
@@ -635,14 +637,14 @@ CMD4Hash CECTag::GetMD4Data() const
 EC_IPv4_t CECTag::GetIPv4Data() const
 {
 	EC_IPv4_t p(0, 0);
-	
+
 	if (m_dataType != EC_TAGTYPE_IPV4) {
 		EC_ASSERT(m_dataType == EC_TAGTYPE_UNKNOWN);
 	} else if (m_tagData == NULL) {
 		EC_ASSERT(false);
 	} else {
-		RawPokeUInt32( p.m_ip, RawPeekUInt32( ((EC_IPv4_t *)m_tagData)->m_ip ) );
-		p.m_port = ENDIAN_NTOHS(((EC_IPv4_t *)m_tagData)->m_port);
+		RawPokeUInt32( p.m_ip, RawPeekUInt32( reinterpret_cast<EC_IPv4_t *>(m_tagData)->m_ip ) );
+		p.m_port = ENDIAN_NTOHS(reinterpret_cast<EC_IPv4_t *>(m_tagData)->m_port);
 	}
 
 	return p;
@@ -667,9 +669,9 @@ double CECTag::GetDoubleData(void) const
 		EC_ASSERT(false);
 		return 0;
 	}
-	
+
 	std::istringstream double_str(m_tagData);
-	
+
 	double data;
 	double_str >> data;
 	return data;
@@ -970,7 +972,7 @@ bool CECTag::AssignIfExist(ec_tagname_t tagname, wxString &target) const
 		return true;
 	}
 	return false;
-}		
+}
 #endif
 
 
@@ -1002,6 +1004,13 @@ void CECTag::DebugPrint(int level, bool print_empty) const
 						s2 = CFormat(wxT("%.1f")) % GetDoubleData(); break;
 					case EC_TAGTYPE_HASH16:
 						s2 = GetMD4Data().Encode(); break;
+					case EC_TAGTYPE_UINT128:
+						// Using any non-inline function from UInt128.h would break linkage
+						// of remote apps otherwise not using CUInt128. So just fall through
+						// and display the value as a byte-stream. Since the value is sent
+						// big-endian on the network, the visual result is correct, except
+						// for the intervening spaces...
+						//s2 = GetInt128Data().ToHexString(); break;
 					case EC_TAGTYPE_CUSTOM:
 						if (m_dataLen == 0) {
 							s2 = wxT("empty");
