@@ -1,15 +1,18 @@
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
 /// Name:         AlcFrame Class
 ///
 /// Purpose:      aMule ed2k link creator
 ///
 /// Author:       ThePolish <thepolish@vipmail.ru>
 ///
-/// Copyright (C) 2004 by ThePolish
+/// Copyright (c) 2004-2011 ThePolish ( thepolish@vipmail.ru )
 ///
-/// Copyright (C) 2004 by Phoenix
+/// Copyright (c) 2004-2011 Marcelo Roberto Jimenez ( phoenix@amule.org )
 ///
-/// Pixmaps from http://jimmac.musichall.cz/ikony.php3 | http://www.everaldo.com | http://www.icomania.com
+/// Pixmaps from:
+///	http://jimmac.musichall.cz/ikony.php3
+///	http://www.everaldo.com
+///	http://www.icomania.com
 ///
 /// This program is free software; you can redistribute it and/or modify
 /// it under the terms of the GNU General Public License as published by
@@ -25,39 +28,36 @@
 /// along with this program; if not, write to the
 /// Free Software Foundation, Inc.,
 /// 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+////////////////////////////////////////////////////////////////////////////////
 
-// For compilers that support precompilation, includes "wx/wx.h"
-#include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
-
-// For all others, include the necessary headers
-#ifndef WX_PRECOMP
-    #include "wx/wx.h"
-#endif
-
-#include <wx/filedlg.h>
-#include <wx/textfile.h>
-#include <wx/file.h>
-#include <wx/timer.h>
-#include <wx/listbox.h>
-#include <wx/url.h>
-#if wxCHECK_VERSION(2,6,0)
-	#include <wx/uri.h>
-#endif
-#include <wx/filename.h>
 #include <wx/clipbrd.h>
 #include <wx/dataobj.h>
+#include <wx/file.h>
+#include <wx/filedlg.h>
+#include <wx/filename.h>
+#include <wx/button.h>
+#include <wx/icon.h>
+#include <wx/log.h>
+#include <wx/msgdlg.h>
+#include <wx/statbox.h>
+#include <wx/stattext.h>
+#include <wx/textfile.h>
+#include <wx/timer.h>
+#include <wx/toolbar.h>
+#include <wx/uri.h>
+#include <wx/url.h>
 
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
 	#include <winerror.h>
 	#include <shlobj.h>
 #elif defined(__WXMAC__)
 	#include <CoreServices/CoreServices.h>
-	#include <wx/mac/corefoundation/cfstring.h>
+	#if wxCHECK_VERSION(2, 9, 0)
+		#include <wx/osx/core/cfstring.h>  // Do_not_auto_remove
+	#else
+		#include <wx/mac/corefoundation/cfstring.h>
+	#endif
 	#include <wx/intl.h>
 #endif
 
@@ -72,7 +72,7 @@ AlcFrame::AlcFrame (const wxString & title):
     wxFrame ((wxFrame *) NULL, -1, title)
 {
   // Give it an icon
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
   wxIcon icon(wxT("alc"));
 #else
   wxIcon icon;
@@ -125,14 +125,13 @@ AlcFrame::AlcFrame (const wxString & title):
                                         wxDefaultPosition, wxSize(300,-1));
   m_inputFileTextCtrl->
   SetToolTip (_
-              ("Enter here the file you want to compute the Ed2k link"));
+              ("Enter here the file you want to compute the eD2k link"));
 
   m_inputAddTextCtrl = new wxTextCtrl (m_mainPanel,-1,wxEmptyString,
                                        wxDefaultPosition, wxSize(300,-1));
   m_inputAddTextCtrl->
   SetToolTip (_
-              ("Enter here the URL you want to add to the Ed2k link: "
-               "Add / at the end to let aLinkCreator append the current file name"));
+              ("Enter here the URL you want to add to the eD2k link: Add / at the end to let aLinkCreator append the current file name"));
 
   // List box
   m_inputUrlListBox = new wxListBox(m_mainPanel, -1, wxDefaultPosition,
@@ -203,7 +202,7 @@ AlcFrame::AlcFrame (const wxString & title):
 #endif
 
   // Hash Vertical Box Sizer
-  m_e2kHashSBox = new wxStaticBox (m_mainPanel, -1, _("Ed2k File Hash"));
+  m_e2kHashSBox = new wxStaticBox (m_mainPanel, -1, _("eD2k File Hash"));
   m_e2kHashSBoxSizer = new wxStaticBoxSizer (m_e2kHashSBox, wxHORIZONTAL);
 
   // Hash results
@@ -214,7 +213,7 @@ AlcFrame::AlcFrame (const wxString & title):
   m_mainPanelVBox->Add( m_e2kHashSBoxSizer, 0, wxALL | wxGROW, 10 );
 
   // Ed2k Vertical Box Sizer
-  m_ed2kSBox = new wxStaticBox (m_mainPanel, -1, _("Ed2k link"));
+  m_ed2kSBox = new wxStaticBox (m_mainPanel, -1, _("eD2k link"));
   m_ed2kSBoxSizer = new wxStaticBoxSizer (m_ed2kSBox, wxVERTICAL);
 
   // Ed2k results
@@ -258,18 +257,18 @@ AlcFrame::AlcFrame (const wxString & title):
   m_toolbar->SetToolBitmapSize (wxSize (32, 32));
   m_toolbar->SetMargins (2, 2);
 
-  m_toolbar->AddTool (ID_BAR_OPEN, wxT("Open"), m_toolBarBitmaps[0],
-                      _("Open a file to compute its ed2k link"));
+  m_toolbar->AddTool (ID_BAR_OPEN, _("Open"), m_toolBarBitmaps[0],
+                      _("Open a file to compute its eD2k link"));
 
-  m_toolbar->AddTool (ID_BAR_COPY, wxT("Copy"), m_toolBarBitmaps[1],
-                      _("Copy computed ed2k link to clipboard"));
+  m_toolbar->AddTool (ID_BAR_COPY, _("Copy"), m_toolBarBitmaps[1],
+                      _("Copy computed eD2k link to clipboard"));
 
-  m_toolbar->AddTool (ID_BAR_SAVEAS, wxT("Save as"), m_toolBarBitmaps[2],
-                      _("Save computed ed2k link to file"));
+  m_toolbar->AddTool (ID_BAR_SAVEAS, _("Save as"), m_toolBarBitmaps[2],
+                      _("Save computed eD2k link to file"));
 
   m_toolbar->AddSeparator ();
 
-  m_toolbar->AddTool (ID_BAR_ABOUT, wxT("About"), m_toolBarBitmaps[3],
+  m_toolbar->AddTool (ID_BAR_ABOUT, _("About"), m_toolBarBitmaps[3],
                       _("About aLinkCreator"));
 
   m_toolbar->Realize ();
@@ -326,7 +325,7 @@ AlcFrame::OnBrowseButton (wxCommandEvent & WXUNUSED(event))
 void
 AlcFrame::SetFileToHash()
 {
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
 	wxString browseroot;
 	LPITEMIDLIST pidl;
 	HRESULT hr = SHGetSpecialFolderLocation(NULL, CSIDL_PERSONAL, &pidl);
@@ -354,7 +353,11 @@ AlcFrame::SetFileToHash()
 		CFURLRef	urlRef		= CFURLCreateFromFSRef(NULL, &fsRef);
 		CFStringRef	cfString	= CFURLCopyFileSystemPath(urlRef, kCFURLPOSIXPathStyle);
 		CFRelease(urlRef) ;
-		browseroot = wxMacCFStringHolder(cfString).AsString(wxLocale::GetSystemEncoding());
+		#if wxCHECK_VERSION(2, 9, 0)
+			browseroot = wxCFStringRef(cfString).AsString(wxLocale::GetSystemEncoding());
+		#else
+			browseroot = wxMacCFStringHolder(cfString).AsString(wxLocale::GetSystemEncoding());
+		#endif
 	} else {
 		browseroot = wxFileName::GetHomeDir();
 	}
@@ -363,9 +366,9 @@ AlcFrame::SetFileToHash()
 	wxString browseroot = wxFileName::GetHomeDir();
 #endif
   const wxString & filename =
-    wxFileSelector (_("Select the file you want to compute the ed2k link"),
+    wxFileSelector (_("Select the file you want to compute the eD2k link"),
                     browseroot, wxEmptyString, wxEmptyString, wxT("*.*"),
-                    wxOPEN | wxFILE_MUST_EXIST );
+                    wxFD_OPEN | wxFD_FILE_MUST_EXIST, this);
 
   if (!filename.empty ())
     {
@@ -397,7 +400,7 @@ AlcFrame::CopyEd2kLinkToClipBoard()
       wxClipboardLocker clipLocker;
       if ( !clipLocker )
         {
-          wxLogError(wxT("Can't open the clipboard"));
+          wxLogError(_("Can't open the clipboard"));
 
           return;
         }
@@ -433,9 +436,9 @@ AlcFrame::SaveEd2kLinkToFile()
   if (!link.IsEmpty())
     {
       const wxString & filename =
-        wxFileSelector (_("Select the file to your computed ed2k link"),
+        wxFileSelector (_("Select the file to your computed eD2k link"),
                         wxFileName::GetHomeDir(),wxT("my_ed2k_link"),
-                        wxT("txt"), wxT("*.txt"), wxSAVE );
+                        wxT("txt"), wxT("*.txt"), wxFD_SAVE, this);
 
       if (!filename.empty ())
         {
@@ -465,11 +468,7 @@ void
 AlcFrame::OnBarAbout (wxCommandEvent & WXUNUSED(event))
 {
   wxMessageBox (_
-                ("aLinkCreator, the aMule ed2k link creator\n\n"
-                 "(c) 2004 ThePolish <thepolish@vipmail.ru>\n\n"
-                 "Pixmaps from http://www.everaldo.com and http://www.icomania.com\n"
-		 "and http://jimmac.musichall.cz/ikony.php3\n\n"
-                 "Distributed under GPL"),
+                ("aLinkCreator, the aMule eD2k link creator\n\n(c) 2004 ThePolish <thepolish@vipmail.ru>\n\nPixmaps from http://www.everaldo.com and http://www.icomania.com\nand http://jimmac.musichall.cz/ikony.php3\n\nDistributed under GPL"),
                 _("About aLinkCreator"), wxOK | wxCENTRE | wxICON_INFORMATION);
 }
 
@@ -499,14 +498,10 @@ bool AlcFrame::Hook(int percent)
 /// Compute Hashes on Start Button
 void AlcFrame::OnStartButton (wxCommandEvent & WXUNUSED(event))
 {
-  int i;
   wxString filename = m_inputFileTextCtrl->GetValue();
 
   if (!filename.empty ())
     {
-      // Initialize computation
-      m_goAhead=true;
-
       // Chrono
       wxStopWatch chrono;
 
@@ -519,7 +514,7 @@ void AlcFrame::OnStartButton (wxCommandEvent & WXUNUSED(event))
 
 #ifdef WANT_MD4SUM
       // Create MD4 progress bar dialog
-      m_progressBar=new wxProgressDialog  (wxT("aLinkCreator is working for you"), wxT("Computing MD4 Hash..."),
+      m_progressBar=new wxProgressDialog  (_("aLinkCreator is working for you"), _("Computing MD4 Hash..."),
                                            100, this, wxPD_AUTO_HIDE | wxPD_CAN_ABORT | wxPD_REMAINING_TIME);
       m_md4HashTextCtrl->SetValue(_("Hashing..."));
 
@@ -534,7 +529,7 @@ void AlcFrame::OnStartButton (wxCommandEvent & WXUNUSED(event))
 #endif
 
       // Create ED2K progress bar dialog
-      m_progressBar=new wxProgressDialog  (wxT("aLinkCreator is working for you"), wxT("Computing ED2K Hashes..."),
+      m_progressBar=new wxProgressDialog  (_("aLinkCreator is working for you"), _("Computing eD2k Hashes..."),
                                            100, this, wxPD_AUTO_HIDE | wxPD_CAN_ABORT | wxPD_REMAINING_TIME);
 
       // Compute ed2k Hash
@@ -549,18 +544,14 @@ void AlcFrame::OnStartButton (wxCommandEvent & WXUNUSED(event))
           // Get URLs
           wxArrayString arrayOfUrls;
           wxString url;
-          for (i=0;i < m_inputUrlListBox->GetCount();++i)
+          for (size_t i = 0; i < m_inputUrlListBox->GetCount(); ++i)
             {
               url=m_inputUrlListBox->GetString(i);
               if (url.Right(1) == wxT("/"))
                 {
                   url += fileToHash.GetFullName();
                 }
-			#if wxCHECK_VERSION(2,6,0)
-				arrayOfUrls.Add(wxURI(url).BuildURI());
-			 #else 
-			 	arrayOfUrls.Add(wxURL::ConvertToValidURI(url));
-			 #endif
+		arrayOfUrls.Add(wxURI(url).BuildURI());
             }
           arrayOfUrls.Shrink(); // Reduce memory usage
 
@@ -573,8 +564,8 @@ void AlcFrame::OnStartButton (wxCommandEvent & WXUNUSED(event))
       else
         {
           // Set cancelled msg
-          m_e2kHashTextCtrl->SetValue(_("Canceled !"));
-          m_ed2kTextCtrl->SetValue(_("Canceled !"));
+          m_e2kHashTextCtrl->SetValue(_("Cancelled !"));
+          m_ed2kTextCtrl->SetValue(_("Cancelled !"));
         }
 
       // Deleting progress bar dialog
@@ -602,9 +593,8 @@ AlcFrame::OnAddUrlButton (wxCommandEvent & WXUNUSED(event))
   if (!url.IsEmpty())
     {
       // Check if the URL already exist in list
-      int i;
       bool UrlNotExists = true;
-      for (i=0;i < m_inputUrlListBox->GetCount();++i)
+      for (size_t i = 0; i < m_inputUrlListBox->GetCount(); ++i)
         {
           if (url == m_inputUrlListBox->GetString(i))
             {
@@ -616,11 +606,7 @@ AlcFrame::OnAddUrlButton (wxCommandEvent & WXUNUSED(event))
       // Add only a not already existant URL
       if (UrlNotExists)
         {
-		#if wxCHECK_VERSION(2,6,0)
-		   	m_inputUrlListBox->Append(wxURI(url).BuildURI());
-		#else 
-			m_inputUrlListBox->Append(wxURL::ConvertToValidURI(url));
-		#endif
+	  m_inputUrlListBox->Append(wxURI(url).BuildURI());
           m_inputAddTextCtrl->SetValue(wxEmptyString);
         }
       else
@@ -647,3 +633,4 @@ AlcFrame::OnClearUrlButton (wxCommandEvent & WXUNUSED(event))
 {
   m_inputUrlListBox->Clear();
 }
+// File_checked_for_headers
