@@ -5,8 +5,8 @@
  *
  *  Author:       Pedro de Oliveira <falso@rdk.homeip.net>
  *
- *  Copyright (C) 2004 by Pedro de Oliveira
- * 
+ *  Copyright (c) 2004-2011 Pedro de Oliveira ( falso@rdk.homeip-net )
+ *
  *  This file is part of aMule.
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -29,19 +29,22 @@
 #ifndef CAS_CONFIGFILE_H
 #define CAS_CONFIGFILE_H
 
-#define IMG_TEXTLINES 6
+#define IMG_TEXTLINES		7
+#define MAX_CONF_ARG_LEN	120
 
 typedef struct {
-        char font[120];
-        char source[120];
-	char template[120];
-        int x[6];
-        int y[6];
-        int enabled[6];
-        float size;
+	char font[MAX_CONF_ARG_LEN+1];
+	char source[MAX_CONF_ARG_LEN+1];
+	char template[MAX_CONF_ARG_LEN+1];
+	int x[IMG_TEXTLINES];
+	int y[IMG_TEXTLINES];
+	int enabled[IMG_TEXTLINES];
+	float size;
+	int img_type; // 0 = PNG, else = JPG
 } CONF;
 
 int writeconfig(void);
 int readconfig(CONF *config);
 
 #endif
+/* // File_checked_for_headers */
