@@ -1,3 +1,22 @@
+/*
+ *  This file is part of aMule.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the
+ *  Free Software Foundation, Inc.,
+ *  51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
+ */
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -8,8 +27,9 @@
 void CreateLine(char *lines[], int line, const char *format, ...)
 {
 	/* Guess we need no more than 80 bytes. */
-	int n, size = 80;
+	int n, size = 100;
 	char *p;
+	char *tmp;
 	va_list ap;
 	if ((p = malloc(size)) == NULL) {
 		lines[line] = NULL;
@@ -22,19 +42,22 @@ void CreateLine(char *lines[], int line, const char *format, ...)
 		va_end(ap);
 		/* If that worked, set the line. */
 		if (n > -1 && n < size) {
-			lines[line] = p;
-			return;
+			break;
 		}
 		/* Else try again with more space. */
 		if (n > -1)	/* glibc 2.1 */
 			size = n+1;	/* precisely what is needed */
 		else		/* glibc 2.0 */
 			size *= 2;	/* twice the old size */
-		if ((p = realloc(p, size)) == NULL) {
-			lines[line] = NULL;
-			return;
+		if ((tmp = realloc(p, size)) == NULL) {
+			free(p);
+			p = NULL;
+			break;
+		} else {
+			p = tmp;
 		}
 	}
+	lines[line] = p;
 }
 
 void AppendToLine(char *lines[], int line, const char *text)
