@@ -61,9 +61,9 @@ void KadGetKeywordHash(const wxString& rstrKeyword, Kademlia::CUInt128* pKadID)
 
 	// This should be safe - we assume rstrKeyword is ANSI anyway.
 	Unicode2CharBuf ansi_buffer(unicode2UTF8(rstrKeyword));
-	
+
 	md4_hasher.CalculateDigest(Output, (const byte *) (const char *) ansi_buffer, strlen(ansi_buffer));
-	
+
 	pKadID->SetValueBE(Output);
 }
 
@@ -73,7 +73,7 @@ bool IdentifyKeyword(const Kademlia::CUInt128& keyID, const wxString& str, wxStr
 	wxStringTokenizer tkz(str, Kademlia::CSearchManager::GetInvalidKeywordChars());
 	while (tkz.HasMoreTokens()) {
 		wxString current_word = tkz.GetNextToken();
-		
+
 		if (current_word.Length() > 2) {
 			current_word.MakeLower();
 			Kademlia::CUInt128 currentID;
@@ -157,7 +157,7 @@ void DecodeSourceIndexDat(const CFileDataIO& file)
 			cout << "\n\t\tnumName : " << (numName = file.ReadUInt32()) << '\n';
 			for (uint32_t iN = 0; iN < numName; iN++) {
 				cout << "\t\t\tLifeTime: " << CTimeT(file.ReadUInt32());
-				cout << "\n\t\t\ttagCount: " << (tagCount = file.ReadUInt8()) << '\n';
+				cout << "\n\t\t\ttagCount: " << static_cast<unsigned int>(tagCount = file.ReadUInt8()) << '\n';
 				for (uint32_t it = 0; it < tagCount; it++) {
 					CTag *tag = file.ReadTag();
 					cout << "\t\t\t\t" << *tag << '\n';
