@@ -47,11 +47,11 @@ wxString StringFrom(CRangeMap<void>::iterator it)
 /**
  * Returns the contents of a TestRangeMap as a string-representation.
  *
- * Using this function allows for easy comparison against the expected 
+ * Using this function allows for easy comparison against the expected
  * result of a particular test.
  */
 template <typename VALUE>
-wxString StringFrom(const CRangeMap<VALUE>& map) 
+wxString StringFrom(const CRangeMap<VALUE>& map)
 {
 	wxString stream;
 
@@ -60,7 +60,7 @@ wxString StringFrom(const CRangeMap<VALUE>& map)
 		if (it != map.begin()) {
 			stream << wxT(", ");
 		}
-		
+
 		stream += StringFrom(it);
 	}
 
@@ -83,16 +83,16 @@ DECLARE(RangeMap);
 	// Sets up a few maps with predefined ranges.
 	void setUp() {
 		m_map.insert(100, 150, 0);
-		
+
 		m_mmaps[CONT].insert(100, 150, 0);
 		m_mmaps[CONT].insert(151, 200, 1);
-		
+
 		m_mmaps[SDIFF].insert(100, 150, 0);
 		m_mmaps[SDIFF].insert(160, 200, 1);
-		
+
 		m_mmaps[SSAME].insert(100, 150, 1);
 		m_mmaps[SSAME].insert(160, 200, 1);
-		
+
 		ASSERT_EQUALS(wxT("[(100, 150, 0)]"), StringFrom(m_map));
 		ASSERT_EQUALS(wxT("[(100, 150, 0), (151, 200, 1)]"), StringFrom(m_mmaps[CONT]));
 		ASSERT_EQUALS(wxT("[(100, 150, 0), (160, 200, 1)]"), StringFrom(m_mmaps[SDIFF]));
@@ -114,36 +114,36 @@ DECLARE(RangeMap);
 	void singleInsert(uint32 start, uint32 end, int value, const wxString& result)
 	{
 		TestRangeMap::iterator it = m_map.insert(start, end, value);
-		
+
 		// Test that the correct iterator was returned
 		ASSERT_TRUE(it.keyStart() <= start);
 		ASSERT_TRUE(it.keyEnd() >= end);
-		ASSERT_EQUALS(*it, value);
-		
+		ASSERT_EQUALS(value, *it);
+
 		// Check the resulting map
 		ASSERT_EQUALS(result, StringFrom(m_map));
 		ASSERT_EQUALS((uint32)std::count(result.begin(), result.end(), '('), m_map.size());
-		
+
 		// Reset the rangemap
 		tearDown();
 		setUp();
-	}	
+	}
 
 	void doErase(uint32 start, uint32 end, const wxString& result)
 	{
 		m_map.erase_range(start, end);
-		
+
 		// Check the resulting map
 		ASSERT_EQUALS(result, StringFrom(m_map));
 		ASSERT_EQUALS((uint32)std::count(result.begin(), result.end(), '('), m_map.size());
-		
+
 		// Reset the rangemap
 		tearDown();
-		setUp();	
+		setUp();
 	}
 
-	/** 
-	 * Tests insertion into a map with multiple ranges, checking against an 
+	/**
+	 * Tests insertion into a map with multiple ranges, checking against an
 	 * expected result.
 	 */
 	void multiInsert(int type, uint32 start, uint32 end, int value, const wxString& result)
@@ -153,12 +153,12 @@ DECLARE(RangeMap);
 		// Test that the correct iterator was returned
 		ASSERT_TRUE(it.keyStart() <= start);
 		ASSERT_TRUE(it.keyEnd() >= end);
-		ASSERT_EQUALS(*it, value);
-		
+		ASSERT_EQUALS(value, *it);
+
 		// Check the resulting map
 		ASSERT_EQUALS(result, StringFrom(m_mmaps[type]));
 		ASSERT_EQUALS((uint32)std::count(result.begin(), result.end(), '('), m_mmaps[type].size());
-		
+
 		tearDown();
 		setUp();
 	}
@@ -182,13 +182,13 @@ TEST(RangeMap, CopyConstructor)
 	TestRangeMap mapB(m_mmaps[CONT]);
 	TestRangeMap mapC(m_mmaps[SSAME]);
 	TestRangeMap mapD(m_mmaps[SDIFF]);
-	
+
 	ASSERT_EQUALS(m_map, mapA);
 	ASSERT_EQUALS(m_mmaps[CONT], mapB);
 	ASSERT_EQUALS(m_mmaps[SSAME], mapC);
-	ASSERT_EQUALS(m_mmaps[SDIFF], mapD);	
-	
-	
+	ASSERT_EQUALS(m_mmaps[SDIFF], mapD);
+
+
 	// The copies must not affect the originals
 	mapA.insert(125, 175, 2);
 	mapB.insert(125, 175, 2);
@@ -207,10 +207,10 @@ TEST(RangeMap, AssignmentOperator)
 	// Check basic assignment
 	TestRangeMap mapA, mapB;
 	mapA = mapB = m_map;
-	
+
 	ASSERT_EQUALS(m_map, mapA);
 	ASSERT_EQUALS(m_map, mapB);
-	
+
 
 	// The copies must not affect the originals
 	mapA.insert(125, 175, 2);
@@ -225,9 +225,9 @@ TEST(RangeMap, AssignmentOperator)
 TEST(RangeMap, Equality)
 {
 	TestRangeMap mapA(m_mmaps[SSAME]), mapB(m_mmaps[SDIFF]);
-	
+
 	ASSERT_FALSE(mapA == mapB);
-	
+
 	mapA = mapB;
 
 	ASSERT_EQUALS(mapA, mapB);
@@ -243,21 +243,21 @@ TEST(RangeMap, Iterators)
 	// Adding a third range
 	m_mmaps[CONT].insert(125, 175, 2);
 	TestRangeMap map(m_mmaps[CONT]);
-	
+
 	TestRangeMap::iterator it = map.begin();
 	TestRangeMap::iterator it_orig = map.begin();
-	TestRangeMap::iterator it_other = map.end();	
-	
+	TestRangeMap::iterator it_other = map.end();
+
 	ASSERT_EQUALS(wxT("(100, 124, 0)"), StringFrom(it));
-	
+
 	it_other = ++it;
-	
+
 	ASSERT_EQUALS(wxT("(125, 175, 2)"), StringFrom(it));
 	ASSERT_EQUALS(it_other, it++);
 	ASSERT_EQUALS(wxT("(176, 200, 1)"), StringFrom(it));
-	
+
 	it_other = --it;
-	
+
 	ASSERT_EQUALS(wxT("(125, 175, 2)"), StringFrom(it));
 	ASSERT_EQUALS(it_other, it--);
 	ASSERT_EQUALS(wxT("(100, 124, 0)"), StringFrom(it));
@@ -268,7 +268,7 @@ TEST(RangeMap, Erase)
 {
 	// Adding a third range
 	m_mmaps[CONT].insert(125, 175, 2);
-	
+
 	// The expected results from forwards deletion
 	TestRangeMap map(m_mmaps[CONT]);
 	wxString expectedFW[4];
@@ -295,7 +295,7 @@ TEST(RangeMap, Erase)
 
 	for (int i = 0; i < 4; ++i) {
 		ASSERT_EQUALS(expectedBW[i], StringFrom(map));
-		
+
 		if (map.begin() != map.end()) {
 			map.erase(--map.end());
 		}
@@ -309,7 +309,7 @@ TEST(RangeMap, Clear)
 	ASSERT_TRUE(m_map.empty());
 	ASSERT_EQUALS(0u, m_map.size());
 	ASSERT_EQUALS(wxT("[]"), StringFrom(m_map));
-	
+
 	for (int i = 0; i < 3; ++i) {
 		m_mmaps[i].clear();
 		ASSERT_TRUE(m_mmaps[i].empty());
@@ -324,7 +324,7 @@ TEST(RangeMap, FindRange)
 	// Adding a third range
 	m_mmaps[CONT].insert(125, 175, 2);
 	TestRangeMap map(m_mmaps[CONT]);
-	
+
 	ASSERT_EQUALS(map.end(), map.find_range(0));
 	ASSERT_EQUALS(map.end(), map.find_range(98));
 	ASSERT_EQUALS(map.end(), map.find_range(99));
@@ -340,7 +340,7 @@ TEST(RangeMap, FindRange)
 	ASSERT_EQUALS(wxT("(176, 200, 1)"), StringFrom(map.find_range(176)));
 	ASSERT_EQUALS(wxT("(176, 200, 1)"), StringFrom(map.find_range(186)));
 	ASSERT_EQUALS(wxT("(176, 200, 1)"), StringFrom(map.find_range(200)));
-	
+
 	ASSERT_EQUALS(map.end(), map.find_range(201));
 	ASSERT_EQUALS(map.end(), map.find_range(202));
 	ASSERT_EQUALS(map.end(), map.find_range(250));
@@ -355,7 +355,7 @@ TEST(RangeMap, InvalidErase)
 
 TEST(RangeMap, InvalidInsert)
 {
-	ASSERT_RAISES(CInvalidParamsEx, m_map.insert(10, 9, 8));	
+	ASSERT_RAISES(CInvalidParamsEx, m_map.insert(10, 9, 8));
 }
 
 
@@ -363,7 +363,7 @@ TEST(RangeMap, InvalidInsert)
 // The following tests exercize the merging algorithm.
 // The comment before each comment descrices the RangeMaps used to test,
 // and which types of ranges are tested. For example, the description
-// "a / b <-> c / d" is to be read as: 
+// "a / b <-> c / d" is to be read as:
 //   Insert range starting at a or b, ending at c or d.
 
 
@@ -414,7 +414,7 @@ TEST(RangeMap, SingleInsert_BeforeStart_TouchingStart_AtEnd_TouchingEnd_AfterEnd
 
 
 // Single insert touching start <-> touching start.
-TEST(RangeMap, SingleInsert_TouchingStart_TouchingStart) 
+TEST(RangeMap, SingleInsert_TouchingStart_TouchingStart)
 {
 	singleInsert(99, 99, 0, wxT("[(99, 150, 0)]")); // Same
 	singleInsert(99, 99, 1, wxT("[(99, 99, 1), (100, 150, 0)]")); // Different
@@ -428,9 +428,9 @@ TEST(RangeMap, SingleInsert_TouchingStart_AtStart_AtStart_Inside)
 		for (int offset_b = 0; offset_b < 2; ++offset_b) { // (at start, inside)
 			int start = 99 + offset_a;
 			int end   = 100 + offset_b;
-			
+
 			// Same
-			singleInsert(start, end, 0, wxString::Format(wxT("[(%u, 150, 0)]"), 99 + offset_a)); 
+			singleInsert(start, end, 0, wxString::Format(wxT("[(%u, 150, 0)]"), 99 + offset_a));
 
 			// Different
 			wxString exp = wxString::Format(wxT("[(%u, %u, 1), (%u, 150, 0)]"), start, end, 101 + offset_b);
@@ -441,14 +441,14 @@ TEST(RangeMap, SingleInsert_TouchingStart_AtStart_AtStart_Inside)
 
 
 // Single insert at start <-> at end / touching end / after end.
-TEST(RangeMap, SingleInsert_AtStart_AtEnd_TouchingEnd_AfterEnd) 
+TEST(RangeMap, SingleInsert_AtStart_AtEnd_TouchingEnd_AfterEnd)
 {
 	// (at end, touching end, after end)
 	for (int offset = 0; offset < 3; ++offset) {
 		// Same
 		singleInsert(100, 150 + offset, 0, wxString::Format(wxT("[(100, %u, 0)]"), 150 + offset));
 		// Different
-		singleInsert(100, 150 + offset, 1, wxString::Format(wxT("[(100, %u, 1)]"), 150 + offset)); 
+		singleInsert(100, 150 + offset, 1, wxString::Format(wxT("[(100, %u, 1)]"), 150 + offset));
 	}
 }
 
@@ -462,10 +462,10 @@ TEST(RangeMap, SingleInsert_Inside_AtEnd_AtEnd_TouchingEnd_AfterEnd)
 		for (int offset_b = 0; offset_b < 3; ++offset_b) {
 			int start = 149 + offset_a;
 			int end   = 150 + offset_b;
-			
+
 			// Same
 			singleInsert(start, end, 0, wxString::Format(wxT("[(100, %u, 0)]"), end));
-			
+
 			// Different
 			singleInsert(start, end, 1, wxString::Format(wxT("[(100, %u, 0), (%u, %u, 1)]"), 148 + offset_a, start, end));
 		}
@@ -479,10 +479,10 @@ TEST(RangeMap, SingleInsert_TouchingEnd_TouchingEnd_AfterEnd)
 	// (touching end, after end)
 	for (int offset = 0; offset < 2; ++offset) {
 		int end = 151 + offset;
-		
+
 		// Same
 		singleInsert(151, end, 0, wxString::Format(wxT("[(100, %u, 0)]"), end));
-		
+
 		// Different
 		singleInsert(151, end, 1, wxString::Format(wxT("[(100, 150, 0), (151, %u, 1)]"), end));
 	}
@@ -514,7 +514,7 @@ TEST(RangeMap, MultiInsert_BeforeStart_TouchingStart)
 	multiInsert(CONT, 0, 99, 0, wxT("[(0, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 0, 99, 0, wxT("[(0, 150, 0), (160, 200, 1)]"));
 	multiInsert(SSAME, 0, 99, 0, wxT("[(0, 99, 0), (100, 150, 1), (160, 200, 1)]"));
-	
+
 	multiInsert(CONT, 0, 99, 1, wxT("[(0, 99, 1), (100, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 0, 99, 1, wxT("[(0, 99, 1), (100, 150, 0), (160, 200, 1)]"));
 	multiInsert(SSAME, 0, 99, 1, wxT("[(0, 150, 1), (160, 200, 1)]"));
@@ -526,11 +526,11 @@ TEST(RangeMap, MultiInsert_BeforeStart_AtStart_InSide)
 {
 	for (int offset = 0; offset < 3; ++offset) { // (at start, inside, inside)
 		int end = 100 + offset;
-		
+
 		multiInsert(CONT, 0, end, 0, wxT("[(0, 150, 0), (151, 200, 1)]"));
 		multiInsert(SDIFF, 0, end, 0, wxT("[(0, 150, 0), (160, 200, 1)]"));
 		multiInsert(SSAME, 0, end, 0, wxString::Format(wxT("[(0, %u, 0), (%u, 150, 1), (160, 200, 1)]"), end, 101 + offset));
-		
+
 		multiInsert(CONT, 0, end, 1, wxString::Format(wxT("[(0, %u, 1), (%u, 150, 0), (151, 200, 1)]"), end, 101 + offset));
 		multiInsert(SDIFF, 0, end, 1, wxString::Format(wxT("[(0, %u, 1), (%u, 150, 0), (160, 200, 1)]"), end, 101 + offset));
 		multiInsert(SSAME, 0, end, 1, wxT("[(0, 150, 1), (160, 200, 1)]"));
@@ -545,11 +545,11 @@ TEST(RangeMap, MultiInsert_BeforeStart_TouchingStart_AtEnd_TouchingEnd_AfterEnd)
 		for (int start_offset = 0; start_offset < 2; ++start_offset) { // (before start, touching start)
 			int start = 98 + start_offset;
 			int end   = 150 + end_offset;
-				
+
 			multiInsert(CONT, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (%u, 200, 1)]"), start, end, end + 1));
 			multiInsert(SDIFF, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (160, 200, 1)]"), start, end));
 			multiInsert(SSAME, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (160, 200, 1)]"), start, end));
-				
+
 			multiInsert(CONT, start, end, 1, wxString::Format(wxT("[(%u, 200, 1)]"), start));
 			multiInsert(SDIFF, start, end, 1, wxString::Format(wxT("[(%u, %u, 1), (160, 200, 1)]"), start, end));
 			multiInsert(SSAME, start, end, 1, wxString::Format(wxT("[(%u, %u, 1), (160, 200, 1)]"), start, end));
@@ -564,7 +564,7 @@ TEST(RangeMap, MultiInsert_TouchingStart_TouchingStart)
 	multiInsert(CONT, 99, 99, 0, wxT("[(99, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 99, 99, 0, wxT("[(99, 150, 0), (160, 200, 1)]"));
 	multiInsert(SSAME, 99, 99, 0, wxT("[(99, 99, 0), (100, 150, 1), (160, 200, 1)]"));
-	
+
 	multiInsert(CONT, 99, 99, 1, wxT("[(99, 99, 1), (100, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 99, 99, 1, wxT("[(99, 99, 1), (100, 150, 0), (160, 200, 1)]"));
 	multiInsert(SSAME, 99, 99, 1, wxT("[(99, 150, 1), (160, 200, 1)]"));
@@ -578,11 +578,11 @@ TEST(RangeMap, MultiInsert_TouchingStart_AtStart_AtStart_Inside)
 		for (int offset_b = 0; offset_b < 2; ++offset_b) { // (at start, inside)
 			int start = 99 + offset_a;
 			int end   = 100 + offset_b;
-			
+
 			multiInsert(CONT, start, end, 0, wxString::Format(wxT("[(%u, 150, 0), (151, 200, 1)]"), start));
 			multiInsert(SDIFF, start, end, 0, wxString::Format(wxT("[(%u, 150, 0), (160, 200, 1)]"), start));
 			multiInsert(SSAME, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (%u, 150, 1), (160, 200, 1)]"), start, end, end + 1));
-			
+
 			multiInsert(CONT, start, end, 1, wxString::Format(wxT("[(%u, %u, 1), (%u, 150, 0), (151, 200, 1)]"), start, end, end + 1));
 			multiInsert(SDIFF, start, end, 1, wxString::Format(wxT("[(%u, %u, 1), (%u, 150, 0), (160, 200, 1)]"), start, end, end + 1));
 			multiInsert(SSAME, start, end, 1, wxString::Format(wxT("[(%u, 150, 1), (160, 200, 1)]"), start));
@@ -597,11 +597,11 @@ TEST(RangeMap, MultiInsert_AtStart_AtEnd_TouchingEnd_AfterEnd)
 	for (int offset = 0; offset < 3; ++offset) { // (at end, touching end, after end)
 		int start = 100;
 		int end   = 150 + offset;
-		
+
 		multiInsert(CONT, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (%u, 200, 1)]"), start, end, end + 1));
 		multiInsert(SDIFF, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (160, 200, 1)]"), start, end));
 		multiInsert(SSAME, start, end, 0, wxString::Format(wxT("[(%u, %u, 0), (160, 200, 1)]"), start, end));
-		
+
 		multiInsert(CONT, start, end, 1, wxString::Format(wxT("[(%u, 200, 1)]"), start));
 		multiInsert(SDIFF, start, end, 1, wxString::Format(wxT("[(%u, %u, 1), (160, 200, 1)]"), start, end));
 		multiInsert(SSAME, start, end, 1, wxString::Format(wxT("[(%u, %u, 1), (160, 200, 1)]"), start, end));
@@ -615,7 +615,7 @@ TEST(RangeMap, MultiInsert_Inside_Inside)
 	multiInsert(CONT, 110, 140, 0, wxT("[(100, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 110, 140, 0, wxT("[(100, 150, 0), (160, 200, 1)]"));
 	multiInsert(SSAME, 110, 140, 0, wxT("[(100, 109, 1), (110, 140, 0), (141, 150, 1), (160, 200, 1)]"));
-	
+
 	multiInsert(CONT, 110, 140, 1, wxT("[(100, 109, 0), (110, 140, 1), (141, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 110, 140, 1, wxT("[(100, 109, 0), (110, 140, 1), (141, 150, 0), (160, 200, 1)]"));
 	multiInsert(SSAME, 110, 140, 1, wxT("[(100, 150, 1), (160, 200, 1)]"));
@@ -629,11 +629,11 @@ TEST(RangeMap, MultiInsert_Inside_AtEnd_AtEnd_TouchingEnd_AfterEnd)
 		for (int offset_b = 0; offset_b < 3; ++offset_b) { // (at end, touching end, after end)
 			int start = 149 + offset_a;
 			int end   = 150 + offset_b;
-			
+
 			multiInsert(CONT, start, end, 0, wxString::Format(wxT("[(100, %u, 0), (%u, 200, 1)]"), end, end + 1));
 			multiInsert(SDIFF, start, end, 0, wxString::Format(wxT("[(100, %u, 0), (160, 200, 1)]"), end));
 			multiInsert(SSAME, start, end, 0, wxString::Format(wxT("[(100, %u, 1), (%u, %u, 0), (160, 200, 1)]"), start - 1, start, end));
-			
+
 			multiInsert(CONT, start, end, 1, wxString::Format(wxT("[(100, %u, 0), (%u, 200, 1)]"), start - 1, start));
 			multiInsert(SDIFF, start, end, 1, wxString::Format(wxT("[(100, %u, 0), (%u, %u, 1), (160, 200, 1)]"), start - 1, start, end));
 			multiInsert(SSAME, start, end, 1, wxString::Format(wxT("[(100, %u, 1), (160, 200, 1)]"), end));
@@ -648,11 +648,11 @@ TEST(RangeMap, MultiInsert_TouchingEnd_TouchingEnd_AfterEnd)
 	for (int offset = 0; offset < 2; ++offset) { // (touching end, after end)
 		int start = 151;
 		int end   = 151 + offset;
-		
+
 		multiInsert(CONT, start, end, 0, wxString::Format(wxT("[(100, %u, 0), (%u, 200, 1)]"), end, end + 1));
 		multiInsert(SDIFF, start, end, 0, wxString::Format(wxT("[(100, %u, 0), (160, 200, 1)]"), end));
 		multiInsert(SSAME, start, end, 0, wxString::Format(wxT("[(100, 150, 1), (%u, %u, 0), (160, 200, 1)]"), start, end));
-		
+
 		multiInsert(CONT, start, end, 1, wxString::Format(wxT("[(100, 150, 0), (%u, 200, 1)]"), start));
 		multiInsert(SDIFF, start, end, 1, wxString::Format(wxT("[(100, 150, 0), (%u, %u, 1), (160, 200, 1)]"), start, end));
 		multiInsert(SSAME, start, end, 1, wxString::Format(wxT("[(100, %u, 1), (160, 200, 1)]"), end));
@@ -666,7 +666,7 @@ TEST(RangeMap, MultiInsert_AfterEnd_AfterEnd)
 	multiInsert(CONT, 152, 170, 0, wxT("[(100, 150, 0), (151, 151, 1), (152, 170, 0), (171, 200, 1)]"));
 	multiInsert(SDIFF, 152, 170, 0, wxT("[(100, 150, 0), (152, 170, 0), (171, 200, 1)]"));
 	multiInsert(SSAME, 152, 170, 0, wxT("[(100, 150, 1), (152, 170, 0), (171, 200, 1)]"));
-	
+
 	multiInsert(CONT, 152, 170, 1, wxT("[(100, 150, 0), (151, 200, 1)]"));
 	multiInsert(SDIFF, 152, 170, 1, wxT("[(100, 150, 0), (152, 200, 1)]"));
 	multiInsert(SSAME, 152, 170, 1, wxT("[(100, 150, 1), (152, 200, 1)]"));
@@ -716,7 +716,7 @@ TEST(RangeMap, Erase_BeforeStart_TouchingStart_AtEnd_TouchingEnd_AfterEnd)
 
 
 // Single erase touching start <-> touching start.
-TEST(RangeMap, Erase_TouchingStart_TouchingStart) 
+TEST(RangeMap, Erase_TouchingStart_TouchingStart)
 {
 	doErase(99, 99, wxT("[(100, 150, 0)]"));
 }
@@ -729,15 +729,15 @@ TEST(RangeMap, Erase_TouchingStart_AtStart_AtStart_Inside)
 		for (int offset_b = 0; offset_b < 2; ++offset_b) { // (at start, inside)
 			int start = 99 + offset_a;
 			int end   = 100 + offset_b;
-			
-			doErase(start, end, wxString::Format(wxT("[(%u, 150, 0)]"), 100 + offset_b + 1)); 
+
+			doErase(start, end, wxString::Format(wxT("[(%u, 150, 0)]"), 100 + offset_b + 1));
 		}
 	}
 }
 
 
 // Single erase at start <-> at end / touching end / after end.
-TEST(RangeMap, Erase_AtStart_AtEnd_TouchingEnd_AfterEnd) 
+TEST(RangeMap, Erase_AtStart_AtEnd_TouchingEnd_AfterEnd)
 {
 	// (at end, touching end, after end)
 	for (int offset = 0; offset < 3; ++offset) {
@@ -755,7 +755,7 @@ TEST(RangeMap, Erase_Inside_AtEnd_AtEnd_TouchingEnd_AfterEnd)
 		for (int offset_b = 0; offset_b < 3; ++offset_b) {
 			int start = 149 + offset_a;
 			int end   = 150 + offset_b;
-			
+
 			doErase(start, end, wxString::Format(wxT("[(100, %u, 0)]"), start - 1));
 		}
 	}
@@ -768,7 +768,7 @@ TEST(RangeMap, Erase_TouchingEnd_TouchingEnd_AfterEnd)
 	// (touching end, after end)
 	for (int offset = 0; offset < 2; ++offset) {
 		int end = 151 + offset;
-		
+
 		doErase(151, end, wxT("[(100, 150, 0)]"));
 	}
 }
@@ -786,34 +786,34 @@ TEST(RangeMap, Swap)
 	{
 		TestRangeMap mapA = m_mmaps[CONT];
 		TestRangeMap mapB = m_mmaps[SSAME];
-		
-		ASSERT_EQUALS(mapA, m_mmaps[CONT]);
-		ASSERT_EQUALS(mapB, m_mmaps[SSAME]);
-		
+
+		ASSERT_EQUALS(m_mmaps[CONT], mapA);
+		ASSERT_EQUALS(m_mmaps[SSAME], mapB);
+
 		std::swap(mapA, mapB);
 
-		ASSERT_EQUALS(mapB, m_mmaps[CONT]);
-		ASSERT_EQUALS(mapA, m_mmaps[SSAME]);		
+		ASSERT_EQUALS(m_mmaps[CONT], mapB);
+		ASSERT_EQUALS(m_mmaps[SSAME], mapA);
 	}
-	
+
 	{
 		TestRangeMap mapA = m_mmaps[CONT];
 		TestRangeMap mapB = m_mmaps[SSAME];
-		
-		ASSERT_EQUALS(mapA, m_mmaps[CONT]);
-		ASSERT_EQUALS(mapB, m_mmaps[SSAME]);
-		
+
+		ASSERT_EQUALS(m_mmaps[CONT], mapA);
+		ASSERT_EQUALS(m_mmaps[SSAME], mapB);
+
 		mapA.swap(mapB);
 
-		ASSERT_EQUALS(mapB, m_mmaps[CONT]);
-		ASSERT_EQUALS(mapA, m_mmaps[SSAME]);		
+		ASSERT_EQUALS(m_mmaps[CONT], mapB);
+		ASSERT_EQUALS(m_mmaps[SSAME], mapA);
 	}
 }
 
 
 /////////////////////////////////////////////////
 // The following test exercize the CRangeSet specialization.
-// 
+//
 
 TEST(RangeMap, RangeSet)
 {
